@@ -3,7 +3,7 @@
  *
  * See RFC 1777 (LDAP v2), RFC 2251 (LDAP v3), and RFC 2222 (SASL).
  *
- * $Id: packet-ldap-template.c 26272 2008-09-25 19:21:44Z etxrab $
+ * $Id: packet-ldap-template.c 26772 2008-11-13 17:54:17Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -210,12 +210,12 @@ static guint global_ldaps_tcp_port = TCP_PORT_LDAPS;
 static guint tcp_port = 0;
 static guint ssl_port = 0;
 
-static dissector_handle_t gssapi_handle = NULL;
-static dissector_handle_t gssapi_wrap_handle = NULL;
-static dissector_handle_t ntlmssp_handle = NULL;
-static dissector_handle_t spnego_handle = NULL;
-static dissector_handle_t ssl_handle = NULL;
-static dissector_handle_t ldap_handle = NULL;
+static dissector_handle_t gssapi_handle;
+static dissector_handle_t gssapi_wrap_handle;
+static dissector_handle_t ntlmssp_handle;
+static dissector_handle_t spnego_handle;
+static dissector_handle_t ssl_handle;
+static dissector_handle_t ldap_handle ;
 
 void prefs_register_ldap(void); /* forward declaration for use in preferences registration */
 
@@ -398,7 +398,7 @@ static int dissect_mscldap_ntver_flags(proto_tree *parent_tree, tvbuff_t *tvb, i
       else
 	one_bit_set = TRUE;
 
-      proto_item_append_text(item, hfi->name);
+      proto_item_append_text(item, "%s", hfi->name);
 
     }
   }
@@ -1267,7 +1267,7 @@ static int dissect_mscldap_netlogon_flags(proto_tree *parent_tree, tvbuff_t *tvb
       else
 	one_bit_set = TRUE;
 
-      proto_item_append_text(item, hfi->name);
+      proto_item_append_text(item, "%s", hfi->name);
 
     }
   }
@@ -2115,7 +2115,7 @@ void proto_register_ldap(void) {
   prefs_register_bool_preference(ldap_module, "desegment_ldap_messages",
     "Reassemble LDAP messages spanning multiple TCP segments",
     "Whether the LDAP dissector should reassemble messages spanning multiple TCP segments."
-    "To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.",
+    " To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.",
     &ldap_desegment);
 
   prefs_register_uint_preference(ldap_module, "tcp.port", "LDAP TCP Port",
@@ -2145,13 +2145,10 @@ void
 proto_reg_handoff_ldap(void)
 {
 	dissector_handle_t cldap_handle;
-	ldap_handle = create_dissector_handle(dissect_ldap_tcp, proto_ldap);
+	ldap_handle = find_dissector("ldap");
 
-	dissector_add("tcp.port", global_ldap_tcp_port, ldap_handle);
 	dissector_add("tcp.port", TCP_PORT_GLOBALCAT_LDAP, ldap_handle);
 
-	ssl_dissector_add(global_ldaps_tcp_port, "ldap", TRUE);
-
 	cldap_handle = create_dissector_handle(dissect_mscldap, proto_cldap);
 	dissector_add("udp.port", UDP_PORT_CLDAP, cldap_handle);
 
@@ -2163,6 +2160,8 @@ proto_reg_handoff_ldap(void)
 
 	ssl_handle = find_dissector("ssl");
 
+	prefs_register_ldap();
+
 /*  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dsml/dsml/ldap_controls_and_session_support.asp */
 	oid_add_from_string("LDAP_PAGED_RESULT_OID_STRING","1.2.840.113556.1.4.319");
 	oid_add_from_string("LDAP_SERVER_SHOW_DELETED_OID","1.2.840.113556.1.4.417");
