@@ -2,7 +2,7 @@
  * Routines for PKCS#12: Personal Information Exchange packet dissection
  * Graeme Lunt 2006
  *
- * $Id: packet-pkcs12-template.c 24116 2008-01-16 20:41:23Z stig $
+ * $Id: packet-pkcs12-template.c 25276 2008-05-11 18:33:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -365,7 +365,7 @@ int PBE_decrypt_data(const char *object_identifier_id _U_, tvbuff_t *encrypted_t
 
 	name = g_string_new("");
 	oidname = oid_resolved_from_string(object_identifier_id);
-	g_string_sprintf(name, "Decrypted %s", oidname ? oidname : object_identifier_id);
+	g_string_printf(name, "Decrypted %s", oidname ? oidname : object_identifier_id);
 
 	/* add it as a new source */
 	add_new_data_source(actx->pinfo, clear_tvb, name->str);
