@@ -2,7 +2,7 @@
  * Routines for Q.932 packet dissection
  * 2007  Tomas Kukosa
  *
- * $Id: packet-q932-template.c 25839 2008-07-26 15:28:04Z kukosa $
+ * $Id: packet-q932-template.c 26693 2008-11-04 21:42:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -60,11 +60,7 @@ static gint ett_q932_ie = -1;
 static rose_ctx_t q932_rose_ctx;
 
 /* Subdissectors */
-static dissector_handle_t data_handle = NULL; 
-static dissector_handle_t q932_ros_handle = NULL; 
-
-/* Gloabl variables */
-
+static dissector_handle_t q932_ros_handle; 
 
 #define	Q932_IE_EXTENDED_FACILITY   0x0D
 #define	Q932_IE_FACILITY            0x1C
@@ -335,7 +331,6 @@ void proto_reg_handoff_q932(void) {
   dissector_add("q931.ie", (0x00 << 8) | Q932_IE_NOTIFICATION_INDICATOR, q932_ie_handle); 
 
   q932_ros_handle = find_dissector("q932.ros");
-  data_handle = find_dissector("data");
 }
 
 /*---------------------------------------------------------------------------*/
