@@ -17,7 +17,7 @@
  * See RFC 2578 for Structure of Management Information Version 2 (SMIv2)
  * Copyright (C) 2007 Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-snmp-template.c 26058 2008-08-22 14:28:03Z wmeier $
+ * $Id: packet-snmp-template.c 27037 2008-12-17 17:23:37Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -546,7 +546,7 @@ extern int dissect_snmp_VarBind(gboolean implicit_tag _U_,
 
 						switch(k->key_type) {
 							case OID_KEY_TYPE_WRONG: {
-								proto_item* pi = proto_tree_add_text(pt_name,tvb,0,0,"OID instaces not handled, if you want this implemented please contact the wireshark developpers");
+								proto_item* pi = proto_tree_add_text(pt_name,tvb,0,0,"OID instaces not handled, if you want this implemented please contact the wireshark developers");
 								expert_add_info_format(actx->pinfo, pi, PI_UNDECODED, PI_WARN, "Unimplemented instance index");
 								oid_info_is_ok = FALSE;
 								goto indexing_done;
@@ -615,6 +615,7 @@ show_oid_index:
 										break;
 									case OID_KEY_TYPE_IMPLIED_STRING:
 									case OID_KEY_TYPE_IMPLIED_BYTES:
+									case OID_KEY_TYPE_ETHER:
 										suboid = &(subids[key_start]);
 										buf_len = key_len;
 										break;
@@ -652,6 +653,9 @@ show_oid_index:
 									case OID_KEY_TYPE_IMPLIED_BYTES:
 										proto_tree_add_bytes(pt_name,k->hfid,tvb,name_offset,buf_len, buf);
 										break;
+									case OID_KEY_TYPE_ETHER:
+										proto_tree_add_ether(pt_name,k->hfid,tvb,name_offset,buf_len, buf);
+										break;
 									case OID_KEY_TYPE_IPADDR: {
 										guint32* ipv4_p = (void*)buf;
 										proto_tree_add_ipv4(pt_name,k->hfid,tvb,name_offset,buf_len, *ipv4_p);
@@ -1120,7 +1124,7 @@ static gboolean snmp_usm_auth_md5(snmp_usm_params_t* p, guint8** calc_auth_p, gu
 	guint8* auth;
 	guint8* key;
 	guint key_len;
-	guint8 calc_auth[16];
+	guint8 *calc_auth;
 	guint start;
 	guint end;
 	guint i;
@@ -1160,6 +1164,8 @@ static gboolean snmp_usm_auth_md5(snmp_usm_params_t* p, guint8** calc_auth_p, gu
 		msg[i] = '\0';
 	}
 
+	calc_auth = ep_alloc(16);
+
 	md5_hmac(msg, msg_len, key, key_len, calc_auth);
 
 	if (calc_auth_p) *calc_auth_p = calc_auth;
@@ -1176,7 +1182,7 @@ static gboolean snmp_usm_auth_sha1(snmp_usm_params_t* p _U_, guint8** calc_auth_
 	guint8* auth;
 	guint8* key;
 	guint key_len;
-	guint8 calc_auth[20];
+	guint8 *calc_auth;
 	guint start;
 	guint end;
 	guint i;
@@ -1216,6 +1222,8 @@ static gboolean snmp_usm_auth_sha1(snmp_usm_params_t* p _U_, guint8** calc_auth_
 		msg[i] = '\0';
 	}
 
+	calc_auth = ep_alloc(20);
+
 	sha1_hmac(key, key_len, msg, msg_len, calc_auth);
 
 	if (calc_auth_p) *calc_auth_p = calc_auth;
