@@ -7,7 +7,7 @@
  * Copyright 2005, Ronnie Sahlberg (krb decryption)
  * Copyright 2005, Anders Broman (converted to asn2wrs generated dissector)
  *
- * $Id: packet-spnego-template.c 26353 2008-10-05 08:41:44Z sahlberg $
+ * $Id: packet-spnego-template.c 26693 2008-11-04 21:42:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -96,8 +96,6 @@ static gint ett_spnego_krb5_cfx_flags = -1;
 
 #include "packet-spnego-ett.c"
 
-static dissector_handle_t data_handle;
-
 /*
  * Unfortunately, we have to have a forward declaration of this,
  * as the code generated by asn2wrs includes a call before the
@@ -1414,9 +1412,8 @@ void proto_reg_handoff_spnego(void) {
 
 	/* Register protocol with GSS-API module */
 
-	spnego_handle = create_dissector_handle(dissect_spnego, proto_spnego);
-	spnego_wrap_handle = new_create_dissector_handle(dissect_spnego_wrap,
-							 proto_spnego);
+        spnego_handle = find_dissector("spnego");
+	spnego_wrap_handle = new_create_dissector_handle(dissect_spnego_wrap,  proto_spnego);
 	gssapi_init_oid("1.3.6.1.5.5.2", proto_spnego, ett_spnego,
 	    spnego_handle, spnego_wrap_handle,
 	    "SPNEGO - Simple Protected Negotiation");
@@ -1430,10 +1427,8 @@ void proto_reg_handoff_spnego(void) {
 	 * See the archive of <ietf-krb-wg@anl.gov> for the thread topic
 	 * SPNEGO implementation issues. 3-Dec-2002.
 	 */
-	spnego_krb5_handle = create_dissector_handle(dissect_spnego_krb5,
-						     proto_spnego_krb5);
-	spnego_krb5_wrap_handle = new_create_dissector_handle(dissect_spnego_krb5_wrap,
-							      proto_spnego_krb5);
+        spnego_krb5_handle = find_dissector("spnego-krb5");
+	spnego_krb5_wrap_handle = find_dissector("spnego-krb5-wrap");
 	gssapi_init_oid("1.2.840.48018.1.2.2", proto_spnego_krb5, ett_spnego_krb5,
 			spnego_krb5_handle, spnego_krb5_wrap_handle,
 			"MS KRB5 - Microsoft Kerberos 5");
@@ -1444,8 +1439,4 @@ void proto_reg_handoff_spnego(void) {
 			spnego_krb5_handle, spnego_krb5_wrap_handle,
 			"KRB5 - Kerberos 5 - User to User");
 
-	/*
-	 * Find the data handle for some calls
-	 */
-	data_handle = find_dissector("data");
 }
