@@ -1,7 +1,7 @@
 /* capture-pcap-util.h
  * Utility definitions for packet capture
  *
- * $Id: capture-pcap-util.h 24407 2008-02-21 12:30:26Z guy $
+ * $Id: capture-pcap-util.h 27074 2008-12-21 23:22:12Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -100,12 +100,8 @@ int get_pcap_linktype(pcap_t *pch, const char *devname);
 const char *set_pcap_linktype(pcap_t *pch, char *devname, int dlt);
 
 
-#ifdef HAVE_PCAP_DATALINK_VAL_TO_NAME
 const char *linktype_val_to_name(int dlt);
-#endif
-#ifdef HAVE_PCAP_DATALINK_NAME_TO_VAL
 int linktype_name_to_val(const char *linktype);
-#endif
 
 #ifdef __cplusplus
 }
