@@ -1,7 +1,7 @@
 /* capture_opts.c
  * Routines for capture options setting
  *
- * $Id: capture_opts.c 25566 2008-06-23 21:58:16Z stig $
+ * $Id: capture_opts.c 27074 2008-12-21 23:22:12Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -157,7 +157,7 @@ capture_opts_log(const char *log_domain, GLogLevelFlags log_level, capture_optio
         "Unknown");
     if (capture_opts->src_type == CAPTURE_IFREMOTE) {
         g_log(log_domain, log_level, "Remote host        : %s", capture_opts->remote_host);
-        g_log(log_domain, log_level, "Remote port        : %u", capture_opts->remote_port);
+        g_log(log_domain, log_level, "Remote port        : %s", capture_opts->remote_port);
     }
     g_log(log_domain, log_level, "Authentication     : %s",
         capture_opts->auth_type == CAPTURE_AUTH_NULL ? "Null" :
@@ -536,17 +536,12 @@ capture_opts_add_opt(capture_options *capture_opts, int opt, const char *optarg,
         status = capture_opts_output_to_pipe(capture_opts->save_file, &capture_opts->output_to_pipe);
         return status;
     case 'y':        /* Set the pcap data link type */
-#ifdef HAVE_PCAP_DATALINK_NAME_TO_VAL
         capture_opts->linktype = linktype_name_to_val(optarg);
         if (capture_opts->linktype == -1) {
           cmdarg_err("The specified data link type \"%s\" isn't valid",
                   optarg);
           return 1;
         }
-#else /* HAVE_PCAP_DATALINK_NAME_TO_VAL */
-        /* we can't get the type name, just treat it as a number */
-        capture_opts->linktype = get_natural_int(optarg, "data link type");
-#endif /* HAVE_PCAP_DATALINK_NAME_TO_VAL */
         break;
     default:
         /* the caller is responsible to send us only the right opt's */
@@ -669,7 +664,7 @@ capture_opts_list_interfaces(gboolean machine_readable)
                 case AT_IPv4:
                     if (inet_ntop(AF_INET, &if_addr->ip_addr.ip4_addr, addr_str,
                                 ADDRSTRLEN)) {
-                        printf(addr_str);
+                        printf("%s", addr_str);
                     } else {
                         printf("<unknown IPv4>");
                     }
@@ -677,7 +672,7 @@ capture_opts_list_interfaces(gboolean machine_readable)
                 case AT_IPv6:
                     if (inet_ntop(AF_INET6, &if_addr->ip_addr.ip6_addr,
                                 addr_str, ADDRSTRLEN)) {
-                        printf(addr_str);
+                        printf("%s", addr_str);
                     } else {
                         printf("<unknown IPv6>");
                     }
