@@ -1,7 +1,7 @@
 /* capture_opts.h
  * Capture options (all parameters needed to do the actual capture)
  *
- * $Id: capture_opts.h 23750 2007-12-04 11:19:29Z kukosa $
+ * $Id: capture_opts.h 25574 2008-06-24 03:38:15Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -32,6 +32,10 @@
 #ifndef __CAPTURE_OPTS_H__
 #define __CAPTURE_OPTS_H__
 
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>	    /* for gid_t */
+#endif
+
 
 /* Current state of capture engine. XXX - differentiate states */
 typedef enum {
@@ -157,7 +161,7 @@ typedef struct capture_options_tag {
 
 /* initialize the capture_options with some reasonable values */
 extern void
-capture_opts_init(capture_options *capture_opts, void *cfile);
+capture_opts_init(capture_options *capture_opts, void *cf);
 
 /* set a command line option value */
 extern int
@@ -175,10 +179,6 @@ capture_opts_list_link_layer_types(capture_options *capture_opts, gboolean machi
 extern int
 capture_opts_list_interfaces(gboolean machine_readable);
 
-/* print interface statistics */
-extern int
-capture_opts_print_statistics(gboolean machine_readable);
-
 /* trim the snaplen entry */
 extern void
 capture_opts_trim_snaplen(capture_options *capture_opts, int snaplen_min);
