@@ -1,6 +1,6 @@
 /* dftest.c.c
  *
- * $Id: dftest.c 20261 2007-01-02 06:49:40Z guy $
+ * $Id: dftest.c 25640 2008-06-30 17:16:29Z morriss $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -43,7 +43,7 @@
 #include <epan/timestamp.h>
 #include <epan/plugins.h>
 #include <epan/filesystem.h>
-#include <epan/privileges.h>
+#include <wsutil/privileges.h>
 #include <epan/prefs.h>
 #include "util.h"
 #include "epan/dfilter/dfilter.h"
@@ -59,6 +59,7 @@ static void read_failure_message(const char *filename, int err);
 int
 main(int argc, char **argv)
 {
+	char		*init_progfile_dir_error;
 	char		*text;
 	char		*gpf_path, *pf_path;
 	int		gpf_open_errno, gpf_read_errno;
@@ -66,20 +67,19 @@ main(int argc, char **argv)
 	e_prefs		*prefs;
 	dfilter_t	*df;
 
-	/*
-	 * Attempt to get the pathname of the executable file.
-	 */
-	init_progfile_dir(argv[0]);
-
 	/*
 	 * Get credential information for later use.
 	 */
 	get_credential_info();
 
 	/*
-	 * Now attempt to get the pathname of the plugins.
+	 * Attempt to get the pathname of the executable file.
 	 */
-	init_plugin_dir();
+	init_progfile_dir_error = init_progfile_dir(argv[0]);
+	if (init_progfile_dir_error != NULL) {
+		fprintf(stderr, "dftest: Can't get pathname of dftest program: %s.\n",
+		    init_progfile_dir_error);
+	}
 
 	timestamp_set_type(TS_RELATIVE);
 
@@ -88,7 +88,7 @@ main(int argc, char **argv)
 	   by the dissectors, and we must do it before we read the preferences,
 	   in case any dissectors register preferences. */
 	epan_init(register_all_protocols,
-		  register_all_protocol_handoffs,
+		  register_all_protocol_handoffs, NULL, NULL,
 		  failure_message, open_failure_message, read_failure_message);
 
 	/* now register the preferences for any non-dissector modules.
