@@ -1,7 +1,7 @@
 /* Edit capture files.  We can delete packets, adjust timestamps, or
  * simply convert from one format to another format.
  *
- * $Id: editcap.c 25640 2008-06-30 17:16:29Z morriss $
+ * $Id: editcap.c 27051 2008-12-18 19:24:34Z morriss $
  *
  * Originally written by Richard Sharpe.
  * Improved by Guy Harris.
@@ -48,6 +48,9 @@
 
 #ifdef _WIN32
 #include <process.h>    /* getpid */
+#ifdef HAVE_WINSOCK2_H
+#include <winsock2.h>
+#endif
 #endif
 
 #ifdef NEED_STRPTIME_H
@@ -369,6 +372,7 @@ list_encap_types(void) {
     }
 }
 
+#ifdef HAVE_PLUGINS
 /*
  *  Don't report failures to load plugins because most (non-wiretap) plugins
  *  *should* fail to load (because we're not linked against libwireshark and
@@ -379,6 +383,7 @@ failure_message(const char *msg_format _U_, va_list ap _U_)
 {
 	return;
 }
+#endif
 
 int
 main(int argc, char *argv[])
