@@ -1,5 +1,5 @@
 /*
- * $Id: dfilter.c 24238 2008-01-31 23:10:09Z stig $
+ * $Id: dfilter.c 25582 2008-06-24 18:22:26Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -254,7 +254,7 @@ dfilter_compile(const gchar *text, dfilter_t **dfp)
 
 		if (depr_test) {
 			for (i = 0; i < deprecated->len; i++) {
-				if (strcasecmp(depr_test, g_ptr_array_index(deprecated, i)) == 0) {
+				if (g_ascii_strcasecmp(depr_test, g_ptr_array_index(deprecated, i)) == 0) {
 					/* It's already in our list */
 					depr_test = NULL;
 				}
@@ -401,7 +401,7 @@ void
 dfilter_dump(dfilter_t *df)
 {
 	guint i;
-	gchar *sep = "";
+	const gchar *sep = "";
 
 	dfvm_dump(stdout, df->insns);
 
