@@ -1,7 +1,7 @@
 /* packet-3com-njack.c
  * Routines for the disassembly of the 3com NetworkJack management protocol
  *
- * $Id: packet-3com-njack.c 26121 2008-09-02 19:08:29Z wmeier $
+ * $Id: packet-3com-njack.c 27057 2008-12-19 04:21:08Z wmeier $
  *
  * Copyright 2005 Joerg Mayer (see AUTHORS file)
  *
@@ -746,7 +746,7 @@ proto_register_njack(void)
                         0x0, "", HFILL }},
 
                 { &hf_njack_tlv_countermode,
-                { "TlvTypeCountermode",   "njack.tlv.contermode", FT_UINT8, BASE_DEC, VALS(&njack_countermode),
+                { "TlvTypeCountermode",   "njack.tlv.countermode", FT_UINT8, BASE_DEC, VALS(&njack_countermode),
                         0x0, "", HFILL }},
 
                 { &hf_njack_tlv_powerforwarding,
