@@ -11,7 +11,7 @@
  * Routines for Mobile IP dissection
  * Copyright 2000, Stefan Raab <sraab@cisco.com>
  *
- * $Id: packet-3g-a11.c 26073 2008-08-25 16:42:09Z wmeier $
+ * $Id: packet-3g-a11.c 27207 2009-01-10 11:21:36Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -33,18 +33,14 @@
  *
  *Ref:
  * http://www.3gpp2.org/Public_html/specs/A.S0009-C_v1.0_070801.pdf
+ * http://www.3gpp2.org/Public_html/specs/A.S0017-D_v1.0_070624.pdf (IOS 5.1)
  */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-
-#include <string.h>
 #include <glib.h>
-#include <time.h>
 
 #include <epan/packet.h>
 /* Include vendor id translation */
@@ -105,7 +101,7 @@ static int hf_a11_ase_gre_proto_type = -1;
 static int hf_a11_ase_gre_key = -1;
 static int hf_a11_ase_pcf_addr_key = -1;
 
-/* Foward QoS Information */
+/* Forward QoS Information */
 static int hf_a11_fqi_length = -1;
 static int hf_a11_fqi_srid = -1;
 static int hf_a11_fqi_flags = -1;
@@ -167,7 +163,9 @@ typedef enum {
     REGISTRATION_UPDATE = 20,
     REGISTRATION_ACK =21,
     SESSION_UPDATE = 22,
-    SESSION_ACK = 23
+    SESSION_ACK = 23,
+    CAPABILITIES_INFO = 24,
+    CAPABILITIES_INFO_ACK = 25
 } a11MessageTypes;
 
 static const value_string a11_types[] = {
@@ -177,6 +175,8 @@ static const value_string a11_types[] = {
   {REGISTRATION_ACK,   "Registration Ack"},
   {SESSION_UPDATE,   "Session Update"},
   {SESSION_ACK,   "Session Update Ack"},
+  {CAPABILITIES_INFO,   "Capabilities Info"},
+  {CAPABILITIES_INFO_ACK,   "Capabilities Info Ack"},
   {0, NULL},
 };
 
@@ -405,10 +405,11 @@ static const struct radius_attribute attrs[]={
   {"SDB Octet Count (Orig.)", 26, 32,  4, ATTR_TYPE_INT},
   {"ESN (Integer)",           26, 48,  4, ATTR_TYPE_INT},
   {"Sublink",	              26, 108,  4, ATTR_TYPE_STR},
+  {"MEID",                    26, 116, 14, ATTR_TYPE_STR},
   {"Reverse PDCH RC",	      26, 114,  2, ATTR_TYPE_INT},
   {"Flow ID Parameter",       26, 144,  4, ATTR_TYPE_INT},
   {"Granted QoS Parameters",  26, 132,  4, ATTR_TYPE_INT},
-  {"Flow Status",			  26, 145,  4, ATTR_TYPE_INT},
+  {"Flow Status",             26, 145,  4, ATTR_TYPE_INT},
   {"Unknown",                 -1, -1, -1, ATTR_TYPE_NULL},
 };
 #define NUM_ATTR (sizeof(attrs)/sizeof(struct radius_attribute))
@@ -1641,6 +1642,81 @@ dissect_a11( tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 					    ntp_fmt_ts(reftime));
 	  offset += 8;
 
+	} /* if tree */
+	break;
+  case CAPABILITIES_INFO: /* IOS5.1 */
+	if (check_col(pinfo->cinfo, COL_INFO))
+	  col_add_fstr(pinfo->cinfo, COL_INFO, "Cap Info: PDSN=%s, PCF=%s",
+				   ip_to_str(tvb_get_ptr(tvb, 8, 4)),
+				   ip_to_str(tvb_get_ptr(tvb,12,4)));
+	if (tree) {
+	  /* Add Subtree */
+	  ti = proto_tree_add_item(tree, proto_a11, tvb, offset, -1, FALSE);
+	  a11_tree = proto_item_add_subtree(ti, ett_a11);
+
+	  /* Type */
+  	  proto_tree_add_uint(a11_tree, hf_a11_type, tvb, offset, 1, type);
+	  offset++;
+
+	  /* Reserved */
+	  offset+=3;
+
+	  /* Home address */
+	  proto_tree_add_item(a11_tree, hf_a11_homeaddr, tvb, offset, 4, FALSE);
+	  offset += 4;
+
+	  /* Home Agent Address */
+	  proto_tree_add_item(a11_tree, hf_a11_haaddr, tvb, offset, 4, FALSE);
+	  offset += 4;
+
+	  /* Care of Address */
+	  proto_tree_add_item(a11_tree, hf_a11_coa, tvb, offset, 4, FALSE);
+	  offset += 4;
+
+	  /* Identifier - assumed to be an NTP time here */
+	  reftime = tvb_get_ptr(tvb, offset, 8);
+	  proto_tree_add_bytes_format_value(a11_tree, hf_a11_ident, tvb,
+					    offset, 8,
+					    reftime,
+					    "%s",
+					    ntp_fmt_ts(reftime));
+	  offset += 8;
+
+	} /* if tree */
+	break;
+  case CAPABILITIES_INFO_ACK: /* IOS5.1 */
+	if (check_col(pinfo->cinfo, COL_INFO))
+	  col_add_fstr(pinfo->cinfo, COL_INFO, "Cap Info Ack: PCF=%s",
+				   ip_to_str(tvb_get_ptr(tvb, 8, 4)));
+	if (tree) {
+	  /* Add Subtree */
+	  ti = proto_tree_add_item(tree, proto_a11, tvb, offset, -1, FALSE);
+	  a11_tree = proto_item_add_subtree(ti, ett_a11);
+
+	  /* Type */
+	  proto_tree_add_uint(a11_tree, hf_a11_type, tvb, offset, 1, type);
+	  offset++;
+
+	  /* Reserved */
+	  offset+=3;
+
+	  /* Home address */
+	  proto_tree_add_item(a11_tree, hf_a11_homeaddr, tvb, offset, 4, FALSE);
+	  offset += 4;
+
+	  /* Care of Address */
+	  proto_tree_add_item(a11_tree, hf_a11_coa, tvb, offset, 4, FALSE);
+	  offset += 4;
+
+	  /* Identifier - assumed to be an NTP time here */
+	  reftime = tvb_get_ptr(tvb, offset, 8);
+	  proto_tree_add_bytes_format_value(a11_tree, hf_a11_ident, tvb,
+					    offset, 8,
+					    reftime,
+					    "%s",
+					    ntp_fmt_ts(reftime));
+	  offset += 8;
+
 	} /* if tree */
 	break;
   } /* End switch */
@@ -2012,14 +2088,14 @@ proto_register_a11(void)
 			"Reverse QoS Update Flow Count.", HFILL }
 	  },
 	  { &hf_a11_fqui_updated_qoslen,
-		 { "Foward Updated QoS Sub-Blob Length",   "a11.ext.fqui.updatedqoslen",
+		 { "Forward Updated QoS Sub-Blob Length",   "a11.ext.fqui.updatedqoslen",
 			FT_UINT8, BASE_DEC, NULL, 0,
-			"Foward Updated QoS Sub-Blob Length.", HFILL }
+			"Forward Updated QoS Sub-Blob Length.", HFILL }
 	  },
 	  { &hf_a11_fqui_updated_qos,
-		 { "Foward Updated QoS Sub-Blob",   "a11.ext.fqui.updatedqos",
+		 { "Forward Updated QoS Sub-Blob",   "a11.ext.fqui.updatedqos",
 			FT_BYTES, BASE_NONE, NULL, 0,
-			"Foward Updated QoS Sub-Blob.", HFILL }
+			"Forward Updated QoS Sub-Blob.", HFILL }
 	  },
 	  { &hf_a11_rqui_updated_qoslen,
 		 { "Reverse Updated QoS Sub-Blob Length",   "a11.ext.rqui.updatedqoslen",
@@ -2081,4 +2157,3 @@ proto_reg_handoff_a11(void)
 	a11_handle = find_dissector("a11");
 	dissector_add("udp.port", UDP_PORT_3GA11, a11_handle);
 }
-
