@@ -3,7 +3,7 @@
  *
  * Copyright (c) 2005 by Alejandro Vaquero <alejandro.vaquero@verso.com>
  *
- * $Id: packet-actrace.c 26124 2008-09-02 21:40:46Z wmeier $
+ * $Id: packet-actrace.c 26176 2008-09-11 14:07:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -803,7 +803,7 @@ void proto_reg_handoff_actrace(void)
 {
 	static gboolean actrace_prefs_initialized = FALSE;
 	static dissector_handle_t actrace_handle;
-	static guint actrace_udp_port = 0;
+	static guint actrace_udp_port;
 
 	if (!actrace_prefs_initialized)
 	{
