@@ -2,7 +2,7 @@
  * Routines for AppleTalk packet disassembly: LLAP, DDP, NBP, ATP, ASP,
  * RTMP, PAP.
  *
- * $Id: packet-atalk.c 25264 2008-05-09 13:59:10Z etxrab $
+ * $Id: packet-atalk.c 27050 2008-12-18 19:08:49Z wmeier $
  *
  * Simon Wilkinson <sxw@dcs.ed.ac.uk>
  *
@@ -1137,7 +1137,7 @@ dissect_asp_reply_get_status(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *
 				}
 				/* else fall to default malformed record */
 			default:
-				ti = proto_tree_add_text(adr_tree, tvb, ofs, len,"Unknow type : %u", type);
+				ti = proto_tree_add_text(adr_tree, tvb, ofs, len,"Unknown type : %u", type);
 				break;
 			}
 			len -= 2;
