@@ -1,7 +1,7 @@
 /* packet-catapult-dct2000.c
  * Routines for Catapult DCT2000 packet stub header disassembly
  *
- * $Id: packet-catapult-dct2000.c 26076 2008-08-25 17:26:26Z wmeier $
+ * $Id: packet-catapult-dct2000.c 27161 2009-01-05 23:18:00Z martinm $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,6 +40,11 @@
 
 #include <wiretap/catapult_dct2000.h>
 #include "packet-umts_fp.h"
+#include "packet-mac-lte.h"
+#include "packet-rlc-lte.h"
+#if 0
+#include "packet-pdcp.h"
+#endif
 
 /* Protocol and registered fields. */
 static int proto_catapult_dct2000 = -1;
@@ -79,6 +84,12 @@ static int hf_catapult_dct2000_sctpprim_addr_v4 = -1;
 static int hf_catapult_dct2000_sctpprim_addr_v6 = -1;
 static int hf_catapult_dct2000_sctpprim_dst_port = -1;
 
+static int hf_catapult_dct2000_lte_ueid = -1;
+static int hf_catapult_dct2000_lte_srbid = -1;
+static int hf_catapult_dct2000_lte_drbid = -1;
+static int hf_catapult_dct2000_lte_cellid = -1;
+static int hf_catapult_dct2000_lte_bcch_transport = -1;
+
 
 /* Variables used for preferences */
 gboolean catapult_dct2000_try_ipprim_heuristic = TRUE;
@@ -110,6 +121,14 @@ static const value_string encap_vals[] = {
     { 0,                                 NULL },
 };
 
+static const value_string bcch_transport_vals[] = {
+    { 1,   "BCH" },
+    { 2,   "DLSCH" },
+    { 0,   NULL },
+};
+
+
+
 
 #define MAX_OUTHDR_VALUES 32
 
@@ -117,7 +136,11 @@ static guint outhdr_values[MAX_OUTHDR_VALUES];
 static gint outhdr_values_found = 0;
 
 extern int proto_fp;
-
+extern int proto_mac_lte;
+extern int proto_rlc_lte;
+#if 0
+extern int proto_pdcp;
+#endif
 
 void proto_register_catapult_dct2000(void);
 
@@ -125,6 +148,12 @@ static dissector_handle_t look_for_dissector(char *protocol_name);
 static void parse_outhdr_string(guchar *outhdr_string);
 static void attach_fp_info(packet_info *pinfo, gboolean received,
                            const char *protocol_name, int variant);
+static void attach_mac_lte_info(packet_info *pinfo);
+static void attach_rlc_lte_info(packet_info *pinfo);
+#if 0
+static void attach_pdcp_info(packet_info *pinfo);
+#endif
+
 
 
 /* Return the number of bytes used to encode the length field
@@ -552,6 +581,185 @@ static gboolean find_sctpprim_variant3_data_offset(tvbuff_t *tvb, int *data_offs
 }
 
 
+typedef enum LogicalChannelType
+{
+    Channel_DCCH=1,
+    Channel_BCCH=2,
+    Channel_CCCH=3,
+    Channel_PCCH=4
+} LogicalChannelType;
+    
+
+/* Dissect an RRC LTE frame by first parsing the header entries then passing
+   the data to the RRC dissector, according to direction and channel type */
+void dissect_rrc_lte(tvbuff_t *tvb, gint offset,
+                     packet_info *pinfo _U_, proto_tree *tree)
+{
+    guint8  tag;
+    dissector_handle_t protocol_handle = 0;
+    gboolean isUplink = FALSE;
+    LogicalChannelType logicalChannelType;
+    guint8   bcch_transport = 0;
+    tvbuff_t *rrc_tvb;
+
+    tag = tvb_get_guint8(tvb, offset++);
+    switch (tag) {
+        case 0x00:    /* Data_Req_UE */
+        case 0x04:    /* Data_Ind_eNodeB */
+            isUplink = TRUE;
+            break;
+
+        case 0x02:    /* Data_Req_eNodeB */
+        case 0x03:    /* Data_Ind_UE */
+            isUplink = FALSE;
+            break;
+
+        default:
+            /* Unexpected opcode tag! */
+            return;
+    }
+
+    /* Skip length */
+    offset += skipASNLength(tvb_get_guint8(tvb, offset));
+
+    /* Get next tag */
+    tag = tvb_get_guint8(tvb, offset++);
+    switch (tag) {
+        case 0x12:    /* UE_Id_LCId */
+            /* Length will fit in one byte here */
+            offset++;
+
+            logicalChannelType = Channel_DCCH;
+
+            /* UEId */
+            proto_tree_add_item(tree, hf_catapult_dct2000_lte_ueid, tvb, offset, 2, FALSE);
+            offset += 2;
+
+            /* Get tag of channel type */
+            tag = tvb_get_guint8(tvb, offset++);
+
+            switch (tag) {
+                case 0:
+                    offset++;
+                    proto_tree_add_item(tree, hf_catapult_dct2000_lte_srbid,
+                                        tvb, offset, 1, FALSE);
+                    break;
+                case 1:
+                    offset++;
+                    proto_tree_add_item(tree, hf_catapult_dct2000_lte_drbid,
+                                        tvb, offset, 1, FALSE);
+                    break;
+
+                default:
+                    /* Unexpected channel type */
+                    return;
+            }
+            break;
+
+        case 0x1a:     /* Cell_LCId */
+
+            /* Skip length */
+            offset++;
+
+            /* Cell-id */
+            proto_tree_add_item(tree, hf_catapult_dct2000_lte_cellid,
+                                tvb, offset, 2, FALSE);
+            offset += 2;
+
+            logicalChannelType = tvb_get_guint8(tvb, offset++);
+            switch (logicalChannelType) {
+                case Channel_BCCH:
+                    /* Skip length */
+                    offset++;
+
+                    /* Transport channel type */
+                    bcch_transport = tvb_get_guint8(tvb, offset);
+                    proto_tree_add_item(tree, hf_catapult_dct2000_lte_bcch_transport,
+                                        tvb, offset, 1, FALSE);
+                    offset++;
+                    break;
+
+                case Channel_CCCH:
+                    /* Skip length */
+                    offset++;
+
+                    /* UEId */
+                    proto_tree_add_item(tree, hf_catapult_dct2000_lte_ueid,
+                                        tvb, offset, 2, FALSE);
+                    offset += 2;
+                    break;
+
+                default:
+                    break;
+            }
+            break;
+
+        default:
+            /* Unexpected tag */
+            return;
+    }
+
+    /* Data tag should follow */
+    tag = tvb_get_guint8(tvb, offset++);
+    if (tag != 0xaa) {
+        return;
+    }
+
+    /* Skip length */
+    offset += skipASNLength(tvb_get_guint8(tvb, offset));
+
+    /* Look up dissector handle corresponding to direction and channel type */
+    if (isUplink) {
+
+        /* Uplink channel types */
+        switch (logicalChannelType) {
+            case Channel_DCCH:
+                protocol_handle = find_dissector("lte-rrc.ul.dcch");
+                break;
+            case Channel_CCCH:
+                protocol_handle = find_dissector("lte-rrc.ul.ccch");
+                break;
+
+            default:
+                /* Unknown Uplink channel type */
+                break;
+        }
+    } else {
+
+        /* Downlink channel types */
+        switch (logicalChannelType) {
+            case Channel_DCCH:
+                protocol_handle = find_dissector("lte-rrc.dl.dcch");
+                break;
+            case Channel_CCCH:
+                protocol_handle = find_dissector("lte-rrc.dl.ccch");
+                break;
+            case Channel_PCCH:
+                protocol_handle = find_dissector("lte-rrc.pcch");
+                break;
+            case Channel_BCCH:
+                if (bcch_transport == 1) {
+                    protocol_handle = find_dissector("lte-rrc.bcch.bch");
+                }
+                else {
+                    protocol_handle = find_dissector("lte-rrc.bcch.dl.sch");
+                }
+                break;
+
+            default:
+                /* Unknown Downlink channel type */
+                break;
+        }
+    }
+
+    /* Send to RRC dissector, if got here, have sub-dissector and some data left */
+    if ((protocol_handle != NULL) && (tvb_length_remaining(tvb, offset) > 0)) {
+        rrc_tvb = tvb_new_subset(tvb, offset, -1, tvb_length_remaining(tvb, offset));
+        call_dissector_only(protocol_handle, rrc_tvb, pinfo, tree);
+    }
+}
+
+
 
 /* Look up dissector by protocol name.  Fix up known name mis-matches.
    This includes exact matches and prefixes (e.g. "diameter_rx" -> "diameter") */
@@ -685,13 +893,19 @@ void attach_fp_info(packet_info *pinfo, gboolean received, const char *protocol_
     int  tf_start, num_chans_start;
     gint node_type;
 
-    /* Allocate & zero struct */
-    struct fp_info *p_fp_info = se_alloc(sizeof(struct fp_info));
+    /* Only need to set info once per session. */
+    struct fp_info *p_fp_info = p_get_proto_data(pinfo->fd, proto_fp);
+    if (p_fp_info != NULL)
+    {
+        return;
+    }
+
+    /* Allocate struct */
+    p_fp_info = se_alloc0(sizeof(struct fp_info));
     if (!p_fp_info)
     {
         return;
     }
-    memset(p_fp_info, 0, sizeof(struct fp_info));
 
     /* Check that the number of outhdr values looks sensible */
     if (((strcmp(protocol_name, "fpiur_r5") == 0) && (outhdr_values_found != 2)) ||
@@ -784,6 +998,7 @@ void attach_fp_info(packet_info *pinfo, gboolean received, const char *protocol_
     {
         if (p_fp_info->release == 7)
         {
+            /* Entity (MAC-hs or MAC-ehs) used */
             if (outhdr_values[i++])
             {
                 p_fp_info->hsdsch_entity = ehs;
@@ -865,6 +1080,120 @@ void attach_fp_info(packet_info *pinfo, gboolean received, const char *protocol_
 }
 
 
+/* Fill in a MAC LTE packet info struct and attach it to the packet for that
+   dissector to use */
+static void attach_mac_lte_info(packet_info *pinfo)
+{
+    struct mac_lte_info *p_mac_lte_info;
+    unsigned int i=0;
+
+    /* Only need to set info once per session. */
+    p_mac_lte_info = p_get_proto_data(pinfo->fd, proto_mac_lte);
+    if (p_mac_lte_info != NULL)
+    {
+        return;
+    }
+
+    /* Allocate & zero struct */
+    p_mac_lte_info = se_alloc0(sizeof(struct mac_lte_info));
+    if (p_mac_lte_info == NULL)
+    {
+        return;
+    }
+
+    /* Populate the struct from outhdr values */
+    p_mac_lte_info->radioType = outhdr_values[i++];
+    p_mac_lte_info->rntiType = outhdr_values[i++];
+    p_mac_lte_info->direction = outhdr_values[i++];
+    p_mac_lte_info->subframeNumber = outhdr_values[i++];
+    p_mac_lte_info->is_predefined_data = outhdr_values[i++];
+    p_mac_lte_info->rnti = outhdr_values[i++];
+    p_mac_lte_info->ueid = outhdr_values[i++];
+    p_mac_lte_info->length = outhdr_values[i++];
+
+    /* Store info in packet */
+    p_add_proto_data(pinfo->fd, proto_mac_lte, p_mac_lte_info);
+}
+
+
+/* Fill in a RLC LTE packet info struct and attach it to the packet for that
+   dissector to use */
+static void attach_rlc_lte_info(packet_info *pinfo)
+{
+    struct rlc_lte_info *p_rlc_lte_info;
+    unsigned int i=0;
+
+    /* Only need to set info once per session. */
+    p_rlc_lte_info = p_get_proto_data(pinfo->fd, proto_rlc_lte);
+    if (p_rlc_lte_info != NULL)
+    {
+        return;
+    }
+
+    /* Allocate & zero struct */
+    p_rlc_lte_info = se_alloc0(sizeof(struct rlc_lte_info));
+    if (p_rlc_lte_info == NULL)
+    {
+        printf("Failed to allocate rlc_lte struct!\n");
+        return;
+    }
+
+    p_rlc_lte_info->rlcMode = outhdr_values[i++];
+    p_rlc_lte_info->direction = outhdr_values[i++];
+    p_rlc_lte_info->priority = outhdr_values[i++];
+    p_rlc_lte_info->UMSequenceNumberLength = outhdr_values[i++];
+    p_rlc_lte_info->channelId = outhdr_values[i++];
+    p_rlc_lte_info->channelType = outhdr_values[i++];
+    p_rlc_lte_info->ueid = outhdr_values[i++];
+    p_rlc_lte_info->pduLength = outhdr_values[i++];
+
+    /* Store info in packet */
+    p_add_proto_data(pinfo->fd, proto_rlc_lte, p_rlc_lte_info);
+}
+
+/* Fill in a PDCP packet info struct and attach it to the packet for the PDCP
+   dissector to use */
+#if 0
+static void attach_pdcp_info(packet_info *pinfo)
+{
+    struct pdcp_info *p_pdcp_info;
+    unsigned int i=0;
+
+    /* Only need to set info once per session. */
+    p_pdcp_info = p_get_proto_data(pinfo->fd, proto_pdcp);
+    if (p_pdcp_info != NULL)
+    {
+        return;
+    }
+
+    /* Allocate & zero struct */
+    p_pdcp_info = se_alloc0(sizeof(struct pdcp_info));
+    if (p_pdcp_info == NULL)
+    {
+        printf("Failed to allocated pdcp struct!\n");
+        return;
+    }
+
+    p_pdcp_info->no_header_pdu = outhdr_values[i++];
+    p_pdcp_info->plane = outhdr_values[i++];
+    p_pdcp_info->seqnum_length = outhdr_values[i++];
+
+    p_pdcp_info->rohc_compression = outhdr_values[i++];
+    p_pdcp_info->rohc_ip_version = outhdr_values[i++];
+    p_pdcp_info->cid_inclusion_info = outhdr_values[i++];
+    p_pdcp_info->large_cid_present = outhdr_values[i++];
+    p_pdcp_info->mode = outhdr_values[i++];
+    p_pdcp_info->rnd = outhdr_values[i++];
+    p_pdcp_info->udp_checkum_present = outhdr_values[i++];
+    p_pdcp_info->profile = outhdr_values[i++];
+
+    /* Store info in packet */
+    p_add_proto_data(pinfo->fd, proto_pdcp, p_pdcp_info);
+}
+#endif
+
+
+
 /* Attempt to show tty (raw character messages) as text lines. */
 void dissect_tty_lines(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int offset)
 {
@@ -1064,9 +1393,32 @@ dissect_catapult_dct2000(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                        atoi((char*)tvb_get_ephemeral_string(tvb, variant_start, variant_length)));
     }
 
+    /* LTE MAC needs info attached */
+    else if (strcmp(protocol_name, "mac_r8_lte") == 0)
+    {
+        parse_outhdr_string(tvb_get_ephemeral_string(tvb, outhdr_start, outhdr_length));
+        attach_mac_lte_info(pinfo);
+    }
+
+    /* LTE RLC needs info attached */
+    else if (strcmp(protocol_name, "rlc_r8_lte") == 0)
+    {
+        parse_outhdr_string(tvb_get_ephemeral_string(tvb, outhdr_start, outhdr_length));
+        attach_rlc_lte_info(pinfo);
+    }
+
+#if 0
+    /* LTE PDCP needs info attached */
+    else if (strcmp(protocol_name, "pdcp_r8_lte") == 0)
+    {
+        parse_outhdr_string(tvb_get_ephemeral_string(tvb, outhdr_start, outhdr_length));
+        attach_pdcp_info(pinfo);
+    }
+#endif
+
 
     /* Note that the first item of pinfo->pseudo_header->dct2000 will contain
-       the pseudo-header needed (in some cases) by the wireshark dissector that
+       the pseudo-header needed (in some cases) by the Wireshark dissector that
        this packet data will be handed off to. */
 
 
@@ -1157,6 +1509,40 @@ dissect_catapult_dct2000(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
                 protocol_handle = find_dissector("sipprim");
             }
 
+            else
+            if (strcmp(protocol_name, "mac_r8_lte") == 0)
+            {
+                protocol_handle = find_dissector("mac-lte");
+            }
+
+            else
+            if (strcmp(protocol_name, "rlc_r8_lte") == 0)
+            {
+                protocol_handle = find_dissector("rlc-lte");
+            }
+
+#if 0
+            else
+            if (strcmp(protocol_name, "pdcp_r8_lte") == 0)
+            {
+                /* Send to intermediate dissector to parse/strip
+                   proprietary RLC primitive header before passing to actual
+                   PDCP dissector */
+                protocol_handle = find_dissector("pdcp_r8");
+            }
+#endif
+
+            else
+            if ((strcmp(protocol_name, "rrc_r8_lte") == 0) ||
+                (strcmp(protocol_name, "rrcpdcpprim_r8_lte") == 0))
+                /* Dissect proprietary header, then pass remainder
+                   to RRC (depending upon direction and channel type) */
+            {
+                dissect_rrc_lte(tvb, offset, pinfo, tree);
+                return;
+            }
+
+
             /* Many DCT2000 protocols have at least one IPPrim variant. If the
                protocol name can be matched to a dissector, try to find the
                UDP/TCP data inside and dissect it.
@@ -1709,6 +2095,38 @@ void proto_register_catapult_dct2000(void)
               "tty line", HFILL
             }
         },
+
+        { &hf_catapult_dct2000_lte_ueid,
+            { "UE Id",
+              "dct2000.lte.ueid", FT_UINT16, BASE_DEC, NULL, 0x0,
+              "User Equipment Identifier", HFILL
+            }
+        },
+        { &hf_catapult_dct2000_lte_srbid,
+            { "srbid",
+              "dct2000.lte.srbid", FT_UINT8, BASE_DEC, NULL, 0x0,
+              "Signalling Radio Bearer Identifier", HFILL
+            }
+        },
+        { &hf_catapult_dct2000_lte_drbid,
+            { "drbid",
+              "dct2000.lte.drbid", FT_UINT8, BASE_DEC, NULL, 0x0,
+              "Data Radio Bearer Identifier", HFILL
+            }
+        },
+        { &hf_catapult_dct2000_lte_cellid,
+            { "Cell-Id",
+              "dct2000.lte.cellid", FT_UINT16, BASE_DEC, NULL, 0x0,
+              "Cell Identifier", HFILL
+            }
+        },
+        { &hf_catapult_dct2000_lte_bcch_transport,
+            { "BCCH Transport",
+              "dct2000.lte.bcch-transport", FT_UINT16, BASE_DEC, VALS(bcch_transport_vals), 0x0,
+              "BCCH Transport Channel", HFILL
+            }
+        },
+
     };
 
     static gint *ett[] =
@@ -1740,22 +2158,22 @@ void proto_register_catapult_dct2000(void)
 
     /* Determines whether for not-handled protocols we should try to parse it if:
        - it looks like its embedded in an ipprim message, AND
-       - the DCT2000 protocol name can be matched to a wireshark dissector name */
+       - the DCT2000 protocol name can be matched to a Wireshark dissector name */
     prefs_register_bool_preference(catapult_dct2000_module, "ipprim_heuristic",
                                    "Use IP Primitive heuristic",
                                    "If a payload looks like its embedded in an "
-                                   "IP primitive message, and there is a wireshark "
+                                   "IP primitive message, and there is a Wireshark "
                                    "dissector matching the DCT2000 protocol name, "
                                    "try parsing the payload using that dissector",
                                    &catapult_dct2000_try_ipprim_heuristic);
 
     /* Determines whether for not-handled protocols we should try to parse it if:
        - it looks like its embedded in an sctpprim message, AND
-       - the DCT2000 protocol name can be matched to a wireshark dissector name */
+       - the DCT2000 protocol name can be matched to a Wireshark dissector name */
     prefs_register_bool_preference(catapult_dct2000_module, "sctpprim_heuristic",
                                    "Use SCTP Primitive heuristic",
                                    "If a payload looks like its embedded in an "
-                                   "SCTP primitive message, and there is a wireshark "
+                                   "SCTP primitive message, and there is a Wireshark "
                                    "dissector matching the DCT2000 protocol name, "
                                    "try parsing the payload using that dissector",
                                    &catapult_dct2000_try_sctpprim_heuristic);
