@@ -2,7 +2,7 @@
  * Routines for the disassembly of the "Cisco Discovery Protocol"
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-cdp.c 25601 2008-06-25 09:12:35Z guy $
+ * $Id: packet-cdp.c 27171 2009-01-06 19:58:42Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -191,10 +191,41 @@ dissect_cdp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     packet_checksum = tvb_get_ntohs(tvb, offset);
     
     data_length = tvb_reported_length(tvb);
-    
-    cksum_vec[0].ptr = tvb_get_ptr(tvb, 0, data_length);
-    cksum_vec[0].len = data_length;
-    
+
+    /* CDP doesn't adhere to RFC 1071 section 2. (B). It incorrectly assumes
+     * checksums are calculated on a big endian platform, therefore i.s.o.
+     * padding odd sized data with a zero byte _at the end_ it sets the last
+     * big endian _word_ to contain the last network _octet_. This byteswap
+     * has to be done on the last octet of network data before feeding it to
+     * the Internet checksum routine.
+     * CDP checksumming code has a bug in the addition of this last _word_
+     * as a signed number into the long word intermediate checksum. When
+     * reducing this long to word size checksum an off-by-one error can be
+     * made. This off-by-one error is compensated for in the last _word_ of
+     * the network data.
+     */
+    if (data_length & 1) {
+        guint8 *padded_buffer;
+        /* Allocate new buffer */
+        padded_buffer = ep_alloc(data_length+1);
+        tvb_memcpy(tvb, padded_buffer, 0, data_length);
+        /* Swap bytes in last word */
+        padded_buffer[data_length] = padded_buffer[data_length-1];
+        padded_buffer[data_length-1] = 0;
+        /* Compensate off-by-one error */
+        if (padded_buffer[data_length] & 0x80) {
+          padded_buffer[data_length]--;
+          padded_buffer[data_length-1]--;
+        }
+        /* Setup checksum routine data buffer */
+        cksum_vec[0].ptr = padded_buffer;
+        cksum_vec[0].len = data_length+1;
+    } else {
+        /* Setup checksum routine data buffer */
+        cksum_vec[0].ptr = tvb_get_ptr(tvb, 0, data_length);
+        cksum_vec[0].len = data_length;
+    }
+
     computed_checksum = in_cksum(cksum_vec, 1);
     checksum_good = (computed_checksum == 0);
     checksum_bad = !checksum_good;
@@ -999,31 +1030,31 @@ dissect_capabilities(tvbuff_t *tvb, int offset, int length, proto_tree *tree)
     ti = proto_tree_add_text(tree, tvb, offset, length, "Capabilities: 0x%08x",
         capabilities);
     capabilities_tree = proto_item_add_subtree(ti, ett_cdp_capabilities);
-    proto_tree_add_text(capabilities_tree, tvb, offset, 4,
+    proto_tree_add_text(capabilities_tree, tvb, offset, 4, "%s",
 	decode_boolean_bitfield(capabilities, 0x01, 4*8,
 	    "Is  a Router",
 	    "Not a Router"));
-    proto_tree_add_text(capabilities_tree, tvb, offset, 4,
+    proto_tree_add_text(capabilities_tree, tvb, offset, 4, "%s",
 	decode_boolean_bitfield(capabilities, 0x02, 4*8,
 	    "Is  a Transparent Bridge",
 	    "Not a Transparent Bridge"));
-    proto_tree_add_text(capabilities_tree, tvb, offset, 4,
+    proto_tree_add_text(capabilities_tree, tvb, offset, 4, "%s",
 	decode_boolean_bitfield(capabilities, 0x04, 4*8,
 	    "Is  a Source Route Bridge",
 	    "Not a Source Route Bridge"));
-    proto_tree_add_text(capabilities_tree, tvb, offset, 4,
+    proto_tree_add_text(capabilities_tree, tvb, offset, 4, "%s",
 	decode_boolean_bitfield(capabilities, 0x08, 4*8,
 	    "Is  a Switch",
 	    "Not a Switch"));
-    proto_tree_add_text(capabilities_tree, tvb, offset, 4,
+    proto_tree_add_text(capabilities_tree, tvb, offset, 4, "%s",
 	decode_boolean_bitfield(capabilities, 0x10, 4*8,
 	    "Is  a Host",
 	    "Not a Host"));
-    proto_tree_add_text(capabilities_tree, tvb, offset, 4,
+    proto_tree_add_text(capabilities_tree, tvb, offset, 4, "%s",
 	decode_boolean_bitfield(capabilities, 0x20, 4*8,
 	    "Is  IGMP capable",
 	    "Not IGMP capable"));
-    proto_tree_add_text(capabilities_tree, tvb, offset, 4,
+    proto_tree_add_text(capabilities_tree, tvb, offset, 4, "%s",
 	decode_boolean_bitfield(capabilities, 0x40, 4*8,
 	    "Is  a Repeater",
 	    "Not a Repeater"));
