@@ -6,7 +6,7 @@
  * Copyright 2003-2005 Fred Hoekstra, Philips Medical Systems.
  *                (fred.hoekstra@philips.com)
  *
- * $Id: packet-dec-dnart.c 25618 2008-06-27 16:15:30Z wmeier $
+ * $Id: packet-dec-dnart.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Use was made of the following documentation:
  * (See URL http://linux-decnet.sourceforge.net/docs).
@@ -261,7 +261,7 @@ static const value_string rt_disc_reason_vals[] = {
     { 0,    "no error"},
     { 3,    "The node is shutting down"},
     { 4,    "The destination end user does not exist"},
-    { 5,    "A conect message contains an invalid end user name"},
+    { 5,    "A connect message contains an invalid end user name"},
     { 6,    "Destination end user has insufficient resources"},
     { 7,    "Unspecified error"},
     { 8,    "A third party has disconnected the link"},
