@@ -6,7 +6,7 @@
  * SHIRASAKI Yasuhiro <yasuhiro@gnome.gr.jp>
  * Tony Lindstrom <tony.lindstrom@ericsson.com>
  *
- * $Id: packet-dhcpv6.c 25618 2008-06-27 16:15:30Z wmeier $
+ * $Id: packet-dhcpv6.c 27045 2008-12-18 08:17:27Z jmayer $
  *
  * The information used comes from:
  * RFC3315.txt (DHCPv6)
@@ -14,9 +14,9 @@
  * RFC3633.txt (Prefix options)
  * RFC3646.txt (DNS servers/domains)
  * RFC3898.txt (NIS options)
+ * RFC4704.txt (Client FQDN)
  * RFC5007.txt (DHCPv6 Leasequery)
  * draft-ietf-dhc-dhcpv6-opt-timeconfig-03.txt
- * draft-ietf-dhc-dhcpv6-opt-fqdn-00.txt
  * draft-ietf-dhc-dhcpv6-opt-lifetime-00.txt
  *
  * Note that protocol constants are still subject to change, based on IANA
@@ -48,6 +48,7 @@
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
+#include <epan/sminmpec.h>
 #include "packet-arp.h"
 
 static int proto_dhcpv6 = -1;
@@ -259,6 +260,17 @@ static const true_false_string fqdn_s = {
     "S bit set", "S bit cleared"
 }; 
 
+static void
+dhcpv6_enterprise_number(proto_tree * subtree, tvbuff_t *tvb, int offset)
+{
+	  guint32 enterprise_number;
+	  enterprise_number = tvb_get_ntohl(tvb, offset);
+	  proto_tree_add_text(subtree, tvb, offset, 4,
+			      "Enterprise-number: %s (%u)",
+			      val_to_str(enterprise_number, sminmpec_values, "%u"),
+			      enterprise_number);
+}
+
 /* Adds domain */
 static void
 dhcpv6_domain(proto_tree * subtree, tvbuff_t *tvb, int offset, guint16 optlen)
@@ -278,9 +290,16 @@ dhcpv6_domain(proto_tree * subtree, tvbuff_t *tvb, int offset, guint16 optlen)
 
         /* read length of the next substring */
         len = tvb_get_guint8(tvb, offset);
+	/* Microsoft dhcpv6 clients aren't currently RFC 4704 conform: They send an
+	 * ASCII string instead of a DNS record encoded domain name. Catch that case
+	 * to allow us to continue after such a malformed record.
+	 */
+	if ( optlen < len ) {
+                proto_tree_add_text(subtree, tvb, start_offset, optlen, "Malformed DNS name record (MS Vista client?)");
+		return;
+	}
         offset++;
         optlen--;
-
         /* if len==0 and pos>0 we have read an entire domain string */
         if(!len){
             if(!pos){
@@ -380,8 +399,7 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 			}
 			hwtype=tvb_get_ntohs(tvb, off + 2);
 			proto_tree_add_text(subtree, tvb, off + 2, 2,
-				"Hardware type: %s (%u)",
-				arphrdtype_to_str(hwtype, "Unknown"),
+				"Hardware type: %s (%u)", arphrdtype_to_str(hwtype, "Unknown"),
 				hwtype);
 			/* XXX seconds since Jan 1 2000 */
 			proto_tree_add_text(subtree, tvb, off + 4, 4,
@@ -398,11 +416,11 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 					optlen, "DUID: malformed option");
 				break;
 			}
-			proto_tree_add_text(subtree, tvb, off + 2, 4,
-					    "enterprise-number");
+			dhcpv6_enterprise_number(subtree, tvb, off + 2);
 			if (optlen > 6) {
+	      			buf = tvb_bytes_to_str(tvb, off + 6, optlen - 6);
 				proto_tree_add_text(subtree, tvb, off + 6,
-					optlen - 6, "identifier");
+					optlen - 6, "identifier: %s", buf);
 			}
 			break;
 		case DUID_LL:
@@ -626,12 +644,11 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 				optlen, "VENDOR_CLASS: malformed option");
 	    break;
 	  }
-	  proto_tree_add_text(subtree, tvb, off, 4,
-			      "enterprise-number: %u",
-			      tvb_get_ntohl(tvb, off));
+	  dhcpv6_enterprise_number(subtree, tvb, off);
 	  if (optlen > 4) {
+	    buf = tvb_bytes_to_str(tvb, off + 4, optlen - 4);
 	    proto_tree_add_text(subtree, tvb, off+4, optlen-4,
-				"vendor-class-data");
+				"vendor-class-data: %s", buf);
 	  }
 	  break;
 	case OPTION_VENDOR_OPTS:
@@ -641,9 +658,7 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 	    break;
 	  }
 
-	  proto_tree_add_text(subtree, tvb, off, 4,
-			      "enterprise-number: %u",
-			      tvb_get_ntohl(tvb, off));
+	  dhcpv6_enterprise_number(subtree, tvb, off);
 	  if (optlen >= 4)
 	  {
             int optoffset = 0;
@@ -667,7 +682,8 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 				optlen, "INTERFACE_ID: malformed option");
 	    break;
 	  }
-	  proto_tree_add_text(subtree, tvb, off, optlen, "Interface-ID");
+	  buf = tvb_get_ephemeral_string(tvb, off, optlen);
+	  proto_tree_add_text(subtree, tvb, off, optlen, "Interface-ID: %s", buf);
 	  break;
 	case OPTION_RECONF_MSG:
 	  if (optlen != 1) {
@@ -807,7 +823,11 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 				optlen, "REMOTE_ID: malformed option");
 	    break;
 	  }
-	  proto_tree_add_text(subtree, tvb, off, optlen, "Remote-ID");
+	  dhcpv6_enterprise_number(subtree, tvb, off);
+	  off += 4;
+	  optlen -= 4;
+	  buf = tvb_bytes_to_str(tvb, off, optlen);
+	  proto_tree_add_text(subtree, tvb, off, optlen, "Remote-ID: %s", buf);
 	  break;
 	case OPTION_SUBSCRIBER_ID:
 	  if (optlen == 0) {
@@ -815,7 +835,8 @@ dhcpv6_option(tvbuff_t *tvb, packet_info *pinfo, proto_tree *bp_tree,
 				optlen, "SUBSCRIBER_ID: malformed option");
 	    break;
 	  }
-	  proto_tree_add_text(subtree, tvb, off, optlen, "Subscriber-ID");
+	  buf = tvb_get_ephemeral_string(tvb, off, optlen);
+	  proto_tree_add_text(subtree, tvb, off, optlen, "Subscriber-ID: %s", buf);
 	  break;
 	case OPTION_CLIENT_FQDN:
 	  if (optlen < 1) {
