@@ -2,7 +2,7 @@
  * Routines for dissecting 3GPP OctetSting AVP:s
  * Copyright 2008, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id: packet-diameter_3gpp.c 25465 2008-06-17 17:10:51Z gerald $
+ * $Id: packet-diameter_3gpp.c 25915 2008-08-04 16:11:17Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -41,7 +41,7 @@
 #include <epan/packet.h>
 #include <epan/proto.h>
 
-#include "packet-gsm_a.h"
+#include "packet-gsm_a_common.h"
 #include "packet-e212.h"
 
 /* Initialize the protocol and registered fields */
