@@ -3,7 +3,7 @@
  * Copyright (c) 2006, Authesserre Samuel <sauthess@gmail.com>
  * Copyright (c) 2007, Mikael Magnusson <mikma@users.sourceforge.net>
  *
- * $Id: packet-dtls.c 26207 2008-09-15 19:49:43Z jake $
+ * $Id: packet-dtls.c 27062 2008-12-19 17:39:52Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -58,6 +58,10 @@
 #include <sys/socket.h>
 #endif
 
+#ifdef HAVE_WINSOCK2_H
+#include <winsock2.h>
+#endif
+
 #include <glib.h>
 
 #include <epan/conversation.h>
@@ -232,8 +236,8 @@ dtls_parse(void)
 
   ssl_set_debug(dtls_debug_file_name);
 
-  /* [re] add dtls dissection to default port in openssl 0.9.8b implementation */
-  ssl_association_add(dtls_associations, dtls_handle, 4433, "http", FALSE,FALSE);
+  dissector_add_handle("sctp.port", dtls_handle);
+  dissector_add_handle("udp.port", dtls_handle);
 }
 
 /*
@@ -386,7 +390,7 @@ dissect_dtls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   conv_version= & ssl_session->version;
 
   /* try decryption only the first time we see this packet
-   * (to keep cipher syncronized)and only if we have
+   * (to keep cipher synchronized)and only if we have
    * the server private key*/
   if (!ssl_session->private_key || pinfo->fd->flags.visited)
     ssl_session = NULL;
@@ -1179,7 +1183,7 @@ dissect_dtls_handshake(tvbuff_t *tvb, packet_info *pinfo,
 	    break;
 
 	  case SSL_HND_CERT_REQUEST:
-	    dissect_dtls_hnd_cert_req(sub_tvb, ssl_hand_tree, offset);
+	    dissect_dtls_hnd_cert_req(sub_tvb, ssl_hand_tree, 0);
 	    break;
 
 	  case SSL_HND_SVR_HELLO_DONE:
@@ -1233,7 +1237,7 @@ dissect_dtls_handshake(tvbuff_t *tvb, packet_info *pinfo,
 	      }
 	      ssl->state |= SSL_HAVE_SESSION_KEY;
 	      ssl_save_session(ssl, dtls_session_hash);
-	      ssl_debug_printf("dissect_dtls_handshake session keys succesfully generated\n");
+	      ssl_debug_printf("dissect_dtls_handshake session keys successfully generated\n");
 	    }
 	    break;
 
