@@ -3,7 +3,7 @@
  * to many dissectors.
  * Copyright 2006, Anders Broman <anders.broman@ericsson.com>
  *
- * $Id: packet-e212.c 26091 2008-08-26 01:28:50Z wmeier $
+ * $Id: packet-e212.c 27117 2008-12-26 21:19:13Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -296,11 +296,11 @@ dissect_e212_mcc_mnc(tvbuff_t *tvb, proto_tree *tree, int offset){
 	octet = tvb_get_guint8(tvb,offset);
 	mcc3 = octet & 0x0f;
 	/* MNC, Mobile network code (octet 3 bits 5 to 8, octet 4)  */
-	mnc3 = octet >> 4;
+	mnc1 = octet >> 4;
 	offset++;
 	octet = tvb_get_guint8(tvb,offset);
-	mnc1 = octet & 0x0f;
-	mnc2 = octet >> 4;
+	mnc2 = octet & 0x0f;
+	mnc3 = octet >> 4;
 
 	mcc = 100 * mcc1 + 10 * mcc2 + mcc3;
 	mnc = 10 * mnc1 + mnc2;
@@ -349,7 +349,7 @@ proto_register_e212(void)
 	proto_e212 = proto_register_protocol(
 			"ITU-T E.212 number",
 			"E.212",
-			"e.212");
+			"e212");
 
 	/*
 	 * Required function calls to register
