@@ -1,7 +1,7 @@
 /* packet-eth.c
  * Routines for ethernet packet disassembly
  *
- * $Id: packet-eth.c 25723 2008-07-12 17:37:22Z guy $
+ * $Id: packet-eth.c 26308 2008-09-30 14:49:44Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -559,8 +559,7 @@ proto_reg_handoff_eth(void)
 	 */
 	fw1_handle = find_dissector("fw1");
 
-	eth_maybefcs_handle = create_dissector_handle(dissect_eth_maybefcs,
-	    proto_eth);
+	eth_maybefcs_handle = find_dissector("eth");
 	dissector_add("wtap_encap", WTAP_ENCAP_ETHERNET, eth_maybefcs_handle);
 
 	eth_withoutfcs_handle = find_dissector("eth_withoutfcs");
