@@ -2,7 +2,7 @@
  *
  * Top-most dissector. Decides dissector based on Wiretap Encapsulation Type.
  *
- * $Id: packet-frame.c 25339 2008-05-21 14:18:37Z morriss $
+ * $Id: packet-frame.c 27176 2009-01-07 07:21:31Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,6 +27,11 @@
 # include "config.h"
 #endif
 
+#ifdef _MSC_VER
+#include <windows.h>
+#endif
+
+
 #include <glib.h>
 #include <epan/packet.h>
 #include <epan/timestamp.h>
@@ -35,6 +40,7 @@
 #include <epan/prefs.h>
 #include <epan/tap.h>
 #include <epan/expert.h>
+#include <epan/crypt/crypt-md5.h>
 
 #include "color.h"
 #include "color_filters.h"
@@ -51,6 +57,7 @@ int hf_frame_len = -1;
 int hf_frame_capture_len = -1;
 static int hf_frame_p2p_dir = -1;
 static int hf_frame_file_off = -1;
+static int hf_frame_md5_hash = -1;
 static int hf_frame_marked = -1;
 static int hf_frame_ref_time = -1;
 static int hf_link_number = -1;
@@ -72,6 +79,7 @@ static dissector_handle_t docsis_handle;
 /* Preferences */
 static gboolean show_file_off = FALSE;
 static gboolean force_docsis_encap;
+static gboolean generate_md5_hash = FALSE;
 
 static const value_string p2p_dirs[] = {
 	{ P2P_DIR_SENT,	"Sent" },
@@ -116,7 +124,7 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 
 	frame_number=pinfo->fd->num; /* dummy so that the buildbot crashdumps
 					will show the packetnumber where the
-					crash occured.
+					crash occurred.
 				     */
 	tree=parent_tree;
 
@@ -165,6 +173,11 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 			pinfo->annex_a_used = pinfo->pseudo_header->mtp2.annex_a_used;
 			break;
 
+		case WTAP_ENCAP_GSM_UM:
+			pinfo->p2p_dir = pinfo->pseudo_header->gsm_um.uplink ?
+			    P2P_DIR_SENT : P2P_DIR_RECV;
+			break;
+
 		}
 	}
 
@@ -245,6 +258,23 @@ dissect_frame(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	   */
 	  proto_tree_set_visible(fh_tree, TRUE);
 
+	  if (generate_md5_hash) {
+		  const guint8 *cp;
+		  md5_state_t md_ctx;
+		  md5_byte_t digest[16];
+		  gchar *digest_string;
+
+		  cp = tvb_get_ptr(tvb, 0, cap_len);
+
+		  md5_init(&md_ctx);
+		  md5_append(&md_ctx, cp, cap_len);
+		  md5_finish(&md_ctx, digest);
+
+		  digest_string = bytestring_to_str(digest, 16, '\0');
+		  ti = proto_tree_add_string(fh_tree, hf_frame_md5_hash, tvb, 0, 0, digest_string);
+		  PROTO_ITEM_SET_GENERATED(ti);
+	  }
+
 	  if(pinfo->fd->flags.ref_time){
 		ti = proto_tree_add_item(fh_tree, hf_frame_ref_time, tvb, 0, 0, FALSE);
 	    PROTO_ITEM_SET_GENERATED(ti);
@@ -492,14 +522,14 @@ show_reported_bounds_error(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		item = proto_tree_add_protocol_format(tree, proto_unreassembled,
 		    tvb, 0, 0, "[Unreassembled Packet%s: %s]",
 		    pinfo->noreassembly_reason, pinfo->current_proto);
-		expert_add_info_format(pinfo, item, PI_REASSEMBLE, PI_WARN, "Unreassembled Packet (Exception occured)");
+		expert_add_info_format(pinfo, item, PI_REASSEMBLE, PI_WARN, "Unreassembled Packet (Exception occurred)");
 	} else {
 		if (check_col(pinfo->cinfo, COL_INFO))
 			col_append_str(pinfo->cinfo, COL_INFO,
 			    "[Malformed Packet]");
 		item = proto_tree_add_protocol_format(tree, proto_malformed,
 		    tvb, 0, 0, "[Malformed Packet: %s]", pinfo->current_proto);
-		expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR, "Malformed Packet (Exception occured)");
+		expert_add_info_format(pinfo, item, PI_MALFORMED, PI_ERROR, "Malformed Packet (Exception occurred)");
 	}
 }
 
@@ -547,6 +577,10 @@ proto_register_frame(void)
 		{ "Frame length stored into the capture file",	"frame.cap_len", FT_UINT32, BASE_DEC, NULL, 0x0,
 			"", HFILL }},
 
+		{ &hf_frame_md5_hash,
+		{ "Frame MD5 Hash",	"frame.md5_hash", FT_STRING, 0, NULL, 0x0,
+			NULL, HFILL }},
+
 		{ &hf_frame_p2p_dir,
 		{ "Point-to-Point Direction",	"frame.p2p_dir", FT_UINT8, BASE_DEC, VALS(p2p_dirs), 0x0,
 			"", HFILL }},
@@ -615,6 +649,10 @@ proto_register_frame(void)
 	    "Show File Offset", "Show File Offset", &show_file_off);
 	prefs_register_bool_preference(frame_module, "force_docsis_encap",
 	    "Treat all frames as DOCSIS frames", "Treat all frames as DOCSIS Frames", &force_docsis_encap);
+	prefs_register_bool_preference(frame_module, "generate_md5_hash",
+	    "Generate an MD5 hash of each frame",
+	    "Whether or not MD5 hashes should be generated for each frame, useful for finding duplicate frames.",
+	    &generate_md5_hash);
 
 	frame_tap=register_tap("frame");
 }
