@@ -2,9 +2,9 @@
  *  packet-h248_3gpp.c
  *  3GPP H.248 Packages
  *
- *  (c) 2006, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ *  (c) 2006, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-h248_3gpp.c 21773 2007-05-15 05:49:43Z etxrab $
+ * $Id: packet-h248_3gpp.c 25937 2008-08-05 21:03:46Z lego $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -295,7 +295,7 @@ static void dissect_3GTFO_codec_mode(proto_tree* tree, tvbuff_t* tvb, packet_inf
 		dissect_ber_octet_string(FALSE, &asn1_ctx, tree, tvb, 0, hfid, &sub_tvb );
 		
 		if (sub_tvb) {
-			proto_tree* pt = proto_item_add_subtree(get_ber_last_created_item(),ett_h248_3GTFO_codec);
+			proto_tree* pt = proto_item_add_subtree(asn1_ctx.created_item, ett_h248_3GTFO_codec);
 			dissect_codec_mode(pt, sub_tvb, 0, tvb_length(tvb));
 		}
 	} else {
@@ -319,7 +319,7 @@ static void dissect_3GTFO_codec_list(proto_tree* tree, tvbuff_t* tvb, packet_inf
 		dissect_ber_octet_string(FALSE, &asn1_ctx, tree, tvb, 0, hfid, &sub_tvb );
 		
 		if (sub_tvb) {
-			proto_tree* pt = proto_item_add_subtree(get_ber_last_created_item(),ett_h248_3GTFO_codec_list);
+			proto_tree* pt = proto_item_add_subtree(asn1_ctx.created_item,ett_h248_3GTFO_codec_list);
 			int len = tvb_length(sub_tvb);
 			int offset = 0;
 			do {
