@@ -2,7 +2,7 @@
  * Routines for H.264 dissection
  * Copyright 2007, Anders Broman <anders.broman[at]ericsson.com>
  *
- * $Id: packet-h264.c 26251 2008-09-23 00:45:05Z wmeier $
+ * $Id: packet-h264.c 26969 2008-12-11 20:35:19Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -50,6 +50,9 @@ static int proto_h264								= -1;
 static int hf_h264_type								= -1;
 static int hf_h264_nal_f_bit						= -1;
 static int hf_h264_nal_nri							= -1;
+static int hf_h264_start_bit						= -1;
+static int hf_h264_forbidden_bit					= -1;
+static int hf_h264_end_bit							= -1;
 static int hf_h264_profile							= -1;
 static int hf_h264_profile_idc						= -1;
 static int hf_h264_rbsp_stop_bit					= -1;
@@ -77,7 +80,7 @@ static int hf_h264_log2_max_pic_order_cnt_lsb_minus4 = -1;
 static int hf_h264_delta_pic_order_always_zero_flag = -1;
 static int hf_h264_offset_for_non_ref_pic			= -1;
 static int hf_h264_offset_for_top_to_bottom_field	= -1;
-static int hf_264_num_ref_frames_in_pic_order_cnt_cycle = -1;
+static int hf_h264_num_ref_frames_in_pic_order_cnt_cycle = -1;
 static int hf_h264_offset_for_ref_frame				= -1;
 static int hf_h264_num_ref_frames					= -1;
 static int hf_h264_gaps_in_frame_num_value_allowed_flag = -1;
@@ -179,6 +182,7 @@ static int hf_h264_frame_num						= -1;
 static int ett_h264 = -1;
 static int ett_h264_profile = -1;
 static int ett_h264_nal = -1;
+static int ett_h264_fua = -1;
 static int ett_h264_stream = -1;
 static int ett_h264_nal_unit = -1;
 static int ett_h264_par_profile = -1;
@@ -204,6 +208,18 @@ static const true_false_string h264_f_bit_vals = {
   "Bit errors or other syntax violations",
   "No bit errors or other syntax violations"
 };
+static const true_false_string h264_start_bit_vals = {
+  "the first packet of FU-A picture",
+  "Not the first packet of FU-A picture"
+};
+static const true_false_string h264_end_bit_vals = {
+  "the last packet of FU-A picture",
+  "Not the last packet of FU-A picture"
+};
+static const true_false_string h264_forbidden_bit_vals = {
+  "Forbidden Bit of FU-A",
+  "Not Forbidden Bit of FU-A"
+};
 
 #define H264_SEQ_PAR_SET		7
 #define H264_PIC_PAR_SET		8
@@ -256,6 +272,25 @@ static const value_string h264_profile_idc_values[] = {
 	{ 0,	NULL }
 };
 
+static const value_string h264_level_bitrate_values[] = {
+	{ 10,	"64kb/s" },
+	{ 11,	"192kb/s" },
+	{ 12,	"384kb/s" },
+	{ 13,	"2 Mb/s" }, 
+	{ 20,	"2 Mb/s" },
+	{ 21,	"4 Mb/s" },
+	{ 22,	"4 Mb/s" },
+	{ 30,	"10 Mb/s" },
+	{ 31,	"14 Mb/s" },
+	{ 32,	"20 Mb/s" },
+	{ 40,	"20 Mb/s" },
+	{ 41,	"50 Mb/s" },
+	{ 42,	"50 Mb/s" },
+	{ 50,	"135 Mb/s" },
+	{ 51,	"240 Mb/s" },	
+	{ 0,	NULL }
+};
+
 static const value_string h264_nal_unit_type_vals[] = {
 	{ 0,	"Unspecified" },
 	{ 1,	"Coded slice of a non-IDR picture" },
@@ -285,7 +320,7 @@ static const value_string h264_nal_unit_type_vals[] = {
 	{ 25,	"Unspecified" },
 	{ 26,	"Unspecified" },
 	{ 27,	"Unspecified" },
-	{ 28,	"Unspecified" },
+	{ 28,	"FU-A" },
 	{ 29,	"Unspecified" },
 	{ 30,	"Unspecified" },
 	{ 31,	"Unspecified" },
@@ -312,7 +347,7 @@ static const value_string h264_slice_type_vals[] = {
 	{ 4,	"SI (SI slice)" },
 	{ 5,	"P (P slice)" },
 	{ 6,	"B (B slice)" },
-	{ 7 ,	"I (I slice)" },
+	{ 7,	"I (I slice)" },
 	{ 8,	"SP (SP slice)" },
 	{ 9,	"SI (SI slice)" },
 	{ 0,	NULL }
@@ -464,7 +499,10 @@ dissect_h264_exp_golomb_code(proto_tree *tree, int hf_index, tvbuff_t *tvb, gint
 	codenum = 1;
 	codenum = codenum << leading_zero_bits;
 	mask = codenum>>1;
-	value = tvb_get_bits8(tvb, bit_offset,leading_zero_bits );
+	if (leading_zero_bits > 8)
+		value = tvb_get_bits16(tvb, bit_offset,leading_zero_bits, FALSE);
+	else
+		value = tvb_get_bits8(tvb, bit_offset,leading_zero_bits );
 	codenum = (codenum-1) + value; 
 	bit_offset = bit_offset + leading_zero_bits;
 
@@ -628,17 +666,17 @@ more_rbsp_data(proto_tree *tree _U_, tvbuff_t *tvb, packet_info *pinfo _U_, gint
 static int
 dissect_h264_rbsp_trailing_bits(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo _U_, gint bit_offset)
 {
-	gint remaining_bits;
+	gint remaining_bits=0;
 
 	proto_tree_add_bits_item(tree, hf_h264_rbsp_stop_bit, tvb, bit_offset, 1, FALSE);
 	bit_offset++;
 
-	remaining_bits = 8 - (bit_offset&0x7);
-
-	proto_tree_add_bits_item(tree, hf_h264_rbsp_trailing_bits, tvb, bit_offset, remaining_bits, FALSE);
+	if((bit_offset&0x7)!=0){
+		remaining_bits = 8 - (bit_offset&0x7);
+		proto_tree_add_bits_item(tree, hf_h264_rbsp_trailing_bits, tvb, bit_offset, remaining_bits, FALSE);
+	}
 
 	return bit_offset+remaining_bits;
-
 }
 
 /*
@@ -659,8 +697,12 @@ dissect_h264_slice_header(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo _U
 	dissect_h264_exp_golomb_code(tree, hf_h264_pic_parameter_set_id, tvb, &bit_offset, H264_UE_V);
 	
 	/* frame_num 2 u(v) */
-	/* XXXX Is frame_num allways 4 bits in the bit stream? */
-	proto_tree_add_bits_item(tree, hf_h264_frame_num, tvb, bit_offset, 4, FALSE);
+	/*  
+	 * represented by log2_max_frame_num_minus4 + 4 bits in
+	 * the bitstream
+	 * proto_tree_add_bits_item(tree, hf_h264_frame_num, tvb, bit_offset, 4, FALSE);
+	 */
+	
 
 	return bit_offset;
 }
@@ -724,19 +766,19 @@ dissect_h264_hrd_parameters(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo
 		bit_offset++;
 	}
 	/* initial_cpb_removal_delay_length_minus1 0 u(5) */
-	proto_tree_add_bits_item(tree, hf_h264_initial_cpb_removal_delay_length_minus1, tvb, bit_offset, 1, FALSE);
+	proto_tree_add_bits_item(tree, hf_h264_initial_cpb_removal_delay_length_minus1, tvb, bit_offset, 5, FALSE);
 	bit_offset = bit_offset + 5;
 
 	/* cpb_removal_delay_length_minus1 0 u(5) */
-	proto_tree_add_bits_item(tree, hf_h264_cpb_removal_delay_length_minus1, tvb, bit_offset, 1, FALSE);
+	proto_tree_add_bits_item(tree, hf_h264_cpb_removal_delay_length_minus1, tvb, bit_offset, 5, FALSE);
 	bit_offset = bit_offset + 5;
 
 	/* dpb_output_delay_length_minus1 0 u(5) */
-	proto_tree_add_bits_item(tree, hf_h264_dpb_output_delay_length_minus11, tvb, bit_offset, 1, FALSE);
+	proto_tree_add_bits_item(tree, hf_h264_dpb_output_delay_length_minus11, tvb, bit_offset, 5, FALSE);
 	bit_offset = bit_offset + 5;
 
 	/* time_offset_length 0 u(5) */
-	proto_tree_add_bits_item(tree, hf_h264_time_offset_length, tvb, bit_offset, 1, FALSE);
+	proto_tree_add_bits_item(tree, hf_h264_time_offset_length, tvb, bit_offset, 5, FALSE);
 	bit_offset = bit_offset + 5;
 
 	return bit_offset;
@@ -948,9 +990,9 @@ dissect_h264_profile(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 	level_idc = tvb_get_guint8(tvb,offset);
 	level_item = proto_tree_add_item(h264_profile_tree, hf_h264_level_idc, tvb, offset, 1, FALSE);
 	if((level_idc==11)&&(constraint_set3_flag==1)){
-		proto_item_append_text(level_item," [Level 1b]");
+		proto_item_append_text(level_item," [Level 1b (128kb/s)]");
 	}else{
-		proto_item_append_text(level_item," [Level %.1f]",((double)level_idc/10));
+		proto_item_append_text(level_item," [Level %.1f %s]",((double)level_idc/10),val_to_str(level_idc, h264_level_bitrate_values, "Unknown "));
 	}
 
 }
@@ -1056,7 +1098,7 @@ dissect_h264_sei_rbsp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo _U_, g
 }
 
 /* Ref 7.3.2.1 Sequence parameter set RBSP syntax */
-static void
+static int
 dissect_h264_seq_parameter_set_rbsp(proto_tree *tree, tvbuff_t *tvb, packet_info *pinfo, gint offset)
 {
 	proto_item *level_item;
@@ -1097,7 +1139,7 @@ dissect_h264_seq_parameter_set_rbsp(proto_tree *tree, tvbuff_t *tvb, packet_info
 	if((level_idc==11)&&(constraint_set3_flag==1)){
 		proto_item_append_text(level_item,"[Level 1b]");
 	}else{
-		proto_item_append_text(level_item,"[Level %.1f]",((double)level_idc/10));
+		proto_item_append_text(level_item," [Level %.1f %s]",((double)level_idc/10),val_to_str(level_idc, h264_level_bitrate_values, "Unknown "));
 	}
 	offset++;
 	/* seq_parameter_set_id 0 ue(v) 
@@ -1150,7 +1192,7 @@ dissect_h264_seq_parameter_set_rbsp(proto_tree *tree, tvbuff_t *tvb, packet_info
 			}
 			*/
 			proto_tree_add_text(tree, tvb, offset, -1, "[Not decoded yet]");
-			return;
+			return -1;
 		}
 
 	}
@@ -1177,7 +1219,7 @@ dissect_h264_seq_parameter_set_rbsp(proto_tree *tree, tvbuff_t *tvb, packet_info
 		dissect_h264_exp_golomb_code(tree, hf_h264_offset_for_top_to_bottom_field, tvb, &bit_offset, H264_SE_V);
 		
 		/* num_ref_frames_in_pic_order_cnt_cycle 0 ue(v) */
-		num_ref_frames_in_pic_order_cnt_cycle = dissect_h264_exp_golomb_code(tree, hf_264_num_ref_frames_in_pic_order_cnt_cycle, tvb, &bit_offset, H264_UE_V);
+		num_ref_frames_in_pic_order_cnt_cycle = dissect_h264_exp_golomb_code(tree, hf_h264_num_ref_frames_in_pic_order_cnt_cycle, tvb, &bit_offset, H264_UE_V);
 		for( i = 0; i < num_ref_frames_in_pic_order_cnt_cycle; i++ ){
 			/*offset_for_ref_frame[ i ] 0 se(v)*/
 			dissect_h264_exp_golomb_code(tree, hf_h264_offset_for_ref_frame, tvb, &bit_offset, H264_SE_V);
@@ -1235,6 +1277,9 @@ dissect_h264_seq_parameter_set_rbsp(proto_tree *tree, tvbuff_t *tvb, packet_info
 	/* 	rbsp_trailing_bits( ) 0 */
 	bit_offset = dissect_h264_rbsp_trailing_bits(tree, tvb, pinfo, bit_offset); 
 
+	offset = bit_offset>>3;
+
+	return offset;
 }
 
 /* 7.3.2.2 Picture parameter set RBSP syntax */
@@ -1425,7 +1470,10 @@ dissect_h264_seq_parameter_set_extension_rbsp(proto_tree *tree, tvbuff_t *tvb, p
 }
 
 
-/* Dissect NAL unit as recived in sprop-parameter-sets of SDP */
+/* 
+ * Dissect NAL unit as recived in sprop-parameter-sets of SDP
+ * or "DecoderConfiguration parameter in H.245
+ */
 void
 dissect_h264_nal_unit(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 {
@@ -1433,9 +1481,17 @@ dissect_h264_nal_unit(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 	proto_tree *h264_nal_tree;
 	gint	offset = 0;
 	guint8 nal_unit_type;
+	guint32 dword;
 	item = proto_tree_add_item(tree, hf_h264_nal_unit, tvb, offset, -1, FALSE);
 	h264_nal_tree = proto_item_add_subtree(item, ett_h264_nal_unit);
 
+startover:
+	/* In decoder configuration start code may be pressent */
+	dword = tvb_get_bits32(tvb,0,32,FALSE);
+	if(dword==1){
+		/* Start code */
+		offset+=4;
+	}
 	/* Ref: 7.3.1 NAL unit syntax */
 	nal_unit_type = tvb_get_guint8(tvb,offset) & 0x1f;
 
@@ -1470,7 +1526,15 @@ dissect_h264_nal_unit(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 		dissect_h264_sei_rbsp(h264_nal_tree, tvb, pinfo, offset);
 		break;
 	case H264_SEQ_PAR_SET:	/* 7 Sequence parameter set*/
-		dissect_h264_seq_parameter_set_rbsp(h264_nal_tree, tvb, pinfo, offset);
+		offset = dissect_h264_seq_parameter_set_rbsp(h264_nal_tree, tvb, pinfo, offset);
+		/* A bit ugly */
+		if(tvb_length_remaining(tvb,offset) > 0){
+			/* In this case length = offset as we start from zero */
+			proto_item_set_len(item, offset/*Length */);
+			item = proto_tree_add_item(tree, hf_h264_nal_unit, tvb, offset, -1, FALSE);
+			h264_nal_tree = proto_item_add_subtree(item, ett_h264_nal_unit);
+			goto startover;
+		}
 		break;
 	case H264_PIC_PAR_SET:	/* 8 Picture parameter set */
 		dissect_h264_pic_parameter_set_rbsp(h264_nal_tree, tvb, pinfo, offset);
@@ -1500,6 +1564,9 @@ dissect_h264_nal_unit(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree)
 	case 19:	/* Coded slice of an auxiliary coded picture without partitioning */
 		dissect_h264_slice_layer_without_partitioning_rbsp(tree, tvb, pinfo, offset);
 		break;
+	case 28:
+		dissect_h264_slice_layer_without_partitioning_rbsp(tree, tvb, pinfo, offset);
+		break;
 	default:
 		/* 24..31 Unspecified */
 		proto_tree_add_text(h264_nal_tree, tvb, offset, -1, "Unspecified NAL unit type");
@@ -1512,8 +1579,8 @@ static void
 dissect_h264(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	int offset = 0;
-	proto_item *item, *ti, *stream_item;
-	proto_tree *h264_tree, *h264_nal_tree, *stream_tree;
+	proto_item *item, *ti, *stream_item, *fua_item;
+	proto_tree *h264_tree, *h264_nal_tree, *stream_tree, *fua_tree;
 	guint8 type;
 
 
@@ -1525,8 +1592,14 @@ dissect_h264(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		item = proto_tree_add_item(tree, proto_h264, tvb, 0, -1, FALSE);
 		h264_tree = proto_item_add_subtree(item, ett_h264);
 
-		ti = proto_tree_add_text(h264_tree, tvb, offset, 1, "NAL unit header or first byte of the payload");
+		type = tvb_get_guint8(tvb,offset)&0x1f;
+/* if the type is 28, it would be draw another title */
+		if(type == 28)
+			ti = proto_tree_add_text(h264_tree, tvb, offset, 1, "FU identifier");
+		else
+			ti = proto_tree_add_text(h264_tree, tvb, offset, 1, "NAL unit header or first byte of the payload");
 		h264_nal_tree = proto_item_add_subtree(ti, ett_h264_nal);
+
 		/* +---------------+
 		 * |0|1|2|3|4|5|6|7|
 		 * +-+-+-+-+-+-+-+-+
@@ -1542,7 +1615,6 @@ dissect_h264(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		 */
 		proto_tree_add_item(h264_nal_tree, hf_h264_nal_f_bit, tvb, offset, 1, FALSE);
 		proto_tree_add_item(h264_nal_tree, hf_h264_nal_nri, tvb, offset, 1, FALSE);
-		type = tvb_get_guint8(tvb,offset)&0x1f;
 		if (check_col(pinfo->cinfo, COL_INFO)){
 			col_append_fstr(pinfo->cinfo, COL_INFO, " %s",
 				val_to_str(type, h264_type_values, "Unknown Type (%u)"));
@@ -1550,7 +1622,21 @@ dissect_h264(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 		proto_tree_add_item(h264_nal_tree, hf_h264_type, tvb, offset, 1, FALSE);
 		offset++;
-		stream_item =proto_tree_add_text(h264_tree, tvb, offset, -1, "H264 bitstream");
+		if (type == 28){
+			fua_item = proto_tree_add_text(h264_tree, tvb, offset, 1, "FU Header");
+			fua_tree = proto_item_add_subtree(fua_item, ett_h264_fua);
+			proto_tree_add_item(fua_tree, hf_h264_start_bit, tvb, offset, 1, FALSE);	
+			proto_tree_add_item(fua_tree, hf_h264_end_bit, tvb, offset, 1, FALSE);
+			proto_tree_add_item(fua_tree, hf_h264_forbidden_bit, tvb, offset, 1, FALSE);
+			proto_tree_add_item(fua_tree, hf_h264_nal_unit_type, tvb, offset, 1, FALSE);
+			if ( (tvb_get_guint8(tvb,offset)&0x80) == 0x80 ){
+				type = tvb_get_guint8(tvb,offset)&0x1f;
+				offset++;
+			}
+			else
+				return;
+		}
+		stream_item =proto_tree_add_text(h264_tree, tvb, offset, -1, "H264 bitstream");	
 		stream_tree = proto_item_add_subtree(stream_item, ett_h264_stream);
 		switch(type){
 		case 1:				/* 1 Coded slice of a non-IDR picture */ 
@@ -1683,6 +1769,18 @@ dissect_h264_par_level(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree _U_)
   offset += 2;
   return offset;
 }
+static int
+dissect_h264_par_DecoderConfigurationInformation(tvbuff_t *tvb, packet_info *pinfo _U_, proto_tree *tree _U_)
+{
+  asn1_ctx_t *actx;
+
+  actx = get_asn1_ctx(pinfo->private_data);
+  DISSECTOR_ASSERT(actx);
+
+  dissect_h264_nal_unit(tvb, pinfo, tree);
+
+  return tvb_length(tvb);
+}
 
 typedef struct _h264_capability_t {
   const gchar *id;
@@ -1706,7 +1804,7 @@ static h264_capability_t h264_capability_tab[] = {
   { "GenericCapability/0.0.8.241.0.0.1/collapsing/11", "AdditionalModesSupported", dissect_h264_par_AdditionalModesSupported },
   { "GenericCapability/0.0.8.241.0.0.1/collapsing/12", "AdditionalDisplayCapabilities", NULL },
   /* TS 26.111  H.264 */
-  { "GenericCapability/0.0.8.241.0.0.1/collapsing/43" , "DecoderConfigurationInformation", NULL },
+  { "GenericCapability/0.0.8.241.0.0.1/nonCollapsing/43" , "DecoderConfigurationInformation", dissect_h264_par_DecoderConfigurationInformation },
   { "GenericCapability/0.0.8.241.0.0.1/collapsing/44" , "AcceptRedundantSlices", NULL },
   { "GenericCapability/0.0.8.241.0.0.1/collapsing/45" , "NalAlignedMode", NULL },
   { "GenericCapability/0.0.8.241.0.0.1/collapsing/46" , "ProfileIOP", dissect_h264_ProfileIOP },
@@ -1753,7 +1851,7 @@ proto_reg_handoff_h264(void)
 {
 	static dissector_handle_t h264_handle;
 	static guint dynamic_payload_type;
-	static int h264_prefs_initialized = FALSE;
+	static gboolean h264_prefs_initialized = FALSE;
 
 	if (!h264_prefs_initialized) {
 		dissector_handle_t h264_name_handle;
@@ -1781,7 +1879,7 @@ proto_reg_handoff_h264(void)
 	}
 }
 
-/* this format is require because a script is used to build the C function
+/* this format is required because a script is used to build the C function
    that calls all the protocol registration.
 */
 
@@ -1808,6 +1906,21 @@ proto_register_h264(void)
 			FT_UINT8, BASE_DEC, VALS(h264_type_values), 0x1f,          
 			"Type", HFILL }
 		},
+		{ &hf_h264_start_bit,
+			{ "Start bit", "h264.start.bit",
+			FT_BOOLEAN, 8, TFS(&h264_start_bit_vals), 0x80,
+			"Start bit", HFILL }
+		},
+		{ &hf_h264_end_bit,
+			{ "End bit", "h264.end.bit",
+			FT_BOOLEAN, 8, TFS(&h264_end_bit_vals), 0x40,
+			"End Bit", HFILL }
+		},
+		{ &hf_h264_forbidden_bit,
+			{ "Forbidden bit", "h264.forbidden.bit",
+			FT_UINT8, BASE_DEC, NULL, 0x20,
+			"Forbidden bit", HFILL }
+		},
 		{ &hf_h264_profile,
 			{ "Profile",           "h264.profile",
 			FT_BYTES, BASE_NONE, NULL, 0x0,          
@@ -1943,7 +2056,7 @@ proto_register_h264(void)
 			FT_INT32, BASE_DEC, NULL, 0x0,          
 			"offset_for_top_to_bottom_field", HFILL }
 		},
-		{ &hf_264_num_ref_frames_in_pic_order_cnt_cycle,
+		{ &hf_h264_num_ref_frames_in_pic_order_cnt_cycle,
 			{ "num_ref_frames_in_pic_order_cnt_cycle",           "h264.num_ref_frames_in_pic_order_cnt_cycle",
 			FT_UINT32, BASE_DEC, NULL, 0x0,          
 			"num_ref_frames_in_pic_order_cnt_cycle", HFILL }
@@ -2406,6 +2519,7 @@ proto_register_h264(void)
 		&ett_h264,
 		&ett_h264_profile,
 		&ett_h264_nal,
+		&ett_h264_fua,
 		&ett_h264_stream,
 		&ett_h264_nal_unit,
 		&ett_h264_par_profile,
