@@ -3,7 +3,7 @@
  *
  * Heikki Vatiainen <hessu@cs.tut.fi>
  *
- * $Id: packet-hsrp.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-hsrp.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -783,7 +783,7 @@ void proto_register_hsrp(void)
                 { &hf_hsrp2_passive_group,
                   { "Passive Groups", "hsrp2.passive_groups",
                     FT_UINT16, BASE_DEC, NULL, 0x0,
-                    "Standby group number which doesn't become the acitve router myself", HFILL }},
+                    "Standby group number which doesn't become the active router myself", HFILL }},
 
                 { &hf_hsrp2_md5_algorithm,
                   { "MD5 Algorithm", "hsrp2._md5_algorithm",
