@@ -12,7 +12,7 @@
  *
  * for the current Internet-Draft for IAX2.
  *
- * $Id: packet-iax2.c 25962 2008-08-08 20:07:23Z guy $
+ * $Id: packet-iax2.c 27050 2008-12-18 19:08:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -2089,7 +2089,7 @@ proto_register_iax2 (void)
 
     {&hf_iax2_absts,
      {"Absolute Time", "iax2.abstime", FT_ABSOLUTE_TIME, BASE_NONE, NULL, 0x0,
-      "The absoulte time of this packet (calculated by adding the IAX timestamp to "
+      "The absolute time of this packet (calculated by adding the IAX timestamp to "
       " the start time of this call)",
       HFILL}},
 
