@@ -1,7 +1,7 @@
 /* packet-ipv6.c
  * Routines for IPv6 packet disassembly
  *
- * $Id: packet-ipv6.c 25882 2008-07-31 09:22:22Z etxrab $
+ * $Id: packet-ipv6.c 27050 2008-12-18 19:08:49Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -77,6 +77,7 @@ static int hf_ipv6_opt_pad1	  = -1;
 static int hf_ipv6_opt_padn	  = -1;
 static int hf_ipv6_dst_opt	  = -1;
 static int hf_ipv6_hop_opt	  = -1;
+static int hf_ipv6_unk_hdr	  = -1;
 static int hf_ipv6_routing_hdr_opt	  = -1;
 static int hf_ipv6_routing_hdr_type	  = -1;
 static int hf_ipv6_routing_hdr_left	  = -1;
@@ -319,7 +320,7 @@ dissect_routing6(tvbuff_t *tvb, int offset, proto_tree *tree, packet_info *pinfo
       ti = proto_tree_add_uint_format(tree, hf_ipv6_routing_hdr_opt, tvb,
 		      offset, len, rt.ip6r_type,
 		      "Routing Header, Type : %s (%u)",
-		      val_to_str(rt.ip6r_type, routing_header_type, "Unkown"),
+		      val_to_str(rt.ip6r_type, routing_header_type, "Unknown"),
 		      rt.ip6r_type);
       rthdr_tree = proto_item_add_subtree(ti, ett_ipv6);
 
@@ -548,6 +549,34 @@ dissect_ipv6_options(tvbuff_t *tvb, int offset, guint length,
   }
 }
 
+static int
+dissect_unknown_option(tvbuff_t *tvb, int offset, proto_tree *tree)
+{
+    struct ip6_ext ext;
+    int len;
+    proto_tree *unkopt_tree;
+    proto_item *ti;
+
+    tvb_memcpy(tvb, (guint8 *)&ext, offset, sizeof(ext));
+    len = (ext.ip6e_len + 1) << 3;
+
+    if (tree) {
+	/* !!! specify length */
+	ti = proto_tree_add_item(tree, hf_ipv6_unk_hdr, tvb, offset, len, FALSE);
+
+	unkopt_tree = proto_item_add_subtree(ti, ett_ipv6);
+
+	proto_tree_add_text(unkopt_tree, tvb,
+	    offset + offsetof(struct ip6_ext, ip6e_nxt), 1,
+	    "Next header: %s (0x%02x)", ipprotostr(ext.ip6e_nxt), ext.ip6e_nxt);
+
+	proto_tree_add_text(unkopt_tree, tvb,
+	    offset + offsetof(struct ip6_ext, ip6e_len), 1,
+	    "Length: %u (%d bytes)", ext.ip6e_len, len);
+    }
+    return len;
+}
+
 static int
 dissect_opts(tvbuff_t *tvb, int offset, proto_tree *tree, packet_info * pinfo, const int hf_option_item)
 {
@@ -686,7 +715,7 @@ dissect_shim_hex(tvbuff_t *tvb, int offset, int len, const char *itemname, guint
 
     p = offset;
 
-    ti = proto_tree_add_text(tree, tvb, offset, len, itemname);
+    ti = proto_tree_add_text(tree, tvb, offset, len, "%s", itemname);
 
     proto_item_append_text(ti, " 0x%02x", tvb_get_guint8(tvb, p) & bitmask);
     for (count=1; count<len; count++)
@@ -938,7 +967,7 @@ dissect_shim6_ct(proto_tree * shim_tree, gint hf_item, tvbuff_t * tvb, gint offs
 			      tmp[0] & SHIM6_BITMASK_CT, tmp[1], tmp[2],
 			      tmp[3], tmp[4], tmp[5]
 			    );
-  proto_tree_add_none_format(shim_tree, hf_item, tvb, offset - 6, 6, ct_str);
+  proto_tree_add_none_format(shim_tree, hf_item, tvb, offset - 6, 6, "%s", ct_str);
 }
 
 static void
@@ -960,7 +989,7 @@ dissect_shim6_probes(proto_tree * shim_tree, tvbuff_t * tvb, gint offset,
     ett_probes = ett_ipv6_shim6_probes_sent;
     ett_probe = ett_ipv6_shim6_probe_sent;
   }
-  it = proto_tree_add_text(shim_tree, tvb, offset, 40 * nbr_probe, label);
+  it = proto_tree_add_text(shim_tree, tvb, offset, 40 * nbr_probe, "%s", label);
   probes_tree = proto_item_add_subtree(it, ett_probes);
 
   for (count=0; count < nbr_probe; count++) {
@@ -1360,78 +1389,97 @@ dissect_ipv6(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 
 again:
    switch (nxt) {
+
    case IP_PROTO_HOPOPTS:
-			hopopts = TRUE;
-			advance = dissect_hopopts(tvb, offset, ipv6_tree, pinfo);
-			nxt = tvb_get_guint8(tvb, offset);
-			poffset = offset;
-			offset += advance;
-			plen -= advance;
-			goto again;
+      hopopts = TRUE;
+      advance = dissect_hopopts(tvb, offset, ipv6_tree, pinfo);
+      nxt = tvb_get_guint8(tvb, offset);
+      poffset = offset;
+      offset += advance;
+      plen -= advance;
+      goto again;
+
     case IP_PROTO_ROUTING:
-			routing = TRUE;
-			advance = dissect_routing6(tvb, offset, ipv6_tree, pinfo);
-			nxt = tvb_get_guint8(tvb, offset);
-			poffset = offset;
-			offset += advance;
-			plen -= advance;
-			goto again;
-    case IP_PROTO_FRAGMENT:	
-			advance = dissect_frag6(tvb, offset, pinfo, ipv6_tree,
-			    &offlg, &ident);
-			nxt = tvb_get_guint8(tvb, offset);
-			poffset = offset;
-			offset += advance;
-			plen -= advance;
-			frag = offlg & (IP6F_OFF_MASK | IP6F_MORE_FRAG);
-			save_fragmented |= frag;
-			if (ipv6_reassemble && frag && tvb_bytes_exist(tvb, offset, plen)) {
-				ipfd_head = fragment_add_check(tvb, offset, pinfo, ident,
-				ipv6_fragment_table,
-				ipv6_reassembled_table,
-			    offlg & IP6F_OFF_MASK,
-			    plen,
-			    offlg & IP6F_MORE_FRAG);
-				next_tvb = process_reassembled_data(tvb, offset, pinfo, "Reassembled IPv6",
-				ipfd_head, &ipv6_frag_items, &update_col_info, ipv6_tree);
-				if (next_tvb) {	/* Process post-fragment headers after reassembly... */
-					offset= 0;
-					offlg = 0;
-					frag = FALSE;
-					tvb = next_tvb;
-					goto again; 
-				}
-			}
-			if (!(offlg & IP6F_OFF_MASK)) /*...or in the first fragment */
-				goto again;
-			break;
+      routing = TRUE;
+      advance = dissect_routing6(tvb, offset, ipv6_tree, pinfo);
+      nxt = tvb_get_guint8(tvb, offset);
+      poffset = offset;
+      offset += advance;
+      plen -= advance;
+      goto again;
+
+    case IP_PROTO_FRAGMENT:  
+      advance = dissect_frag6(tvb, offset, pinfo, ipv6_tree,
+          &offlg, &ident);
+      nxt = tvb_get_guint8(tvb, offset);
+      poffset = offset;
+      offset += advance;
+      plen -= advance;
+      frag = offlg & (IP6F_OFF_MASK | IP6F_MORE_FRAG);
+      save_fragmented |= frag;
+      if (ipv6_reassemble && frag && tvb_bytes_exist(tvb, offset, plen)) {
+        ipfd_head = fragment_add_check(tvb, offset, pinfo, ident,
+        ipv6_fragment_table,
+        ipv6_reassembled_table,
+          offlg & IP6F_OFF_MASK,
+          plen,
+          offlg & IP6F_MORE_FRAG);
+        next_tvb = process_reassembled_data(tvb, offset, pinfo, "Reassembled IPv6",
+        ipfd_head, &ipv6_frag_items, &update_col_info, ipv6_tree);
+        if (next_tvb) {  /* Process post-fragment headers after reassembly... */
+          offset= 0;
+          offlg = 0;
+          frag = FALSE;
+          tvb = next_tvb;
+          goto again; 
+        }
+      }
+      if (!(offlg & IP6F_OFF_MASK)) /*...or in the first fragment */
+        goto again;
+      break;
+
     case IP_PROTO_AH:
-			ah = TRUE;
-			advance = dissect_ah_header(
-				  tvb_new_subset(tvb, offset, -1, -1),
-				  pinfo, ipv6_tree, NULL, NULL);
-			nxt = tvb_get_guint8(tvb, offset);
-			poffset = offset;
-			offset += advance;
-			plen -= advance;
-			goto again;
+      ah = TRUE;
+      advance = dissect_ah_header(tvb_new_subset(tvb, offset, -1, -1),
+                                  pinfo, ipv6_tree, NULL, NULL);
+      nxt = tvb_get_guint8(tvb, offset);
+      poffset = offset;
+      offset += advance;
+      plen -= advance;
+      goto again;
+
     case IP_PROTO_SHIM6:
-			shim6 = TRUE;
-			advance = dissect_shim6(tvb, offset, ipv6_tree, pinfo);
-			nxt = tvb_get_guint8(tvb, offset);
-			stype = tvb_get_guint8(tvb, offset+2);
-			poffset = offset;
-			offset += advance;
-			plen -= advance;
-			goto again;
+      shim6 = TRUE;
+      advance = dissect_shim6(tvb, offset, ipv6_tree, pinfo);
+      nxt = tvb_get_guint8(tvb, offset);
+      stype = tvb_get_guint8(tvb, offset+2);
+      poffset = offset;
+      offset += advance;
+      plen -= advance;
+      goto again;
+
     case IP_PROTO_DSTOPTS:
-			dstopts = TRUE;
-			advance = dissect_dstopts(tvb, offset, ipv6_tree, pinfo);
-			nxt = tvb_get_guint8(tvb, offset);
-			poffset = offset;
-			offset += advance;
-			plen -= advance;
-			goto again;
+      dstopts = TRUE;
+      advance = dissect_dstopts(tvb, offset, ipv6_tree, pinfo);
+      nxt = tvb_get_guint8(tvb, offset);
+      poffset = offset;
+      offset += advance;
+      plen -= advance;
+      goto again;
+
+    default:
+      /* Since we did not recognize this IPv6 option, check
+       * whether it is a known protocol. If not, then it
+       * is an unknown IPv6 option
+       */
+      if (!dissector_get_port_handle(ip_dissector_table, nxt)) {
+        advance = dissect_unknown_option(tvb, offset, ipv6_tree); 
+        nxt = tvb_get_guint8(tvb, offset);
+        poffset = offset;
+        offset += advance;
+        plen -= advance;
+        goto again;
+      }
     }
 
 #ifdef TEST_FINALHDR
@@ -1475,7 +1523,7 @@ again:
       if (check_col(pinfo->cinfo, COL_INFO)) {
         /* If we had an Authentication Header, the AH dissector already
            put something in the Info column; leave it there. */
-      	if (!ah) {
+        if (!ah) {
           if (hopopts || routing || dstopts || shim6) {
             if (hopopts) {
               col_append_fstr(pinfo->cinfo, COL_INFO, "%shop-by-hop options",
@@ -1491,13 +1539,13 @@ again:
                               sep);
             }
             if (shim6) {
-		if (stype & SHIM6_BITMASK_P) {
-              	  col_append_str(pinfo->cinfo, COL_INFO, "Shim6 (Payload)");
-		}
-		else {
-              	  col_append_fstr(pinfo->cinfo, COL_INFO, "Shim6 (%s)",
-		    val_to_str(stype & SHIM6_BITMASK_TYPE, shimctrlvals, "Unknown"));
-		}
+              if (stype & SHIM6_BITMASK_P) {
+                col_append_str(pinfo->cinfo, COL_INFO, "Shim6 (Payload)");
+	      }
+              else {
+                col_append_fstr(pinfo->cinfo, COL_INFO, "Shim6 (%s)",
+                   val_to_str(stype & SHIM6_BITMASK_TYPE, shimctrlvals, "Unknown"));
+              }
             }
           } else
             col_set_str(pinfo->cinfo, COL_INFO, "IPv6 no next header");
@@ -1578,6 +1626,10 @@ proto_register_ipv6(void)
       { "Hop-by-Hop Option",	"ipv6.hop_opt",
 				FT_NONE, BASE_NONE, NULL, 0x0,
 				"Hop-by-Hop Option", HFILL }},
+    { &hf_ipv6_unk_hdr,
+      { "Unknown Extension Header",	"ipv6.unknown_hdr",
+				FT_NONE, BASE_NONE, NULL, 0x0,
+				"Unknown Extension Header", HFILL }},
     { &hf_ipv6_routing_hdr_opt,
       { "Routing Header, Type ","ipv6.routing_hdr",
 				FT_UINT8, BASE_DEC, NULL, 0x0,
