@@ -1,7 +1,7 @@
 /* packet-ipvs-syncd.c   2001 Ronnie Sahlberg <See AUTHORS for email>
  * Routines for IGMP packet disassembly
  *
- * $Id: packet-ipvs-syncd.c 27934 2009-04-02 17:34:30Z gerald $
+ * $Id: packet-ipvs-syncd.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -63,8 +63,8 @@ static int ett_flags = -1;
 #define IPVS_SYNCD_PORT 8848
 
 static const value_string proto_strings[] = {
-	{0x06, "TCP"},
-	{0x11, "UDP"},
+	{0x06, "UDP"},
+	{0x11, "TCP"},
 	{0x00, NULL},
 };
 
@@ -121,7 +121,7 @@ dissect_ipvs_syncd(tvbuff_t *tvb, packet_info *pinfo, proto_tree *parent_tree)
 	proto_tree_add_item(tree, hf_syncid, tvb, offset, 1, FALSE);
 	offset += 1;
 
-	proto_tree_add_item(tree, hf_size, tvb, offset, 2, FALSE);
+	proto_tree_add_item(tree, hf_size, tvb, offset, 2, TRUE);
 	offset += 2;
 
 	for (conn = 0; conn < cnt; conn++)
@@ -253,7 +253,7 @@ proto_register_ipvs_syncd(void)
 
 		{ &hf_syncid,
 			{ "Synchronization ID", "ipvs.syncid", FT_UINT8, BASE_DEC,
-			  NULL, 0, "Syncronization ID", HFILL }},
+			  NULL, 0, "Synchronization ID", HFILL }},
 
 		{ &hf_size,
 			{ "Size", "ipvs.size", FT_UINT16, BASE_DEC,
