@@ -6,7 +6,7 @@
  * Portions Copyright (c) 2000-2002 by Gilbert Ramirez.
  * Portions Copyright (c) Novell, Inc. 2002-2003
  *
- * $Id: packet-ipx.c 25821 2008-07-24 16:46:09Z gerald $
+ * $Id: packet-ipx.c 26647 2008-10-31 15:11:57Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1242,7 +1242,7 @@ dissect_ipxsap(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		sap_tree = proto_item_add_subtree(ti, ett_ipxsap);
 
 		if (query.query_type >= 1 && query.query_type <= 4) {
-			proto_tree_add_text(sap_tree, tvb, 0, 2, sap_type[query.query_type - 1]);
+			proto_tree_add_text(sap_tree, tvb, 0, 2, "%s", sap_type[query.query_type - 1]);
 			if ((query.query_type - 1) % 2) {
 			  hidden_item = proto_tree_add_boolean(sap_tree,
 						     hf_sap_response,
