@@ -1,7 +1,7 @@
 /* packet-isis-lsp.c
  * Routines for decoding isis lsp packets and their CLVs
  *
- * $Id: packet-isis-lsp.c 25601 2008-06-25 09:12:35Z guy $
+ * $Id: packet-isis-lsp.c 27213 2009-01-12 22:05:37Z jake $
  * Stuart Stanley <stuarts@mxmail.net>
  *
  * Wireshark - Network traffic analyzer
@@ -303,7 +303,7 @@ static const isis_clv_handle_t clv_l2_lsp_opts[] = {
 	},
 	{
 		ISIS_CLV_PARTITION_DIS,
-		"Parition Designated Level 2 IS",
+		"Partition Designated Level 2 IS",
 		&ett_isis_lsp_clv_partition_dis,
 		dissect_lsp_partition_dis_clv
 	},
@@ -597,7 +597,7 @@ dissect_lsp_ip_reachability_clv(tvbuff_t *tvb, proto_tree *tree, int offset,
                         if (ISIS_LSP_CLV_METRIC_SUPPORTED(tvb_get_guint8(tvb, offset+2))) {
                           proto_tree_add_text (ntree, tvb, offset+2, 1, "Expense Metric: Not supported");
 			} else {
-                          proto_tree_add_text (ntree, tvb, offset+2, 1, "Exense Metric:  %d, %s",
+                          proto_tree_add_text (ntree, tvb, offset+2, 1, "Expense Metric:  %d, %s",
                                                ISIS_LSP_CLV_METRIC_VALUE(tvb_get_guint8(tvb, offset+2)),
 					       ISIS_LSP_CLV_METRIC_IE(tvb_get_guint8(tvb, offset+2)) ? "External" : "Internal");
 			}
@@ -1713,7 +1713,7 @@ dissect_lsp_prefix_neighbors_clv(tvbuff_t *tvb, proto_tree *tree, int offset,
 		}
 		if ( mylen > length) {
 			isis_dissect_unknown(tvb, tree, offset,
-				"Interal length of prefix neighbor too long (%d vs %d)",
+				"Integral length of prefix neighbor too long (%d vs %d)",
 				mylen, length );
 			return;
 		}
@@ -1778,7 +1778,7 @@ isis_dissect_isis_lsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 {
 	proto_item	*ti, *to, *ta;
 	proto_tree	*lsp_tree = NULL, *info_tree, *att_tree;
-	guint16		pdu_length, checksum, cacl_checksum=0;
+	guint16		pdu_length, lifetime, checksum, cacl_checksum=0;
 	guint8		lsp_info, lsp_att;
 	int		len, offset_checksum;
 	proto_item	*it_cksum;
@@ -1800,6 +1800,7 @@ isis_dissect_isis_lsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 		proto_tree_add_item(lsp_tree, hf_isis_lsp_remaining_life, 
 			tvb, offset, 2, FALSE);
 	}
+	lifetime = tvb_get_ntohs(tvb, offset);
 	offset += 2;
 	offset_checksum = offset;
 
@@ -1829,33 +1830,33 @@ isis_dissect_isis_lsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, int o
 	offset += 4;
 
 	if (tree) {
-    		checksum = tvb_get_ntohs(tvb, offset);    		
+		checksum = lifetime ? tvb_get_ntohs(tvb, offset) : 0;
 		switch (check_and_get_checksum(tvb, offset_checksum, pdu_length-12, checksum, offset, &cacl_checksum))
 		{
-
-        		case NO_CKSUM :
-	      			proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
+			case NO_CKSUM :
+				checksum = tvb_get_ntohs(tvb, offset);
+				proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
 					"Checksum: 0x%04x [unused]", checksum);
-       	 		break;
-        		case DATA_MISSING :
-          			isis_dissect_unknown(tvb, tree, offset,
-		    			"[packet length %d went beyond packet]",
-      			 		tvb_length_remaining(tvb, offset_checksum));
-        		break;
-        		case CKSUM_NOT_OK :
-					it_cksum = proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
-						"Checksum: 0x%04x [incorrect, should be 0x%04x]",
-						checksum, cacl_checksum);
-					isis_lsp_checkum_additional_info(tvb, pinfo, it_cksum, offset, FALSE);
-        		break;
-	        	case CKSUM_OK :
-	        			it_cksum = proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
-						"Checksum: 0x%04x [correct]", checksum);
-					isis_lsp_checkum_additional_info(tvb, pinfo, it_cksum, offset, TRUE);
-        		break;
-        		default :
-          			g_message("'check_and_get_checksum' returned an invalid value");
-    		}
+			break;
+			case DATA_MISSING :
+				isis_dissect_unknown(tvb, tree, offset,
+					"[packet length %d went beyond packet]",
+			 		tvb_length_remaining(tvb, offset_checksum));
+			break;
+			case CKSUM_NOT_OK :
+				it_cksum = proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
+					"Checksum: 0x%04x [incorrect, should be 0x%04x]",
+					checksum, cacl_checksum);
+				isis_lsp_checkum_additional_info(tvb, pinfo, it_cksum, offset, FALSE);
+			break;
+			case CKSUM_OK :
+				it_cksum = proto_tree_add_uint_format(lsp_tree, hf_isis_lsp_checksum, tvb, offset, 2, checksum,
+					"Checksum: 0x%04x [correct]", checksum);
+				isis_lsp_checkum_additional_info(tvb, pinfo, it_cksum, offset, TRUE);
+			break;
+			default :
+				g_message("'check_and_get_checksum' returned an invalid value");
+		}
 	}
 	offset += 2;
 
