@@ -3,7 +3,7 @@
 *
 * Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: packet-k12.c 26135 2008-09-03 23:51:26Z guy $
+* $Id: packet-k12.c 27133 2008-12-30 17:17:14Z martinm $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -453,12 +453,12 @@ proto_register_k12(void)
 
   k12_uat = uat_new("K12 Protocols",
 		    sizeof(k12_handles_t),
-		    "k12_protos",
-		    TRUE,
-		    (void**) &k12_handles,
-		    &nk12_handles,
-		    UAT_CAT_FFMT,
-		    "ChK12ProtocolsSection",
+		    "k12_protos",             /* filename */
+		    TRUE,                     /* from_profile */
+		    (void**) &k12_handles,    /* data_ptr */
+		    &nk12_handles,            /* numitems_ptr */
+		    UAT_CAT_FFMT,             /* category */
+		    "ChK12ProtocolsSection",  /* help */
 		    k12_copy_cb,
 		    k12_update_cb,
 		    k12_free_cb,
