@@ -3,7 +3,7 @@
  *
  * Ronnie Sahlberg 2004
  *
- * $Id: packet-kerberos4.c 19129 2006-09-04 08:18:52Z sahlberg $
+ * $Id: packet-kerberos4.c 26308 2008-09-30 14:49:44Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -457,6 +457,6 @@ proto_reg_handoff_krb4(void)
 {
   dissector_handle_t krb4_handle;
 
-  krb4_handle = new_create_dissector_handle(dissect_krb4, proto_krb4);
+  krb4_handle = find_dissector("krb4");
   dissector_add("udp.port", UDP_PORT_KRB4, krb4_handle);
 }
