@@ -2,7 +2,7 @@
  * Routines for IEEE 802.2 LLC layer
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-llc.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-llc.c 25291 2008-05-14 05:44:42Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -92,6 +92,7 @@ static dissector_handle_t eth_withoutfcs_handle;
 static dissector_handle_t eth_withfcs_handle;
 static dissector_handle_t fddi_handle;
 static dissector_handle_t tr_handle;
+static dissector_handle_t turbo_handle;
 static dissector_handle_t data_handle;
 
 /*
@@ -192,6 +193,7 @@ http://www.cisco.com/univercd/cc/td/doc/product/software/ios113ed/113ed_cr/ibm_r
 	{ OUI_PROFINET,			"PROFIBUS Nutzerorganisation e.V." },
 	{ OUI_SONY_ERICSSON_3,	"Sony Ericsson Mobile Communications AB" },
 	{ OUI_CATENA,			"Catena Networks" },
+	{ OUI_CIMETRICS,		"Cimetrics" },
 	{ OUI_IEEE_802_3,		"IEEE 802.3" },
 	{ OUI_MEDIA_ENDPOINT,	"Media (TIA TR-41 Committee)" },
 	{ OUI_SONY_ERICSSON_4,	"Sony Ericsson Mobile Communications AB" },
@@ -210,6 +212,7 @@ http://www.cisco.com/univercd/cc/td/doc/product/software/ios113ed/113ed_cr/ibm_r
 	{ OUI_SIEMENS,			"Siemens AG" },
 	{ OUI_APPLE_ATALK,		"Apple (AppleTalk)" },
 	{ OUI_HP,				"Hewlett-Packard" },
+	{ OUI_TURBOCELL,		"Karlnet (Turbocell)" },
 	{ 0,               NULL }
 };
 
@@ -685,6 +688,11 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
 		call_dissector(bpdu_handle, next_tvb, pinfo, tree);
 		break;
 
+	case OUI_TURBOCELL:
+		next_tvb = tvb_new_subset(tvb, offset+3, -1, -1);
+		call_dissector(turbo_handle, next_tvb, pinfo, tree);
+		break;
+
 	default:
 		/*
 		 * Do we have information for this OUI?
@@ -871,14 +879,15 @@ proto_reg_handoff_llc(void)
 	dissector_handle_t llc_handle;
 
 	/*
-	 * Get handles for the BPDU, Ethernet, FDDI, and Token Ring
-	 * dissectors.
+	 * Get handles for the BPDU, Ethernet, FDDI, Token Ring and
+	 * Turbocell dissectors.
 	 */
 	bpdu_handle = find_dissector("bpdu");
 	eth_withoutfcs_handle = find_dissector("eth_withoutfcs");
 	eth_withfcs_handle = find_dissector("eth_withfcs");
 	fddi_handle = find_dissector("fddi");
 	tr_handle = find_dissector("tr");
+	turbo_handle = find_dissector("turbocell");
 	data_handle = find_dissector("data");
 
 	llc_handle = find_dissector("llc");
