@@ -9,7 +9,7 @@
  *          Laboratories, Inc., http://www.PacketCable.com/
  * www.iana.org/assignments/mgcp-localconnectionoptions
  *
- * $Id: packet-mgcp.c 26269 2008-09-25 18:32:14Z kukosa $
+ * $Id: packet-mgcp.c 27037 2008-12-17 17:23:37Z wmeier $
  *
  * Copyright (c) 2000 by Ed Warnicke <hagbard@physics.rutgers.edu>
  * Copyright (c) 2004 by Thomas Anders <thomas.anders [AT] blue-cable.de>
@@ -824,7 +824,7 @@ void proto_register_mgcp(void)
             "Specific Endpoint ID", HFILL }},
         { &hf_mgcp_param_secondendpointid,
           { "SecondEndpointID (Z2)", "mgcp.param.secondendpointid", FT_STRING, BASE_DEC, NULL, 0x0,
-            "Second Endpoing ID", HFILL }},
+            "Second Endpoint ID", HFILL }},
         { &hf_mgcp_param_reqinfo,
           { "RequestedInfo (F)", "mgcp.param.reqinfo", FT_STRING, BASE_DEC, NULL, 0x0,
             "Requested Info", HFILL }},
