@@ -3,7 +3,7 @@
  * Copyright 2000, Stefan Raab <sraab@cisco.com>
  * Copyright 2007, Ville Nuorvala <Ville.Nuorvala@secgo.com>
  *
- * $Id: packet-mip.c 21948 2007-05-26 01:01:27Z standel $
+ * $Id: packet-mip.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -812,7 +812,7 @@ void proto_register_mip(void)
           { &hf_mip_rext_i,
 		 { "'I' bit Support",          "mip.ext.rev.i",
 			FT_BOOLEAN, 16, NULL, 32768,
-			"Agent surevidpports Inform bit in Revocation", HFILL }
+			"Agent supports Inform bit in Revocation", HFILL }
           },
           { &hf_mip_rext_reserved,
 		 { "Reserved",                 "mip.ext.rev.reserved",
