@@ -1,6 +1,6 @@
 /* packet-mip6.c
  *
- * $Id: packet-mip6.c 29702 2009-09-04 21:26:50Z gerald $
+ * $Id: packet-mip6.c 27062 2008-12-19 17:39:52Z gerald $
  *
  * Routines for Mobile IPv6 dissection (RFC 3775)
  * Copyright 2003 Oy L M Ericsson Ab <teemu.rinta-aho@ericsson.fi>
@@ -668,7 +668,7 @@ static const ip_tcp_opt mip6_opts[] = {
 	dissect_mip6_opt_ni
 },
 {
-	MBAD,
+	BAD,
 	"Binding Authorization Data",
 	&ett_mip6_opt_bad,
 	VARIABLE_LENGTH,
