@@ -11,7 +11,7 @@
  *     - mpls subdissector table indexed by label value
  *     - enhanced "what's past last mpls label?" heuristic
  *
- * $Id: packet-mpls.c 26308 2008-09-30 14:49:44Z wmeier $
+ * $Id: packet-mpls.c 27087 2008-12-22 16:10:11Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -575,7 +575,7 @@ static void
 dissect_mpls(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
     int offset = 0;
-    guint32 label;
+    guint32 label = LABEL_INVALID;
     guint8 exp;
     guint8 bos;
     guint8 ttl;
