@@ -5,7 +5,7 @@
  *
  * MySQL 4.1+ protocol by Axel Schwenke <axel@mysql.com>
  *
- * $Id: packet-mysql.c 26277 2008-09-26 17:04:01Z wmeier $
+ * $Id: packet-mysql.c 27037 2008-12-17 17:23:37Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -669,7 +669,7 @@ void proto_register_mysql(void)
 		"", HFILL }},
 
 		{ &hf_mysql_cap_no_schema,
-		{ "Dont Allow database.table.column","mysql.caps.ns",
+		{ "Don't Allow database.table.column","mysql.caps.ns",
 		FT_BOOLEAN, 16, TFS(&flags_set_truth), MYSQL_CAPS_NS,
 		"", HFILL }},
 
