@@ -3,7 +3,7 @@
  * Greg Morris <gmorris@novell.com>
  * Copyright (c) Novell, Inc. 2002-2004
  *
- * $Id: packet-ncp-nmas.c 26089 2008-08-25 22:06:20Z wmeier $
+ * $Id: packet-ncp-nmas.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -52,7 +52,7 @@ static int hf_msg_version = -1;
 static int hf_session_ident = -1;
 static int hf_msg_verb = -1;
 static int hf_attribute = -1;
-static int hf_clearence = -1;
+static int hf_clearance = -1;
 static int hf_login_sequence = -1;
 static int hf_opaque = -1;
 static int hf_data = -1;
@@ -100,7 +100,7 @@ static const value_string nmas_msgverb_enum[] = {
 static const value_string nmas_attribute_enum[] = {
     { 1, "User Name" },
     { 2, "Tree Name" },
-    { 4, "Clearence" },
+    { 4, "Clearance" },
     { 11, "Login Sequence" },
     { 0,          NULL }
 };
@@ -138,7 +138,7 @@ static const value_string nmas_errors_enum[] = {
     { 0xFFFFF993, "(-1645) TIMED OUT NOT RECOVERABLE" },
     { 0xFFFFF992, "(-1646) TIMED OUT UNKNOWN" },
     { 0xFFFFF991, "(-1647) AUTHORIZATION FAILURE" },
-    { 0xFFFFF990, "(-1648) INVALID DISTINGUSHED NAME" },
+    { 0xFFFFF990, "(-1648) INVALID DISTINGUISHED NAME" },
     { 0xFFFFF98F, "(-1649) CANNOT RESOLVE DISTINGUISHED NAME" },
     { 0xFFFFF98E, "(-1650) CANNOT RESOLVE CONNECTION" },
     { 0xFFFFF98D, "(-1651) NO CRYPTOGRAPHY" },
@@ -301,8 +301,10 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
     foffset += 1;
 
     /* Fill in the INFO column. */
-    if (check_col(pinfo->cinfo, COL_INFO)) {
+    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
        col_set_str(pinfo->cinfo, COL_PROTOCOL, "NMAS");
+    }
+    if (check_col(pinfo->cinfo, COL_INFO)) {
        col_add_fstr(pinfo->cinfo, COL_INFO, "C NMAS - %s",
                     val_to_str(subfunc, nmas_func_enum, "Unknown (0x%02x)"));
     }
@@ -437,7 +439,7 @@ dissect_nmas_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, nc
                         foffset = nmas_string(tvb, hf_tree, atree, foffset, FALSE);
                         break;
                     case 4:
-                        foffset = nmas_string(tvb, hf_clearence, atree, foffset, FALSE);
+                        foffset = nmas_string(tvb, hf_clearance, atree, foffset, FALSE);
                         break;
                     case 11:
                         foffset = nmas_string(tvb, hf_login_sequence, atree, foffset, FALSE);
@@ -492,7 +494,7 @@ dissect_nmas_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guin
         subverb = request_value->req_nds_flags;
         msgverb = request_value->nds_request_verb;
     }
-    if (check_col(pinfo->cinfo, COL_INFO)) {
+    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
        col_set_str(pinfo->cinfo, COL_PROTOCOL, "NMAS");
     }
     if (tvb_reported_length_remaining(tvb, foffset)<4) {
@@ -717,10 +719,10 @@ proto_register_nmas(void)
         { "Attribute Type",        "nmas.attribute", FT_UINT32, BASE_DEC, VALS(nmas_attribute_enum), 0x0,
             "Attribute Type", HFILL }},
 
-        { &hf_clearence,
-        { "Requested Clearence",    "nmas.clearence",
+        { &hf_clearance,
+        { "Requested Clearance",    "nmas.clearance",
           FT_STRING,    BASE_NONE,   NULL,   0x0,
-          "Requested Clearence", HFILL }},
+          "Requested Clearance", HFILL }},
 
         { &hf_login_sequence,
         { "Requested Login Sequence",    "nmas.login_seq",
