@@ -3,7 +3,7 @@
  * Greg Morris <gmorris@novell.com>
  * Copyright (c) Novell, Inc. 2002-2003
  *
- * $Id: packet-ncp-sss.c 26089 2008-08-25 22:06:20Z wmeier $
+ * $Id: packet-ncp-sss.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -141,7 +141,7 @@ static const value_string sss_msgverb_enum[] _U_ = {
 static const value_string sss_attribute_enum[] _U_ = {
     { 1, "User Name" },
     { 2, "Tree Name" },
-    { 4, "Clearence" },
+    { 4, "Clearance" },
     { 11, "Login Sequence" },
     { 0,          NULL }
 };
@@ -579,9 +579,11 @@ dissect_sss_request(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, ncp
     subfunc = tvb_get_guint8(tvb, foffset);
     foffset += 1;
 
-	/* Fill in the INFO column. */
-	if (check_col(pinfo->cinfo, COL_INFO)) {
+    /* Fill in the PROTOCOL & INFO  columns. */
+    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
        col_set_str(pinfo->cinfo, COL_PROTOCOL, "NSSS");
+    }
+    if (check_col(pinfo->cinfo, COL_INFO)) {
        col_add_fstr(pinfo->cinfo, COL_INFO, "C SecretStore - %s", val_to_str(subfunc, sss_func_enum, "Unknown (%d)"));
     }
     switch (subfunc) {
@@ -726,7 +728,7 @@ dissect_sss_reply(tvbuff_t *tvb, packet_info *pinfo, proto_tree *ncp_tree, guint
         subverb = request_value->req_nds_flags;
         msgverb = request_value->nds_request_verb;
     }
-	if (check_col(pinfo->cinfo, COL_INFO)) {
+    if (check_col(pinfo->cinfo, COL_PROTOCOL)) {
        col_set_str(pinfo->cinfo, COL_PROTOCOL, "NSSS");
     }
     if (tvb_length_remaining(tvb, foffset)<4) {
