@@ -9,7 +9,7 @@
  * Portions Copyright (c) by James Coe 2000-2002
  * Portions Copyright (c) Novell, Inc. 2000-2003
  *
- * $Id: packet-ncp.c 23252 2007-10-23 05:50:00Z etxrab $
+ * $Id: packet-ncp.c 26028 2008-08-14 23:51:52Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -173,7 +173,7 @@ static const value_string burst_command[] = {
 
 */
 
-static value_string ncp_type_vals[] = {
+static const value_string ncp_type_vals[] = {
 	{ NCP_ALLOCATE_SLOT,	"Create a service connection" },
 	{ NCP_SERVICE_REQUEST,	"Service request" },
 	{ NCP_SERVICE_REPLY,	"Service reply" },
@@ -186,7 +186,7 @@ static value_string ncp_type_vals[] = {
 	{ 0,			NULL }
 };
 
-static value_string ncp_oplock_vals[] = {
+static const value_string ncp_oplock_vals[] = {
     { 0x21, "Message Waiting" },
     { 0x24, "Clear Op-lock" },
     { 0, NULL }
