@@ -1,7 +1,7 @@
 /* packet-nhrp.c
  * Routines for NBMA Next Hop Resoultion Protocol
  *
- * $Id: packet-nhrp.c 26280 2008-09-26 20:06:40Z wmeier $
+ * $Id: packet-nhrp.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -746,7 +746,7 @@ proto_register_nhrp(void)
 		  { "Client Protocol Address",	"nhrp.client.prot.addr", FT_IPv4, 		BASE_NONE, NULL, 0x0, "", HFILL }},
 
 		{ &hf_nhrp_ext_C,
-		  { "Compulsary Flag",			"nhrp.ext.c", 			FT_BOOLEAN, 16, NULL, 0x8000, "", HFILL }},
+		  { "Compulsory Flag",			"nhrp.ext.c", 			FT_BOOLEAN, 16, NULL, 0x8000, "", HFILL }},
 		{ &hf_nhrp_ext_type,
 		  { "Extension Type",			"nhrp.ext.type", 		FT_UINT16,	BASE_HEX, NULL, 0x3FFF, "", HFILL }},
 		{ &hf_nhrp_ext_len,
