@@ -3,7 +3,7 @@
  * Original Author Mark C. Brown <mbrown@hp.com>
  * Copyright (C) 2004 Hewlett-Packard Development Company, L.P.
  *
- * $Id: packet-pagp.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-pagp.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -433,7 +433,7 @@ proto_register_pagp(void)
     { &hf_pagp_flags,
       { "Flags",		"pagp.flags",
 	FT_UINT8,	BASE_HEX,	NULL,	0x0,
-      	"Infomation flags", HFILL }},
+      	"Information flags", HFILL }},
 
     { &hf_pagp_flags_slow_hello,
       { "Slow Hello",		"pagp.flags.slowhello",
