@@ -1,7 +1,7 @@
 /* packet-portmap.c
  * Routines for portmap dissection
  *
- * $Id: packet-portmap.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-portmap.c 26277 2008-09-26 17:04:01Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -69,7 +69,6 @@ static gint ett_portmap_rpcb = -1;
 static gint ett_portmap_entry = -1;
 
 static dissector_handle_t rpc_handle;
-static dissector_handle_t rpc_tcp_handle;
 
 /* Dissect a getport call */
 static int
@@ -168,7 +167,7 @@ dissect_getport_reply(tvbuff_t *tvb, int offset, packet_info *pinfo _U_,
 		proto_item_append_text(tree, " Port:%d", port);
 	} else {
 		if (check_col(pinfo->cinfo, COL_INFO)) {
-			col_append_fstr(pinfo->cinfo, COL_INFO,  " PROGRAM_NOT_AVAILABLE");
+			col_append_str(pinfo->cinfo, COL_INFO,  " PROGRAM_NOT_AVAILABLE");
 		}
 		proto_item_append_text(tree, " PROGRAM_NOT_AVAILABLE");
 	}
@@ -661,5 +660,4 @@ proto_reg_handoff_portmap(void)
 	rpc_init_proc_table(PORTMAP_PROGRAM, 3, portmap3_proc, hf_portmap_procedure_v3);
 	rpc_init_proc_table(PORTMAP_PROGRAM, 4, portmap4_proc, hf_portmap_procedure_v4);
 	rpc_handle = find_dissector("rpc");
-	rpc_tcp_handle = find_dissector("rpc-tcp");
 }
