@@ -4,7 +4,7 @@
  * Uwe Girlich <uwe@planetquake.com>
  *	http://www.idsoftware.com/q1source/q1source.zip
  *
- * $Id: packet-quakeworld.c 26121 2008-09-02 19:08:29Z wmeier $
+ * $Id: packet-quakeworld.c 26253 2008-09-23 01:10:45Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -330,7 +330,7 @@ static const value_string names_direction[] = {
 
 /* I took this name and value directly out of the QW source. */
 #define PORT_MASTER 27500
-static unsigned int gbl_quakeworldServerPort=PORT_MASTER;
+static guint gbl_quakeworldServerPort=PORT_MASTER;
 
 
 /* out of band message id bytes (taken out of quakeworldsource/client/protocol.h */
@@ -773,7 +773,7 @@ proto_reg_handoff_quakeworld(void)
 {
 	static gboolean Initialized=FALSE;
 	static dissector_handle_t quakeworld_handle;
-	static int ServerPort=0;
+	static guint ServerPort;
 
 	if (!Initialized) {
 		quakeworld_handle = create_dissector_handle(dissect_quakeworld,
