@@ -1,7 +1,7 @@
 /* packet-s5066.c
  * Routines for STANAG 5066 SIS layer packet disassembly
  *
- * $Id: packet-s5066.c 26208 2008-09-15 19:54:40Z wmeier $
+ * $Id: packet-s5066.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Copyright (c) 2005 by Menno Andriesse <s5066 [AT] nc3a.nato.int>
  *
@@ -140,7 +140,7 @@ static gint hf_s5066_st_txmode = -1;
 static const value_string s5066_st_txmode[] = {
 	{ 0, "Ignore service type field"},
 	{ 1, "ARQ"},
-	{ 2, "Non-ARQ (Broacast)"},
+	{ 2, "Non-ARQ (Broadcast)"},
 	{ 3, "Non-ARQ (with errors)"},
 	{ 4, "Other non-ARQ types"},
 	{ 5, "Other non-ARQ types"},
@@ -429,7 +429,7 @@ proto_register_s5066(void)
 {
 	static hf_register_info hf[] = {
 		{ &hf_s5066_sync_word,
-			{ "Sync preample", "s5066.sync", FT_UINT16, BASE_HEX, NULL, 0x0, "", HFILL }
+			{ "Sync preamble", "s5066.sync", FT_UINT16, BASE_HEX, NULL, 0x0, "", HFILL }
 		},
 		{ &hf_s5066_version,
 			{ "S5066 version", "s5066.version", FT_UINT8, BASE_HEX, NULL, 0x0, "", HFILL }
@@ -785,8 +785,8 @@ proto_register_s5066(void)
 				       &s5066_desegment);
 	prefs_register_bool_preference(s5066_module, "edition_one",
 				       "Dissect edition 1.0 of STANAG 5066",
-				       "Whether the S5066 dissector should dissect editon 1 of the STANAG."
-				       " This editon was never formally approved and is very rare. The common edition is editon 1.2.",
+				       "Whether the S5066 dissector should dissect this edition of the STANAG."
+				       " This edition was never formally approved and is very rare. The common edition is edition 1.2.",
 				       &s5066_edition_one);
 	prefs_register_uint_preference(s5066_module, "tcp.port",
 				       "STANAG 5066 TCP Port",
