@@ -9,7 +9,7 @@
  *       In particular I have not had an opportunity to see how it
  *       responds to SRVLOC over TCP.
  *
- * $Id: packet-srvloc.c 25713 2008-07-11 20:12:22Z morriss $
+ * $Id: packet-srvloc.c 27037 2008-12-17 17:23:37Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -370,7 +370,7 @@ dissect_authblk(tvbuff_t *tvb, int offset, proto_tree *tree)
     } else {
       proto_tree_add_text(tree, tvb, offset, 8, "Timestamp not representable");
     }
-    proto_tree_add_text(tree, tvb, offset + 8, 2, "Block Structure Desciptor: %u",
+    proto_tree_add_text(tree, tvb, offset + 8, 2, "Block Structure Descriptor: %u",
 			tvb_get_ntohs(tvb, offset + 8));
     length = tvb_get_ntohs(tvb, offset + 10);
     proto_tree_add_text(tree, tvb, offset + 10, 2, "Authenticator length: %u",
