@@ -5,7 +5,7 @@
  * Full Tacacs+ parsing with decryption by
  *   Emanuele Caratti <wiz@iol.it>
  *
- * $Id: packet-tacacs.c 25290 2008-05-14 01:47:41Z wmeier $
+ * $Id: packet-tacacs.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -867,12 +867,16 @@ parse_tuple( char *key_from_option )
 	printf("keys: %s\n", key_from_option );
 	*/
 	client=strchr(key_from_option,'/');
-	if(!client)
+	if(!client) {
+		g_free(tacplus_data);
 		return;
+	}
 	*client++='\0';
 	key=strchr(client,'=');
-	if(!key)
+	if(!key) {
+		g_free(tacplus_data);
 		return;
+	}
 	*key++='\0';
 	/*
 	printf("%s %s => %s\n", key_from_option, client, key );
@@ -1101,7 +1105,7 @@ proto_register_tacplus(void)
 	proto_register_subtree_array(ett, array_length(ett));
 	tacplus_module = prefs_register_protocol (proto_tacplus, tacplus_pref_cb );
 
-        prefs_register_bool_preference(tacplus_module, "desegment", "Reassemble TACACS+ messages spanning multiple TCP segments.", "Whether the TACACS+ dissector should reasssemble messages spanning multiple TCP segments.  To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.", &tacplus_preference_desegment);
+        prefs_register_bool_preference(tacplus_module, "desegment", "Reassemble TACACS+ messages spanning multiple TCP segments.", "Whether the TACACS+ dissector should reassemble messages spanning multiple TCP segments.  To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.", &tacplus_preference_desegment);
 
 	prefs_register_string_preference ( tacplus_module, "key",
 	"TACACS+ Encryption Key", "TACACS+ Encryption Key", &tacplus_opt_key );
