@@ -3,7 +3,7 @@
  * By brooss <brooss.teambb@gmail.com>
  * Copyright 2008 brooss
  *
- * $Id: packet-teamspeak2.c 26356 2008-10-05 23:08:54Z wmeier $
+ * $Id: packet-teamspeak2.c 26925 2008-12-05 16:27:31Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -590,7 +590,18 @@ static void ts2_add_statusflags(tvbuff_t *tvb, proto_tree *ts2_tree, guint32 off
 static void ts2_parse_channelchange(tvbuff_t *tvb, proto_tree *ts2_tree);
 static void ts2_parse_loginpart2(tvbuff_t *tvb, proto_tree *ts2_tree);
 
+static void ts2_init(void) {
+	fragment_table_init(&msg_fragment_table);
+	reassembled_table_init(&msg_reassembled_table);
+    	if (conv_vals)
+		g_mem_chunk_destroy(conv_vals);
 
+	/* now create memory chunks */
+	conv_vals = g_mem_chunk_new("ts2_conv_vals",
+				    sizeof(ts2_conversation),
+				    my_init_count * sizeof(ts2_conversation),
+				    G_ALLOC_AND_FREE);
+}
 
 /* 
  * proto_register_ts2()
@@ -605,17 +616,8 @@ void proto_register_ts2(void)
 		);
 	proto_register_field_array(proto_ts2, hf, array_length(hf));
 	proto_register_subtree_array(ett, array_length(ett));
-	
-	fragment_table_init(&msg_fragment_table);
-	reassembled_table_init(&msg_reassembled_table);
-    	if (conv_vals)
-		g_mem_chunk_destroy(conv_vals);
 
-	/* now create memory chunks */
-	conv_vals = g_mem_chunk_new("ts2_conv_vals",
-				    sizeof(ts2_conversation),
-				    my_init_count * sizeof(ts2_conversation),
-				    G_ALLOC_AND_FREE);
+	register_init_routine(ts2_init);
 }
 
 /*
@@ -693,15 +695,16 @@ static void ts2_standard_dissect(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 	guint16 fragment_number;
 	ts2_frag *frag;
 	gboolean outoforder;
+
 	guint16 type = tvb_get_letohs(tvb, 2);
 	/*guint16 class = tvb_get_letohs(tvb, 0);*/
 	proto_tree_add_item(ts2_tree, hf_ts2_seqnum, tvb, 12, 4, TRUE);
 
-    
+	/* XXX: Following fragmentation stuff should be separate from the GUI stuff ??    */
 	/* Get our stored fragmentation data or create one! */
 	if ( ! ( frag = p_get_proto_data(pinfo->fd, proto_ts2) ) ) {
-        frag = se_alloc(sizeof(ts2_frag));
-        frag->frag_num=0;
+		frag = se_alloc(sizeof(ts2_frag));
+		frag->frag_num=0;
 	}
 
 	/* decide if the packet is server to client or client to server
@@ -766,60 +769,38 @@ static void ts2_standard_dissect(tvbuff_t *tvb, packet_info *pinfo, proto_tree *
 		switch(type)
 		{
 			case TS2T_LOGINPART2:
-			{
 				ts2_parse_loginpart2(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_CHANNELLIST:
-			{
 				ts2_parse_channellist(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_PLAYERLIST:
-			{
 				ts2_parse_playerlist(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_NEWPLAYERJOINED:
-			{
 				ts2_parse_newplayerjoined(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_KNOWNPLAYERUPDATE:
-			{
 				ts2_parse_knownplayerupdate(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_PLAYERLEFT:
-			{
 				ts2_parse_playerleft(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_PLAYERKICKED:
-			{
 				ts2_parse_playerleft(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_LOGINEND:
-			{
 				ts2_parse_loginend(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_CHANGESTATUS:
-			{
 				ts2_parse_changestatus(next_tvb, ts2_tree);
 				break;
-			}
 			case TS2T_SWITCHCHANNEL:
-			{
 				ts2_parse_switchchannel(next_tvb, ts2_tree);
 				break;	
-			}
 			case TS2T_CHANNELCHANGE:
-			{
 				ts2_parse_channelchange(next_tvb, ts2_tree);
 				break;
-			}
 		}
 	}
 	/* The packet is out of order, update the cinfo and ignore the packet */
@@ -1054,12 +1035,30 @@ static void dissect_ts2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		else
 			col_add_fstr(pinfo->cinfo, COL_INFO, "Type: %s, Class: %s", val_to_str(type, typenames, "Unknown (0x%02x)"), val_to_str(class, classnames, "Unknown (0x%02x)"));
 	}
+
+	/* XXX: We need to do all the non GUI stuff whether or not if(tree) */
+        /*      Do only once by checking visited ?                          */
+        /*      ToDo: Rewrite ??                                            */
+	if (!tree) {
+		switch(class) {
+			case TS2C_CONNECTION:
+				switch(type) {
+					case TS2T_LOGINREQUEST:
+						conversation_data->server_port=pinfo->destport;
+						conversation_data->server_addr=pinfo->dst;
+						break;
+				}
+				break;
+			case TS2C_STANDARD:
+				ts2_standard_dissect(tvb, pinfo, tree, conversation_data);
+				break;
+		}
+	}
+
 	if (tree) { /* we are being asked for details */
 		proto_item *ti = NULL;
 		proto_tree *ts2_tree = NULL;
 
-		
-
 		ti = proto_tree_add_item(tree, proto_ts2, tvb, 0, -1, TRUE);
 		ts2_tree = proto_item_add_subtree(ti, ett_ts2);
 		
@@ -1074,23 +1073,17 @@ static void dissect_ts2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		switch(class)
 		{
 			case TS2C_CONNECTION:
-			{
 				proto_tree_add_item(ts2_tree, hf_ts2_seqnum, tvb, 12, 4, TRUE);
 				ts2_add_checked_crc32(ts2_tree, hf_ts2_crc32, tvb, 16, tvb_get_letohl(tvb, 16));
 
 				switch(type)
 				{
 					case TS2T_PING:
-					{
 						break;
-					}
 					case TS2T_PINGREPLY:
-					{ 
 						proto_tree_add_item(ts2_tree, hf_ts2_ackto, tvb, 20, 4, TRUE);
 						break;
-					}
 					case TS2T_LOGINREQUEST:
-					{
 						proto_tree_add_item(ts2_tree, hf_ts2_protocol_string, tvb, 20, 1, TRUE);
 						proto_tree_add_item(ts2_tree, hf_ts2_platform_string, tvb, 50, 1, TRUE);
 						proto_tree_add_item(ts2_tree, hf_ts2_unknown, tvb, 80, 9, TRUE);
@@ -1103,9 +1096,7 @@ static void dissect_ts2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						conversation_data->server_addr=pinfo->dst;
 
 						break;
-					}
 					case TS2T_LOGINREPLY:
-					{
 						proto_tree_add_item(ts2_tree, hf_ts2_server_name, tvb, 20, 1, TRUE);
 						proto_tree_add_item(ts2_tree, hf_ts2_platform_string, tvb, 50, 1, TRUE);
 						proto_tree_add_item(ts2_tree, hf_ts2_unknown, tvb, 80, 9, TRUE);
@@ -1114,25 +1105,19 @@ static void dissect_ts2(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 						proto_tree_add_item(ts2_tree, hf_ts2_sessionkey, tvb, 172, 4, TRUE);
 						proto_tree_add_item(ts2_tree, hf_ts2_unknown, tvb, 178, 3, TRUE);
 						proto_tree_add_item(ts2_tree, hf_ts2_server_welcome_message, tvb, 180, 1, TRUE);
-	
-					}
+                                                break;
 				}
 				break;
-			}
 			case TS2C_ACK:
-			{
 				/* Ignore the type for ACK, its always zero and clashes with CELP_5_1 */
 				
 				proto_tree_add_item(ts2_tree, hf_ts2_seqnum, tvb, 12, 4, TRUE);
 				break;
-			}
 			case TS2C_STANDARD:
-			{
 				ts2_standard_dissect(tvb, pinfo, ts2_tree, conversation_data);
-			}
-			break;
+				break;
 		}
-	}	
+	} /* if (tree) */	
 }
 
 
