@@ -1,7 +1,7 @@
 /* packet-tnef.c
  * Routines for Transport-Neutral Encapsulation Format (TNEF) packet disassembly
  *
- * $Id: packet-tnef.c 26308 2008-09-30 14:49:44Z wmeier $
+ * $Id: packet-tnef.c 26883 2008-11-30 13:25:14Z stig $
  *
  * Copyright (c) 2007 by Graeme Lunt
  *
@@ -34,11 +34,14 @@
 #include <time.h>
 #include <glib.h>
 #include <string.h>
+
 #include <epan/packet.h>
 #include <epan/conversation.h>
 #include <epan/addr_resolv.h>
 #include <epan/strutil.h>
 
+#include <wiretap/tnef.h>
+
 #include "packet-dcerpc.h"
 #include "packet-dcerpc-nspi.h"
 #include "packet-ber.h"
@@ -47,8 +50,6 @@
 #define PSNAME "TNEF"
 #define PFNAME "tnef"
 
-#define TNEF_SIGNATURE 0x223E9F78
-
 #define ATP_TRIPLES   (0x0000)
 #define ATP_STRING    (0x0001)
 #define ATP_TEXT      (0x0002)
@@ -146,6 +147,8 @@ static int hf_tnef_PropValue_i = -1;
 static int hf_tnef_PropValue_l = -1;
 static int hf_tnef_PropValue_b = -1;
 static int hf_tnef_PropValue_lpszA = -1;
+static int hf_tnef_PropValue_lpszW = -1;
+static int hf_tnef_PropValue_lpguid = -1;
 static int hf_tnef_PropValue_bin = -1;
 static int hf_tnef_PropValue_ft = -1;
 static int hf_tnef_PropValue_err = -1;
@@ -244,7 +247,7 @@ static const value_string tnef_Attribute_vals[] = {
 	{ 0, NULL }
 };
 
-static gint dissect_counted_values(tvbuff_t *tvb, gint offset, int hf_id,  packet_info *pinfo _U_, proto_tree *tree, gboolean single)
+static gint dissect_counted_values(tvbuff_t *tvb, gint offset, int hf_id,  packet_info *pinfo _U_, proto_tree *tree, gboolean single, gboolean unicode)
 {
 	 proto_item *item;
 	 guint32 length, count, i;
@@ -270,7 +273,12 @@ static gint dissect_counted_values(tvbuff_t *tvb, gint offset, int hf_id,  packe
 		 proto_tree_add_item(tree, hf_tnef_value_length, tvb, offset, 4, TRUE);
 		 offset += 4;
 
-		 proto_tree_add_item(tree, hf_id, tvb, offset, length, FALSE);
+		 if (unicode) {
+			 char *unicode_str = tvb_get_ephemeral_faked_unicode(tvb, offset, length/2, TRUE);
+			 proto_tree_add_string(tree, hf_id, tvb, offset, length, unicode_str);
+		 } else {
+			 proto_tree_add_item(tree, hf_id, tvb, offset, length, FALSE);
+		 }
 		 offset += length;
 
 		 /* XXX: may be padding ? */
@@ -432,16 +440,16 @@ static void dissect_mapiprops(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tre
 				offset = PIDL_dissect_uint16(tvb, offset, pinfo, prop_tree, drep, hf_tnef_PropValue_b, 0);
 				break;
 			case PT_STRING8:
-				offset = dissect_counted_values(tvb, offset, hf_tnef_PropValue_lpszA, pinfo, prop_tree, TRUE);
+				offset = dissect_counted_values(tvb, offset, hf_tnef_PropValue_lpszA, pinfo, prop_tree, TRUE, FALSE);
 				break;
 			case PT_BINARY:
-				offset = dissect_counted_values(tvb, offset, hf_tnef_PropValue_bin, pinfo, prop_tree, TRUE);
+				offset = dissect_counted_values(tvb, offset, hf_tnef_PropValue_bin, pinfo, prop_tree, TRUE, FALSE);
 				break;
-			case PT_UNICODE: /* XXX */
-				/* offset = nspi_dissect_element_SPropValue_CTR_lpszW(tvb, offset, pinfo, prop_tree, drep); */
+			case PT_UNICODE:
+				offset = dissect_counted_values (tvb, offset, hf_tnef_PropValue_lpszW, pinfo, prop_tree, TRUE, TRUE);
 				break;
-			case PT_CLSID: /* XXX */
-				/* offset = nspi_dissect_element_SPropValue_CTR_lpguid(tvb, offset, pinfo, prop_tree, drep); */
+			case PT_CLSID:
+				offset = nspi_dissect_struct_MAPIUID(tvb, offset, pinfo, prop_tree, drep, hf_tnef_PropValue_lpguid, 0);
 				break;
 			case PT_SYSTIME:
 				offset = nspi_dissect_struct_FILETIME(tvb,offset,pinfo,prop_tree,drep,hf_tnef_PropValue_ft,0);
@@ -629,6 +637,20 @@ static void dissect_tnef(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
     proto_tree_add_item(tree, hf_tnef_padding, tvb, offset, tvb_length_remaining(tvb, offset), TRUE);    
 }
 
+static void dissect_tnef_file(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
+{
+  if (check_col(pinfo->cinfo, COL_PROTOCOL))
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, PSNAME);
+
+  if (check_col(pinfo->cinfo, COL_DEF_SRC))
+    col_set_str(pinfo->cinfo, COL_DEF_SRC, PSNAME " encoded file");
+
+  if (check_col(pinfo->cinfo, COL_INFO))
+    col_append_str(pinfo->cinfo, COL_INFO, PNAME);
+
+  dissect_tnef(tvb, pinfo, tree);
+}
+
 /* Register all the bits needed by the filtering engine */
 
 void
@@ -759,6 +781,10 @@ proto_register_tnef(void)
       { "B", "tnef.PropValue.b", FT_UINT16, BASE_DEC, NULL, 0, "", HFILL }},
     { &hf_tnef_PropValue_lpszA, 
       { "Lpsza", "tnef.PropValue.lpszA", FT_STRING, BASE_NONE, NULL, 0, "", HFILL }},
+    { &hf_tnef_PropValue_lpszW, 
+      { "Lpszw", "tnef.PropValue.lpszW", FT_STRING, BASE_NONE, NULL, 0, "", HFILL }},
+    { &hf_tnef_PropValue_lpguid, 
+      { "Lpguid", "tnef.PropValue.lpguid", FT_NONE, BASE_NONE, NULL, 0, "", HFILL }},
     { &hf_tnef_PropValue_bin, 
       { "Bin", "tnef.PropValue.bin", FT_NONE, BASE_NONE, NULL, 0, "", HFILL }},
     { &hf_tnef_PropValue_ft, 
@@ -810,12 +836,15 @@ proto_register_tnef(void)
 void
 proto_reg_handoff_tnef(void)
 {
-  dissector_handle_t tnef_handle;
+  dissector_handle_t tnef_handle, tnef_file_handle;
 
   tnef_handle = find_dissector(PFNAME);
+  tnef_file_handle = create_dissector_handle(dissect_tnef_file, proto_tnef);
+
   dissector_add_string("media_type", "application/ms-tnef", tnef_handle);
 
   /* X.400 file transfer bodypart */
   register_ber_oid_dissector("1.2.840.113556.3.10.1", dissect_tnef, proto_tnef, "id-et-tnef");
 
+  dissector_add("wtap_encap", WTAP_ENCAP_TNEF, tnef_file_handle);
 }
