@@ -2,7 +2,7 @@
  * Routines for Token-Ring packet disassembly
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
- * $Id: packet-tr.c 25308 2008-05-15 13:22:06Z wmeier $
+ * $Id: packet-tr.c 26822 2008-11-22 15:55:01Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -326,10 +326,10 @@ dissect_tr(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
 	proto_tree	*tr_tree, *bf_tree;
 	proto_item	*ti, *hidden_item;
-	int		frame_type;
 	guint8		rcf1, rcf2;
 	tvbuff_t	*next_tvb;
 
+	volatile int		frame_type;
 	volatile int		fixoffset = 0;
 	volatile int		source_routed = 0;
 	volatile guint8		trn_rif_bytes;
