@@ -1,7 +1,7 @@
 /* packet-udp.c
  * Routines for UDP/UDPLite packet disassembly
  *
- * $Id: packet-udp.c 26308 2008-09-30 14:49:44Z wmeier $
+ * $Id: packet-udp.c 27038 2008-12-17 19:27:19Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -216,7 +216,7 @@ dissect(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree, guint32 ip_proto)
         get_udp_port(udph->uh_sport), udph->uh_sport, get_udp_port(udph->uh_dport), udph->uh_dport);
       }
     } else {
-      ti = proto_tree_add_item(tree, proto_udp, tvb, offset, 8, FALSE);
+      ti = proto_tree_add_item(tree, (ip_proto == IP_PROTO_UDP) ? proto_udp : proto_udplite, tvb, offset, 8, FALSE);
     }
     udp_tree = proto_item_add_subtree(ti, ett_udp);
 
