@@ -2,7 +2,7 @@
  * Allow users to specify the dissectors for DLTs
  * Luis E. Garcia Ontanon <luis@ontanon.org>
  *
- * $Id: packet-user_encap.c 26280 2008-09-26 20:06:40Z wmeier $
+ * $Id: packet-user_encap.c 27028 2008-12-17 00:08:38Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -97,9 +97,9 @@ static void dissect_user(tvbuff_t* tvb, packet_info* pinfo, proto_tree* tree) {
 	if (!encap) {
 		char* msg = ep_strdup_printf("User encapsulation not handled: DLT=%d, check your Preferences->Protocols->DLT_USER",
 									 pinfo->match_port + 147 - WTAP_ENCAP_USER0);
-		proto_item* item = proto_tree_add_text(tree, tvb, 0, 0, msg);
+		proto_item* item = proto_tree_add_text(tree, tvb, 0, 0, "%s", msg);
 		
-		expert_add_info_format(pinfo, item, PI_UNDECODED, PI_WARN, msg);
+		expert_add_info_format(pinfo, item, PI_UNDECODED, PI_WARN, "%s", msg);
 		
 		call_dissector(data_handle, tvb, pinfo, tree);
 		return;
@@ -185,7 +185,7 @@ void proto_register_user_encap(void)
 	prefs_register_uat_preference(module,
 				      "encaps_table",
 				      "Encapsulations Table",
-				      "A table that enumerates the various protocols to be used against a cartain user DLT",
+				      "A table that enumerates the various protocols to be used against a certain user DLT",
 				      encaps_uat);
 	
 	
