@@ -1,7 +1,7 @@
 /* packet-vj.c
  * Routines for Van Jacobson header decompression.  (See RFC 1144.)
  *
- * $Id: packet-vj.c 18196 2006-05-21 04:49:01Z sahlberg $
+ * $Id: packet-vj.c 27191 2009-01-08 07:32:22Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -225,7 +225,7 @@ dissect_vjuc(tvbuff_t *tvb, packet_info *pinfo, proto_tree * tree)
   gint        ipsize;
 
   if(check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_INFO, "PPP VJ");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "PPP VJ");
 
   if(tree != NULL) {
     ti = proto_tree_add_protocol_format(tree, proto_vj, tvb, 0, -1,
@@ -407,7 +407,7 @@ dissect_vjc(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   gint        err      = VJ_ERROR;
 
   if(check_col(pinfo->cinfo, COL_PROTOCOL))
-    col_set_str(pinfo->cinfo, COL_INFO, "PPP VJ");
+    col_set_str(pinfo->cinfo, COL_PROTOCOL, "PPP VJ");
 
   if(tree != NULL) {
     ti = proto_tree_add_protocol_format(tree, proto_vj, tvb, 0, -1,
@@ -561,9 +561,8 @@ vjc_tvb_setup(tvbuff_t *src_tvb,
   vj_header_t *hdr_buf;
   guint8       offset;
   guint8      *data_ptr;
-  iphdr_type  *ip;
-  tcphdr_type *thp;
   gint         hdr_len;
+  gint         tot_len;
   gint         buf_len;
   guint8      *pbuf;
 
@@ -585,15 +584,14 @@ vjc_tvb_setup(tvbuff_t *src_tvb,
 
   /* Copy header and form tvb */
   data_ptr = hdr_buf->data;
-  ip = (iphdr_type *)data_ptr;
-  hdr_len  = lo_nibble(ip->ihl_version) * 4;
-  thp = (tcphdr_type *)(data_ptr + hdr_len);
-  hdr_len += TCP_OFFSET(thp) * 4;
+  hdr_len  = lo_nibble(data_ptr[0]) * 4;
+  hdr_len += hi_nibble(data_ptr[hdr_len + 12]) * 4;
   buf_len  = tvb_length(src_tvb) + hdr_len - offset;
   pbuf     = g_malloc(buf_len);
   memcpy(pbuf, data_ptr, hdr_len);
   tvb_memcpy(src_tvb, pbuf + hdr_len, offset, buf_len - hdr_len);
-  *dst_tvb = tvb_new_real_data(pbuf, buf_len, g_ntohs(ip->tot_len));
+  memcpy(&tot_len, data_ptr + 2, 2);
+  *dst_tvb = tvb_new_real_data(pbuf, buf_len, g_ntohs(tot_len));
   tvb_set_child_real_data_tvbuff(src_tvb, *dst_tvb);
   add_new_data_source(pinfo, *dst_tvb, "VJ Decompressed");
   return VJ_OK;
