@@ -1,7 +1,7 @@
 /* packet-vlan.c
  * Routines for VLAN 802.1Q ethernet header disassembly
  *
- * $Id: packet-vlan.c 26307 2008-09-30 14:46:48Z wmeier $
+ * $Id: packet-vlan.c 26822 2008-11-22 15:55:01Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -74,7 +74,8 @@ static void
 dissect_vlan(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
   proto_tree *ti;
-  guint16 tci,encap_proto;
+  guint16 tci;
+  volatile guint16 encap_proto;
   volatile gboolean is_802_2;
   proto_tree *volatile vlan_tree;
 
