@@ -12,7 +12,7 @@
  *
  * Copyright 2007 Jens Braeuer <jensb@cs.tu-berlin.de>
  *
- * $Id: packet-wps.c 26214 2008-09-16 05:43:36Z jake $
+ * $Id: packet-wps.c 27095 2008-12-23 17:39:19Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1126,14 +1126,18 @@ dissect_wps_tlvs(proto_tree *eap_tree, tvbuff_t *tvb, int offset,
       break;
 
     case WPS_TLV_TYPE_UUID_E:
-      tmp_item = proto_tree_add_item(tlv_root, hf_eapwps_tlv_uuid_e, tvb, offset+4, 8, FALSE);
+      tmp_item = proto_tree_add_item(tlv_root, hf_eapwps_tlv_uuid_e, tvb, offset+4, tlv_len, FALSE);
       hfindex = hf_eapwps_tlv_uuid_e;
+      if (tlv_len > 16 && pinfo) 
+	expert_add_info_format(pinfo, tmp_item, PI_MALFORMED, PI_ERROR, fmt_warn_too_long, tlv_len);
 
       break;
 
     case WPS_TLV_TYPE_UUID_R:
-      tmp_item = proto_tree_add_item(tlv_root, hf_eapwps_tlv_uuid_r, tvb, offset+4, 8, FALSE);
+      tmp_item = proto_tree_add_item(tlv_root, hf_eapwps_tlv_uuid_r, tvb, offset+4, tlv_len, FALSE);
       hfindex = hf_eapwps_tlv_uuid_r;
+      if (tlv_len > 16 && pinfo) 
+	expert_add_info_format(pinfo, tmp_item, PI_MALFORMED, PI_ERROR, fmt_warn_too_long, tlv_len);
 
       break;
 
@@ -1376,7 +1380,7 @@ dissect_exteap_wps(proto_tree *eap_tree, tvbuff_t *tvb, int offset,
 
   pi = proto_item_get_parent(pi);
   if (pi != NULL) 
-    proto_item_append_text(pi, " (Wifi Allicance, WifiProtectedSetup)");
+    proto_item_append_text(pi, " (Wifi Alliance, WifiProtectedSetup)");
   if (pinfo != NULL && check_col(pinfo->cinfo, COL_INFO))
     col_append_fstr(pinfo->cinfo, COL_INFO, ", WPS");
 
