@@ -2,7 +2,7 @@
  * Routines for X.25 packet disassembly
  * Olivier Abad <oabad@noos.fr>
  *
- * $Id: packet-x25.c 25874 2008-07-30 14:50:17Z etxrab $
+ * $Id: packet-x25.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -544,7 +544,7 @@ static const char *clear_diag(unsigned char code)
     if (code == 248)
 	return "Connection rejection - incompatible information in user data";
     if (code == 249)
-	return "Connection rejection - unrecognizable protocol indentifier "
+	return "Connection rejection - unrecognizable protocol identifier "
                "in user data";
     if (code == 250)
 	return "Reset - user resynchronization";
@@ -704,7 +704,7 @@ dump_facilities(proto_tree *tree, int *offset, tvbuff_t *tvb)
 		    else
 			proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
 				"00.. .... = Fast select not requested");
-		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1, "%s",
 			    decode_boolean_bitfield(byte1, 0x01, 1*8,
 				"Reverse charging requested",
 				"Reverse charging not requested"));
@@ -718,7 +718,7 @@ dump_facilities(proto_tree *tree, int *offset, tvbuff_t *tvb)
 		    byte1 = tvb_get_guint8(tvb, *offset + 1);
 		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
 			    "Parameter : %02X", byte1);
-		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1, "%s",
 			    decode_boolean_bitfield(byte1, 0x01, 1*8,
 				"Charging information requested",
 				"Charging information not requested"));
@@ -756,7 +756,7 @@ dump_facilities(proto_tree *tree, int *offset, tvbuff_t *tvb)
 		    default:
 			g_snprintf(tmpbuf, 80, "From the called DTE : %%u (Reserved)");
 		    }
-		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1, "%s",
 			    decode_numeric_bitfield(byte1, 0xF0, 1*8, tmpbuf));
 		    switch (byte1 & 0x0F)
 		    {
@@ -781,7 +781,7 @@ dump_facilities(proto_tree *tree, int *offset, tvbuff_t *tvb)
 		    default:
 			g_snprintf(tmpbuf, 80, "From the calling DTE : %%u (Reserved)");
 		    }
-		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1, "%s",
 			    decode_numeric_bitfield(byte1, 0x0F, 1*8, tmpbuf));
 		}
 		break;
@@ -904,7 +904,7 @@ dump_facilities(proto_tree *tree, int *offset, tvbuff_t *tvb)
 			g_snprintf(tmpbuf, 80, "From the called DTE : %%u (Unknown)");
 			break;
 		    }
-		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1, "%s",
 			    decode_numeric_bitfield(byte1, 0x0F, 1*8, tmpbuf));
 
 		    byte2 = tvb_get_guint8(tvb, *offset + 2);
@@ -941,7 +941,7 @@ dump_facilities(proto_tree *tree, int *offset, tvbuff_t *tvb)
 			g_snprintf(tmpbuf, 80, "From the calling DTE : %%u (Unknown)");
 			break;
 		    }
-		    proto_tree_add_text(fac_subtree, tvb, *offset+2, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+2, 1, "%s",
 			    decode_numeric_bitfield(byte2, 0x0F, 1*8, tmpbuf));
 		}
 		break;
@@ -950,10 +950,10 @@ dump_facilities(proto_tree *tree, int *offset, tvbuff_t *tvb)
 		    ti = proto_tree_add_text(fac_tree, tvb, *offset, 1, "Code : %02X "
 			    "(Window size)", fac);
 		    fac_subtree = proto_item_add_subtree(ti, ett_x25_fac_window_size);
-		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+1, 1, "%s",
 			    decode_numeric_bitfield(tvb_get_guint8(tvb, *offset+1),
 				0x7F, 1*8, "From the called DTE: %u"));
-		    proto_tree_add_text(fac_subtree, tvb, *offset+2, 1,
+		    proto_tree_add_text(fac_subtree, tvb, *offset+2, 1, "%s",
 			    decode_numeric_bitfield(tvb_get_guint8(tvb, *offset+2),
 				0x7F, 1*8, "From the calling DTE: %u"));
 		}
@@ -1393,12 +1393,12 @@ x25_ntoa(proto_tree *tree, int *offset, tvbuff_t *tvb,
     len2 = (byte >> 4) & 0x0F;
 
     if (tree) {
-	proto_tree_add_text(tree, tvb, *offset, 1,
+	proto_tree_add_text(tree, tvb, *offset, 1, "%s",
 		decode_numeric_bitfield(byte, 0xF0, 1*8,
 			is_registration ?
 		          "DTE address length : %u" :
 		          "Calling address length : %u"));
-	proto_tree_add_text(tree, tvb, *offset, 1,
+	proto_tree_add_text(tree, tvb, *offset, 1, "%s",
 		decode_numeric_bitfield(byte, 0x0F, 1*8,
 			is_registration ?
 		          "DCE address length : %u" :
