@@ -3,7 +3,7 @@
  *
  * (C) 2005, Luis E. Garcia Ontanon.
  *
- * $Id: packet-xml.c 26261 2008-09-24 10:42:24Z kukosa $
+ * $Id: packet-xml.c 27024 2008-12-16 14:18:55Z wmeier $
  *
  * Refer to the AUTHORS file or the AUTHORS section in the man page
  * for contacting the author(s) of this file.
@@ -292,7 +292,7 @@ static void after_xmlpi(void* tvbparse_data, const void* wanted_data _U_, tvbpar
 	xml_frame_t* current_frame = g_ptr_array_index(stack,stack->len - 1);
 
 	proto_tree_add_text(current_frame->tree,
-						   tok->tvb, tok->offset, tok->len,
+						   tok->tvb, tok->offset, tok->len, "%s",
 						   tvb_format_text(tok->tvb,tok->offset,tok->len));
 
 	if (stack->len > 1) {
@@ -964,7 +964,7 @@ next_attribute:
 	} else {
 		/*
 		 * if we were given a proto_name the namespace will be registered
-		 * as an indipendent protocol with its own hf and ett arrays.
+		 * as an independent protocol with its own hf and ett arrays.
 		 */
 		hfs = g_array_new(FALSE,FALSE,sizeof(hf_register_info));
 		etts = g_array_new(FALSE,FALSE,sizeof(gint*));
@@ -1059,7 +1059,7 @@ next_attribute:
 
 	/*
 	 * if we were given a proto_name the namespace will be registered
-	 * as an indipendent protocol.
+	 * as an independent protocol.
 	 */
 	if( dtd_data->proto_name ) {
 		gint* ett_p;
