@@ -2,7 +2,7 @@
  * Routines for Xpress Transport Protocol dissection
  * Copyright 2008, Shigeo Nakamura <naka_shigeo@yahoo.co.jp>
  *
- * $Id: packet-xtp.c 26281 2008-09-26 22:07:45Z wmeier $
+ * $Id: packet-xtp.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -84,7 +84,7 @@ static const value_string pformat_vals[] = {
 
 static const value_string diag_code_vals[] = {
 	{ 1, "Context Refused" },
-	{ 2, "Context Abaondoned" },
+	{ 2, "Context Abandoned" },
 	{ 3, "Invalid Context" },
 	{ 4, "Request Refused" },
 	{ 5, "Join Refused" },
@@ -107,7 +107,7 @@ static const value_string diag_val_vals[] = {
 	{ 10, "Host going down" },
 	{ 11, "Invalid retransmission request" },
 	{ 12, "Context in improper state" },
-	{ 13, "Joing request denied" },
+	{ 13, "Join request denied" },
 	{ 0, NULL }
 };
 
