@@ -3,7 +3,7 @@
  * Copyright 2003, Wayne Parrott <wayne_p@pacific.net.au>
  * Copied from packet-yhoo.c and updated
  *
- * $Id: packet-ymsg.c 21829 2007-05-18 17:25:26Z martinm $
+ * $Id: packet-ymsg.c 27065 2008-12-20 00:09:02Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -531,8 +531,8 @@ proto_register_ymsg(void)
 
 	ymsg_module = prefs_register_protocol(proto_ymsg, NULL);
 	prefs_register_bool_preference(ymsg_module, "desegment",
-				       "Reasssemble YMSG messages spanning multiple TCP segments",
-				       "Whether the YMSG dissector should reasssemble messages spanning multiple TCP segments. "
+				       "Reassemble YMSG messages spanning multiple TCP segments",
+				       "Whether the YMSG dissector should reassemble messages spanning multiple TCP segments. "
 				       "To use this option, you must also enable \"Allow subdissectors to reassemble TCP streams\" in the TCP protocol settings.",
 				       &ymsg_desegment);
 }
