@@ -2,7 +2,7 @@
  * Wireshark memory management and garbage collection functions
  * Ronnie Sahlberg 2005
  *
- * $Id: emem.c 24596 2008-03-10 07:53:46Z jake $
+ * $Id: emem.c 25927 2008-08-05 02:23:35Z lego $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -42,9 +42,9 @@
 #endif
 
 #include <glib.h>
+
 #include <proto.h>
 #include "emem.h"
-#include <wiretap/file_util.h>
 
 #ifdef _WIN32
 #include <windows.h>	/* VirtualAlloc, VirtualProtect */
@@ -101,6 +101,8 @@ static int dev_zero_fd;
 #ifdef DEBUG_USE_CANARIES
 #define EMEM_CANARY_SIZE 8
 #define EMEM_CANARY_DATA_SIZE (EMEM_CANARY_SIZE * 2 - 1)
+
+/* this should be static, but if it were gdb would had problems finding it */
 guint8  ep_canary[EMEM_CANARY_DATA_SIZE], se_canary[EMEM_CANARY_DATA_SIZE];
 #endif /* DEBUG_USE_CANARIES */
 
@@ -125,8 +127,8 @@ typedef struct _emem_header_t {
   emem_chunk_t *used_list;
 } emem_header_t;
 
-emem_header_t ep_packet_mem;
-emem_header_t se_packet_mem;
+static emem_header_t ep_packet_mem;
+static emem_header_t se_packet_mem;
 
 #if !defined(SE_DEBUG_FREE)
 #if defined (_WIN32)
@@ -145,13 +147,8 @@ static intptr_t pagesize;
 void
 emem_canary(guint8 *canary) {
 	int i;
-#if GLIB_MAJOR_VERSION >= 2
 	static GRand   *rand_state = NULL;
-#endif
 
-
-	/* First, use GLib's random function if we have it */
-#if GLIB_MAJOR_VERSION >= 2
 	if (rand_state == NULL) {
 		rand_state = g_rand_new();
 	}
@@ -159,26 +156,6 @@ emem_canary(guint8 *canary) {
 		canary[i] = (guint8) g_rand_int(rand_state);
 	}
 	return;
-#else
-	FILE *fp;
-	size_t sz;
-	/* Try /dev/urandom */
-	if ((fp = eth_fopen("/dev/urandom", "r")) != NULL) {
-		setbuf(fp, NULL);
-		sz = fread(canary, 1, EMEM_CANARY_DATA_SIZE, fp);
-		fclose(fp);
-		if (sz == EMEM_CANARY_DATA_SIZE) {
-			return;
-		}
-	}
-
-	/* Our last resort */
-	srandom(time(NULL) | getpid());
-	for (i = 0; i < EMEM_CANARY_DATA_SIZE; i ++) {
-		canary[i] = (guint8) random();
-	}
-	return;
-#endif /* GLIB_MAJOR_VERSION >= 2 */
 }
 
 #if !defined(SE_DEBUG_FREE)
@@ -199,6 +176,50 @@ emem_canary_pad (size_t allocation) {
 #endif
 #endif /* DEBUG_USE_CANARIES */
 
+/* used for debugging canaries, will block */
+#ifdef DEBUG_INTENSE_CANARY_CHECKS
+gboolean intense_canary_checking = FALSE;
+
+/*  used to intensivelly check ep canaries
+ */
+void ep_check_canary_integrity(const char* fmt, ...) {
+    va_list ap;
+    static gchar there[128] = {
+        'L','a','u','n','c','h',0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,
+        0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0 };
+    gchar here[128];
+	emem_chunk_t* npc = NULL;
+
+    if (! intense_canary_checking ) return;
+
+    here[126] = '\0';
+    here[127] = '\0';
+    
+    va_start(ap,fmt);
+    g_vsnprintf(here, 126,fmt, ap);
+    va_end(ap);
+    
+	for (npc = ep_packet_mem.free_list; npc != NULL; npc = npc->next) {
+        static unsigned i_ctr;
+
+        if (npc->c_count > 0x00ffffff) {
+            g_error("ep_packet_mem.free_list was corrupted\nbetween: %s\nand: %s",there, here);
+        }
+        
+		for (i_ctr = 0; i_ctr < npc->c_count; i_ctr++) {
+			if (memcmp(npc->canary[i_ctr], &ep_canary, npc->cmp_len[i_ctr]) != 0) {
+				g_error("Per-packet memory corrupted\nbetween: %s\nand: %s",there, here);
+            }
+		}
+    }
+    
+    strncpy(there,here,126);
+    
+}
+#endif
+
 
 /* Initialize the packet-lifetime memory allocation pool.
  * This function should be called only once when Wireshark or TShark starts
@@ -210,6 +231,10 @@ ep_init_chunk(void)
 	ep_packet_mem.free_list=NULL;
 	ep_packet_mem.used_list=NULL;
 
+#ifdef DEBUG_INTENSE_CANARY_CHECKS
+    intense_canary_checking = (gboolean)getenv("WIRESHARK_DEBUG_EP_CANARY");
+#endif
+    
 #ifdef DEBUG_USE_CANARIES
 	emem_canary(ep_canary);
 #endif /* DEBUG_USE_CANARIES */
@@ -234,7 +259,7 @@ ep_init_chunk(void)
 #elif defined(USE_GUARD_PAGES)
 	pagesize = sysconf(_SC_PAGESIZE);
 #ifdef NEED_DEV_ZERO
-	dev_zero_fd = open("/dev/zero", O_RDWR);
+	dev_zero_fd = ws_open("/dev/zero", O_RDWR);
 	g_assert(dev_zero_fd != -1);
 #endif
 #endif /* _WIN32 / USE_GUARD_PAGES */
@@ -693,6 +718,7 @@ gchar* se_strdup_printf(const gchar* fmt, ...) {
 	return dst;
 }
 
+
 /* release all allocated memory back to the pool.
  */
 void
@@ -1345,7 +1371,7 @@ se_tree_create_non_persistent(int type, const char *name)
 /* This tree is PErmanent and will never be released
  */
 emem_tree_t *
-pe_tree_create(int type, char *name)
+pe_tree_create(int type, const char *name)
 {
 	emem_tree_t *tree_list;
 
@@ -1363,7 +1389,7 @@ pe_tree_create(int type, char *name)
  * as the parent tree.
  */
 static emem_tree_t *
-emem_tree_create_subtree(emem_tree_t *parent_tree, char *name)
+emem_tree_create_subtree(emem_tree_t *parent_tree, const char *name)
 {
 	emem_tree_t *tree_list;
 
@@ -1435,7 +1461,7 @@ emem_tree_lookup32_array(emem_tree_t *se_tree, emem_tree_key_t *key)
 
 
 /* Strings are stored as an array of uint32 containing the string characters
-   with 4 characters in each uint32. 
+   with 4 characters in each uint32.
    The first byte of the string is stored as the most significant byte.
    If the string is not a multiple of 4 characters in length the last
    uint32 containing the string bytes are padded with 0 bytes.
@@ -1470,7 +1496,7 @@ emem_tree_insert_string(emem_tree_t* se_tree, const gchar* k, void* v, guint32 f
 		if (i%4 == 3) {
 			aligned[i/4] = tmp;
 			tmp = 0;
-		}		
+		}
 	}
 	/* add required padding to the last uint32 */
 	if (i%4 != 0) {
@@ -1480,7 +1506,7 @@ emem_tree_insert_string(emem_tree_t* se_tree, const gchar* k, void* v, guint32 f
 		}
 		aligned[i/4-1] = tmp;
 	}
-	
+
 	/* add the terminator */
 	aligned[div-1] = 0x00000001;
 
@@ -1523,7 +1549,7 @@ emem_tree_lookup_string(emem_tree_t* se_tree, const gchar* k, guint32 flags)
 		if (i%4 == 3) {
 			aligned[i/4] = tmp;
 			tmp = 0;
-		}		
+		}
 	}
 	/* add required padding to the last uint32 */
 	if (i%4 != 0) {
@@ -1533,7 +1559,7 @@ emem_tree_lookup_string(emem_tree_t* se_tree, const gchar* k, guint32 flags)
 		}
 		aligned[i/4-1] = tmp;
 	}
-	
+
 	/* add the terminator */
 	aligned[div-1] = 0x00000001;
 
