@@ -1,5 +1,5 @@
 /*
- * $Id: ftype-integer.c 24288 2008-02-08 05:45:46Z sfisher $
+ * $Id: ftype-integer.c 25423 2008-06-04 01:30:40Z guy $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -29,22 +29,6 @@
 #include "ftypes-int.h"
 #include <epan/addr_resolv.h>
 
-#ifdef NEED_G_ASCII_STRTOULL_H
-#include "g_ascii_strtoull.h"
-#endif
-
-/*
- * GLib 1.2[.x] doesn't define G_MAXUINT32 or G_MAXUINT64; if they're
- * not defined, we define them as the maximum 32-bit and 64-bit
- * unsigned numbers.
- */
-#ifndef G_MAXUINT32
-#define G_MAXUINT32	((guint32)0xFFFFFFFFU)
-#endif
-#ifndef G_MAXUINT64
-#define G_MAXUINT64	((guint64)G_GINT64_CONSTANT(0xFFFFFFFFFFFFFFFFU))
-#endif
-
 static void
 int_fvalue_new(fvalue_t *fv)
 {
