@@ -1,7 +1,7 @@
 /* oui.h
  * Definitions of OUIs
  *
- * $Id: oui.h 19262 2006-09-20 06:13:02Z etxrab $
+ * $Id: oui.h 26040 2008-08-19 08:07:45Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -46,6 +46,7 @@
 #define OUI_SONY_ERICSSON_2	0x000E07	/* Sony Ericsson Mobile Communications AB */
 #define OUI_PROFINET		0x000ECF	/* PROFIBUS Nutzerorganisation e.V. */
 #define OUI_SONY_ERICSSON_3	0x000FDE	/* Sony Ericsson Mobile Communications AB */
+#define OUI_CIMETRICS		0x001090	/* Cimetrics, Inc. */
 #define OUI_IEEE_802_3		0x00120F	/* IEEE 802.3 */
 #define OUI_MEDIA_ENDPOINT	0x0012BB	/* Media (TIA TR-41 Committee) */
 #define OUI_SONY_ERICSSON_4	0x0012EE	/* Sony Ericsson Mobile Communications AB */
@@ -55,6 +56,7 @@
 #define OUI_SONY_ERICSSON_7	0x001813	/* Sony Ericsson Mobile Communications AB */
 #define OUI_SONY_ERICSSON_8	0x001963	/* Sony Ericsson Mobile Communications AB */
 #define OUI_CISCOWL			0x004096	/* Cisco Wireless (Aironet) */
+#define	OUI_MARVELL			0x005043	/* Marvell Semiconductor */
 #define OUI_ERICSSON_2		0x008037	/* Ericsson Group */	
 #define OUI_BRIDGED			0x0080C2	/* Bridged Frame-Relay, RFC 2427 */
 										/* and Bridged ATM, RFC 2684 */
@@ -65,6 +67,7 @@
 #define	OUI_SIEMENS			0x080006	/* Siemens AG */
 #define	OUI_APPLE_ATALK		0x080007	/* Appletalk */
 #define	OUI_HP				0x080009	/* Hewlett-Packard */
+#define	OUI_TURBOCELL		0x0020F6	/* KarlNet, who brought you Turbocell */
 
 /* 
  * Defined in packet-llc.c
