@@ -1,7 +1,7 @@
 /* packet.h
  * Definitions for packet disassembly structures and routines
  *
- * $Id: packet.h 25986 2008-08-12 04:44:35Z etxrab $
+ * $Id: packet.h 26659 2008-10-31 18:44:46Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -407,7 +407,7 @@ extern void dissector_dump_decodes(void);
  * dissector has been called.
  */
 extern void register_postdissector(dissector_handle_t);
-extern gboolean have_postdissector();
+extern gboolean have_postdissector(void);
 extern void call_all_postdissectors(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree);
 
 #ifdef __cplusplus
