@@ -1,7 +1,7 @@
 /* prefs.h
  * Definitions for preference handling routines
  *
- * $Id: prefs.h 26371 2008-10-07 15:18:40Z stig $
+ * $Id: prefs.h 27166 2009-01-06 14:34:18Z rbalint $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -123,6 +123,7 @@ typedef struct _e_prefs {
   gboolean gui_geometry_save_position;
   gboolean gui_geometry_save_size;
   gboolean gui_geometry_save_maximized;
+  gboolean gui_macosx_style;
   console_open_e gui_console_open;
   guint    gui_recent_df_entries_max;
   guint    gui_recent_files_count_max;
@@ -293,6 +294,17 @@ extern const char *prefs_get_title_by_name(const char *name);
  */
 extern module_t *prefs_find_module(const char *name);
 
+/** Given a module name, and a preference name return a pointer to the given 
+ * module's given preference or NULL if it's not found.
+ *
+ * @param module The preference module name.  Usually the same as the protocol
+ * name, e.g. "tcp".
+ * @param pref The preference name, e.g. "desegment".
+ * @return A pointer to the corresponding preference, or NULL if it
+ * wasn't found.
+ */
+extern pref_t *prefs_find_preference(module_t * module, const char *pref);
+
 /*
  * Register a preference with an unsigned integral value.
  */
