@@ -1,12 +1,12 @@
 /*
  *  uat.h
  *
- *  $Id: uat.h 28404 2009-05-18 22:51:53Z gerald $
+ *  $Id: uat.h 25937 2008-08-05 21:03:46Z lego $
  *
  *  User Accessible Tables
  *  Mantain an array of user accessible data strucures
  *
- * (c) 2007, Luis E. Garcia Ontanon <luis.ontanon@gmail.com>
+ * (c) 2007, Luis E. Garcia Ontanon <luis@ontanon.org>
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -444,7 +444,7 @@ static void basename ## _ ## field_name ## _tostr_cb(void* rec, const char** out
 #define UAT_PROTO_DEF(basename, field_name, dissector_field, name_field, rec_t) \
 static void basename ## _ ## field_name ## _set_cb(void* rec, const char* buf, unsigned len, void* u1 _U_, void* u2 _U_) {\
 	if (len) { \
-		((rec_t*)rec)->name_field = g_strndup(buf,len); g_strdown(((rec_t*)rec)->name_field ); g_strchug(((rec_t*)rec)->name_field); \
+		((rec_t*)rec)->name_field = ep_strndup(buf,len); g_strdown(((rec_t*)rec)->name_field ); g_strchug(((rec_t*)rec)->name_field); \
 		((rec_t*)rec)->dissector_field = find_dissector(((rec_t*)rec)->name_field); \
 	} else { \
 		((rec_t*)rec)->dissector_field = find_dissector("data"); \
