@@ -1,7 +1,7 @@
 /* fileset.c
  * Routines for handling file sets
  *
- * $Id: fileset.c 25354 2008-05-22 15:46:27Z morriss $
+ * $Id: fileset.c 26570 2008-10-27 04:47:57Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -242,8 +242,8 @@ void fileset_update_dlg(void)
 void
 fileset_add_dir(const char *fname)
 {
-    ETH_DIR       *dir;             /* scanned directory */
-    ETH_DIRENT    *file;            /* current file */
+    WS_DIR        *dir;             /* scanned directory */
+    WS_DIRENT     *file;            /* current file */
     const char    *name;
     fileset_entry *entry;
     GString       *dirname;
