@@ -1,6 +1,6 @@
 /* about_dlg.c
  *
- * $Id: about_dlg.c 26247 2008-09-22 21:28:55Z etxrab $
+ * $Id: about_dlg.c 27063 2008-12-19 23:49:03Z gerald $
  *
  * Ulf Lamping <ulf.lamping@web.de>
  *
@@ -35,6 +35,9 @@
 #ifdef HAVE_LIBSMI
 #include <epan/oids.h>
 #endif
+#ifdef HAVE_GEOIP
+#include <epan/geoip_db.h>
+#endif
 
 #include "../globals.h"
 #include "../log.h"
@@ -362,7 +365,7 @@ about_folders_page_new(void)
   char *path;
   const gchar *titles[] = { "Name", "Folder", "Typical Files"};
   GtkWidget *scrolledwindow;
-#ifdef HAVE_LIBSMI
+#if defined (HAVE_LIBSMI) || defined (HAVE_GEOIP)
   gint i;
   gchar **resultArray;
 #endif
@@ -425,6 +428,23 @@ about_folders_page_new(void)
       "dissector plugins");
 #endif
 
+#ifdef HAVE_GEOIP
+  /* GeoIP */
+  path = geoip_db_get_paths();
+
+#ifdef _WIN32
+  resultArray = g_strsplit(path, ";", 10);
+#else
+  resultArray = g_strsplit(path, ":", 10);
+#endif
+
+  for(i = 0; resultArray[i]; i++)
+    about_folders_row(table, "GeoIP path", g_strstrip(resultArray[i]),
+		      "GeoIP database search path");
+  g_strfreev(resultArray);
+  g_free((void *) path);
+#endif
+
 #ifdef HAVE_LIBSMI
   /* SMI MIBs/PIBs */
   path = oid_get_default_mib_path();
