@@ -1,7 +1,7 @@
 /* bootp_stat.c
  * boop_stat   2003 Jean-Michel FAYARD
  *
- * $Id: bootp_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: bootp_stat.c 26641 2008-10-31 09:53:56Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -246,7 +246,7 @@ dhcpstat_init(const char *optarg, void *userdata _U_)
 			dhcpstat_draw);
 	if (error_string){
 		/* error, we failed to attach to the tap. clean up */
-		simple_dialog( ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str );
+		simple_dialog( ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str );
 		g_free(sp->filter);
 		g_free(sp);
 		g_string_free(error_string, TRUE);
@@ -268,6 +268,7 @@ dhcpstat_init(const char *optarg, void *userdata _U_)
 	window_present(sp->win);
 
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(sp->win->window);
 }
 
 static tap_dfilter_dlg dhcp_stat_dlg = {
