@@ -1,7 +1,7 @@
 /* capture_file_dlg.c
  * Dialog boxes for handling capture files
  *
- * $Id: capture_file_dlg.c 25947 2008-08-06 14:11:46Z morriss $
+ * $Id: capture_file_dlg.c 27151 2009-01-04 14:21:54Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -66,6 +66,7 @@
 #endif
 #include "gtk/stock_icons.h"
 #include "gtk/range_utils.h"
+#include "gtk/filter_autocomplete.h"
 
 #if _WIN32
 #include <gdk/gdkwin32.h>
@@ -232,7 +233,7 @@ preview_do(GtkWidget *prev, wtap *wth)
         }
 
         packets++;
-        if(packets%1000) {
+        if(packets%1000 == 0) {
             /* do we have a timeout? */
             time(&time_current);
             if(time_current-time_preview >= (time_t) prefs.gui_fileopen_preview) {
@@ -501,6 +502,10 @@ file_open_cmd(GtkWidget *w)
   gtk_box_pack_start(GTK_BOX(filter_hbox), filter_te, TRUE, TRUE, 3);
   g_signal_connect(filter_te, "changed",
                    G_CALLBACK(filter_te_syntax_check_cb), NULL);
+  g_object_set_data(G_OBJECT(filter_hbox), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+  g_signal_connect(filter_te, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+  g_signal_connect(file_open_w, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
+  colorize_filter_te_as_empty(filter_te);
   gtk_widget_show(filter_te);
   gtk_tooltips_set_tip(tooltips, filter_te, "Enter a display filter.", NULL);
 
@@ -574,7 +579,7 @@ file_open_cmd_cb(GtkWidget *widget, gpointer data _U_) {
   gpointer  dialog;
 
   if((cfile.state != FILE_CLOSED) && !cfile.user_saved && prefs.gui_ask_unsaved) {
-    /* user didn't saved his current file, ask him */
+    /* user didn't save his current file, ask him */
     dialog = simple_dialog(ESD_TYPE_CONFIRMATION, ESD_BTNS_SAVE_DONTSAVE_CANCEL,
                 "%sSave capture file before opening a new one?%s\n\n"
                 "If you open a new capture file without saving, your capture data will be discarded.",
@@ -807,6 +812,10 @@ file_merge_cmd(GtkWidget *w)
   gtk_box_pack_start(GTK_BOX(filter_hbox), filter_te, TRUE, TRUE, 3);
   g_signal_connect(filter_te, "changed",
                    G_CALLBACK(filter_te_syntax_check_cb), NULL);
+  g_object_set_data(G_OBJECT(filter_hbox), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+  g_signal_connect(filter_te, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+  g_signal_connect(file_merge_w, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
+  colorize_filter_te_as_empty(filter_te);
   gtk_widget_show(filter_te);
   gtk_tooltips_set_tip(tooltips, filter_te, "Enter a display filter.", NULL);
 
