@@ -1,7 +1,7 @@
 /* capture_if_details_dlg.c
  * Routines for capture interface details window (only Win32!)
  *
- * $Id: capture_if_details_dlg_win32.c 25634 2008-06-29 15:51:43Z wmeier $
+ * $Id: capture_if_details_dlg_win32.c 26545 2008-10-24 22:13:09Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -40,9 +40,7 @@
 #include "../globals.h"
 #include "../file.h"
 #include "../capture.h"
-#include "../capture_wpcap_packet.h"
 #include "../simple_dialog.h"
-#include <wiretap/wtap.h>
 
 #include "gtk/main.h"
 #include "gtk/dlg_utils.h"
@@ -51,15 +49,25 @@
 #include "gtk/gtkvumeter.h"
 #include "gtk/capture_if_details_dlg_win32.h"
 
+#include <winsock2.h>    /* Needed here to force a definition of WINVER           */
+                         /* for some (all ?) Microsoft compilers newer than vc6.  */
+                         /* (If windows.h were used instead, there might be       */
+                         /*  issues re winsock.h included before winsock2.h )     */
+#include <windowsx.h>
+#include <Ntddndis.h>
 
+#include "../capture_wpcap_packet.h"
 
 /* packet32.h requires sockaddr_storage 
- * wether sockaddr_storage is defined or not depends on the Platform SDK 
+ * whether sockaddr_storage is defined or not depends on the Platform SDK 
  * version installed. The only one not defining it is the SDK that comes
  * with MSVC 6.0 (WINVER 0x0400).
  *
  * copied from RFC2553 (and slightly modified because of datatypes) ...
  * XXX - defined more than once, move this to a header file */
+#ifndef WINVER
+#error WINVER not defined ...
+#endif
 #if (WINVER <= 0x0400) && defined(_MSC_VER)
 typedef unsigned short eth_sa_family_t;
 
@@ -94,9 +102,6 @@ struct sockaddr_storage {
 #endif /* WINVER */
 
 #include <Packet32.h>
-#include <windows.h>
-#include <windowsx.h>
-#include <Ntddndis.h>
 
 #define DETAILS_STR_MAX     1024
 
