@@ -1,7 +1,7 @@
 /* capture_if_dlg.c
  * Routines for the capture interface dialog
  *
- * $Id: capture_if_dlg.c 25672 2008-07-08 02:25:30Z wmeier $
+ * $Id: capture_if_dlg.c 26471 2008-10-15 22:51:17Z gerald $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -74,7 +74,7 @@
 
 
 #ifdef HAVE_AIRPCAP
-#include <airpcap.h>
+#include "airpcap.h"
 #include "airpcap_loader.h"
 #include "airpcap_gui_utils.h"
 #include "airpcap_dlg.h"
