@@ -1,7 +1,7 @@
 /* capture_info_dlg.c
  * Routines for packet capture info dialog
  *
- * $Id: capture_info_dlg.c 22745 2007-08-30 09:28:41Z stig $
+ * $Id: capture_info_dlg.c 25986 2008-08-12 04:44:35Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -26,29 +26,30 @@
 # include "config.h"
 #endif
 
+#ifdef HAVE_LIBPCAP
+
 #ifdef HAVE_SYS_TYPES_H
 # include <sys/types.h>
 #endif
 
 #include <string.h>
-
-#ifdef HAVE_LIBPCAP
-
-#include <gtk/gtk.h>
-#include "gtk/compat_macros.h"
-
 #include <time.h>
 
+#include <gtk/gtk.h>
+
 #include <epan/packet.h>
-#include "capture.h"
-#include "capture_info.h"
-#include "globals.h"
-#include "capture_ui_utils.h"
-#include "dlg_utils.h"
-#include "gui_utils.h"
-#include "main.h"
-#include "capture-pcap-util.h"
-#include "help_dlg.h"
+
+#include "../capture.h"
+#include "../capture_info.h"
+#include "../globals.h"
+#include "../capture_ui_utils.h"
+#include "../capture-pcap-util.h"
+
+#include "gtk/dlg_utils.h"
+#include "gtk/gui_utils.h"
+#include "gtk/main.h"
+#include "gtk/help_dlg.h"
+#include "gtk/stock_icons.h"
 
 #ifdef HAVE_AIRPCAP
 #include <airpcap.h>
@@ -88,28 +89,40 @@ pct(gint num, gint denom) {
   }
 }
 
-static gboolean
-capture_info_delete_cb(GtkWidget *w _U_, GdkEvent *event _U_, gpointer data _U_) {
+/* Workhorse for stopping capture */
+static void
+capture_info_stop(capture_options *capture_opts)
+{
 #ifdef HAVE_AIRPCAP
   airpcap_set_toolbar_stop_capture(airpcap_if_active);
 #endif
-
   capture_stop(capture_opts);
+}
+
+/* GTK signals for "delete" and "clicked" events. Note they have different signatures */
+static gboolean
+capture_info_delete_cb(GtkWidget *w _U_, GdkEvent *event _U_, gpointer data) {
+  capture_info_stop(data);
   return TRUE;
 }
 
-static gint
+static void
+capture_info_stop_clicked_cb(GtkButton *w _U_, gpointer data) {
+  capture_info_stop(data);
+}
+
+static gboolean
 capture_info_ui_update_cb(gpointer data)
 {
   capture_info *cinfo = data;
   capture_info_ui_t *info = cinfo->ui;
 
   if (!info) /* ...which might happen on slow displays? */
-      return 1;
+      return TRUE;
 
   cinfo->running_time = time(NULL) - info->start_time;
   capture_info_ui_update(cinfo);
-  return 1;   /* call the timer again */
+  return TRUE;   /* call the timer again */
 }
 
 
@@ -117,7 +130,7 @@ capture_info_ui_update_cb(gpointer data)
 /* will keep pointers to the fields in the counts parameter */
 void capture_info_ui_create(
 capture_info    *cinfo,
-const gchar     *iface)
+capture_options	*capture_opts)
 {
   unsigned int      i;
   GtkWidget         *main_vb, *stop_bt, *counts_tb;
@@ -155,6 +168,10 @@ const gchar     *iface)
   info->counts[10].value_ptr = &(cinfo->counts->vines);
   info->counts[11].title = "Other";
   info->counts[11].value_ptr = &(cinfo->counts->other);
+  info->counts[12].title = "I2C Events";
+  info->counts[12].value_ptr = &(cinfo->counts->i2c_event);
+  info->counts[13].title = "I2C Data";
+  info->counts[13].value_ptr = &(cinfo->counts->i2c_data);
 
   /*
    * Create the dialog window, with a title that includes the interface.
@@ -166,7 +183,7 @@ const gchar     *iface)
    * it might be less cryptic, but if a more descriptive name is
    * available, we should still use that.
    */
-  descr = get_interface_descriptive_name(iface);
+  descr = get_interface_descriptive_name(capture_opts->iface);
   title_iface = g_strdup_printf("Wireshark: Capture from %s", descr);
   g_free(descr);
   cap_w_title = create_user_window_title(title_iface);
@@ -176,7 +193,7 @@ const gchar     *iface)
 
   /* Container for capture display widgets */
   main_vb = gtk_vbox_new(FALSE, 1);
-  gtk_container_border_width(GTK_CONTAINER(main_vb), 5);
+  gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
   gtk_container_add(GTK_CONTAINER(info->cap_w), main_vb);
   gtk_widget_show(main_vb);
 
@@ -187,7 +204,7 @@ const gchar     *iface)
   /* Individual statistic elements */
   counts_tb = gtk_table_new(PACKET_COUNTS_SIZE, 4, TRUE);
   gtk_container_add(GTK_CONTAINER(counts_fr), counts_tb);
-  gtk_container_border_width(GTK_CONTAINER(counts_tb), 5);
+  gtk_container_set_border_width(GTK_CONTAINER(counts_tb), 5);
   gtk_widget_show(counts_tb);
 
   gtk_table_set_row_spacings(GTK_TABLE(counts_tb), 0);
@@ -212,7 +229,7 @@ const gchar     *iface)
           /* downsize the default size of this progress bar in x direction (def:150), */
           /* otherwise it will become too large and the dialog will look ugly */
           /* XXX: use a TreeView instead of a table in order to fix this */
-          WIDGET_SET_SIZE(info->counts[i].percent_pb, 70, -1);
+          gtk_widget_set_size_request(info->counts[i].percent_pb, 70, -1);
       }
 
       info->counts[i].percent_lb = gtk_label_new("0.0%");
@@ -256,26 +273,18 @@ const gchar     *iface)
 
   /* allow user to either click a stop button, or the close button on
 	the window to stop a capture in progress. */
-  if(topic_available(HELP_CAPTURE_INFO_DIALOG)) {
-      bbox = dlg_button_row_new(WIRESHARK_STOCK_CAPTURE_STOP, GTK_STOCK_HELP, NULL);
-  } else{
-      bbox = dlg_button_row_new(WIRESHARK_STOCK_CAPTURE_STOP, NULL);
-  }
+  bbox = dlg_button_row_new(WIRESHARK_STOCK_CAPTURE_STOP, GTK_STOCK_HELP, NULL);
   gtk_box_pack_start(GTK_BOX(main_vb), bbox, FALSE, FALSE, 3);
   gtk_widget_show(bbox);
 
-  stop_bt = OBJECT_GET_DATA(bbox, WIRESHARK_STOCK_CAPTURE_STOP);
+  stop_bt = g_object_get_data(G_OBJECT(bbox), WIRESHARK_STOCK_CAPTURE_STOP);
   window_set_cancel_button(info->cap_w, stop_bt, NULL);
-  SIGNAL_CONNECT(stop_bt, "clicked", capture_info_delete_cb, capture_opts);
+  g_signal_connect(stop_bt, "clicked", G_CALLBACK(capture_info_stop_clicked_cb), capture_opts);
+  g_signal_connect(info->cap_w, "delete_event", G_CALLBACK(capture_info_delete_cb), capture_opts);
 
-  SIGNAL_CONNECT(info->cap_w, "delete_event", capture_info_delete_cb,
-                 capture_opts);
-
-  if(topic_available(HELP_CAPTURE_INFO_DIALOG)) {
-      ci_help = OBJECT_GET_DATA(bbox, GTK_STOCK_HELP);
-      gtk_tooltips_set_tip (tooltips, ci_help, ("Get help about this dialog"), NULL);
-      SIGNAL_CONNECT(ci_help, "clicked", topic_cb, HELP_CAPTURE_INFO_DIALOG);
-  }
+  ci_help = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_HELP);
+  gtk_tooltips_set_tip (tooltips, ci_help, ("Get help about this dialog"), NULL);
+  g_signal_connect(ci_help, "clicked", G_CALLBACK(topic_cb), (gpointer)HELP_CAPTURE_INFO_DIALOG);
 
   gtk_widget_show(info->cap_w);
   window_present(info->cap_w);
@@ -285,7 +294,7 @@ const gchar     *iface)
   cinfo->ui = info;
 
   /* update the dialog once a second, even if no packets rushing in */
-  info->timer_id = gtk_timeout_add(1000, (GtkFunction)capture_info_ui_update_cb,(gpointer)cinfo);
+  info->timer_id = g_timeout_add(1000, capture_info_ui_update_cb,cinfo);
 }
 
 
@@ -341,7 +350,7 @@ capture_info    *cinfo)
   if (!info) /* ...which probably shouldn't happen */
       return;
 
-  gtk_timeout_remove(info->timer_id);
+  g_source_remove(info->timer_id);
 
   /* called from capture engine, so it's ok to destroy the dialog here */
   gtk_grab_remove(GTK_WIDGET(info->cap_w));
