@@ -1,7 +1,7 @@
 /* dcerpc_stat.c
  * dcerpc_stat   2002 Ronnie Sahlberg
  *
- * $Id: dcerpc_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: dcerpc_stat.c 26641 2008-10-31 09:53:56Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -56,6 +56,7 @@
 #include "gtk/service_response_time_table.h"
 #include "gtk/gtkglobals.h"
 #include "gtk/main.h"
+#include "gtk/filter_autocomplete.h"
 
 
 /* used to keep track of the statistics for an entire program interface */
@@ -315,7 +316,7 @@ gtk_dcerpcstat_init(const char *optarg, void* userdata _U_)
 	error_string=register_tap_listener("dcerpc", rs, filter, dcerpcstat_reset, dcerpcstat_packet, dcerpcstat_draw);
 	if(error_string){
 		/* error, we failed to attach to the tap. clean up */
-		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
+		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
 		g_string_free(error_string, TRUE);
 		free_srt_table_data(&rs->srt_table);
 		g_free(rs);
@@ -336,6 +337,7 @@ gtk_dcerpcstat_init(const char *optarg, void* userdata _U_)
 	window_present(rs->win);
 
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(rs->win->window);
 }
 
 
@@ -634,10 +636,15 @@ gtk_dcerpcstat_cb(GtkWidget *w _U_, gpointer d _U_)
 	/* Filter entry */
 	filter_entry=gtk_entry_new();
 	g_signal_connect(filter_entry, "changed", G_CALLBACK(filter_te_syntax_check_cb), NULL);
+	g_object_set_data(G_OBJECT(filter_box), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+	g_signal_connect(filter_entry, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+	g_signal_connect(dlg, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
 	gtk_box_pack_start(GTK_BOX(filter_box), filter_entry, TRUE, TRUE, 0);
 	filter=gtk_entry_get_text(GTK_ENTRY(main_display_filter_widget));
 	if(filter){
 		gtk_entry_set_text(GTK_ENTRY(filter_entry), filter);
+	} else {
+		colorize_filter_te_as_empty(filter_entry);
 	}
 	gtk_widget_show(filter_entry);
 
