@@ -1,7 +1,7 @@
 /* win32-file-dlg.c
  * Native Windows file dialog routines
  *
- * $Id: file_dlg_win32.c 25921 2008-08-04 23:05:32Z gerald $
+ * $Id: file_dlg_win32.c 27109 2008-12-24 14:18:59Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,6 +34,12 @@
 #include <io.h>
 #include <fcntl.h>
 
+#include <windows.h>
+#include <windowsx.h>
+#include <commdlg.h>
+#include <richedit.h>
+
+
 #include <gtk/gtk.h>
 
 #include "epan/filesystem.h"
@@ -59,11 +65,6 @@
 #include "gtk/file_dlg_win32.h"
 #include "gtk/help_dlg.h"
 
-#include <windows.h>
-#include <windowsx.h>
-#include <commdlg.h>
-#include <richedit.h>
-
 typedef enum {
     merge_append,
     merge_chrono,
@@ -886,7 +887,6 @@ print_update_dynamic(HWND dlg_hwnd, print_args_t *args) {
 
 
 #define PREVIEW_STR_MAX      200
-#define PREVIEW_TIMEOUT_SECS   3
 
 
 /* If preview_file is NULL, disable the elements.  If not, enable and
@@ -972,9 +972,9 @@ preview_set_filename(HWND of_hwnd, gchar *preview_file) {
                 stop_time = cur_time;
             }
             packet++;
-            if(packet%100) {
+            if(packet%100 == 0) {
                 time(&time_current);
-                if(time_current-time_preview >= PREVIEW_TIMEOUT_SECS) {
+                if(time_current-time_preview >= (time_t) prefs.gui_fileopen_preview) {
                     is_breaked = TRUE;
                     break;
                 }
