@@ -3,6 +3,9 @@
  *
  * Copyright 2008, Bahaa Naamneh <b.naamneh@gmail.com>
  *
+ * With several usability improvements:
+ * Copyright 2008, Stig Bjorlykke <stig@bjorlykke.org>
+ *
  * $Id$
  *
  * Wireshark - Network traffic analyzer
@@ -41,23 +44,78 @@
 #define E_FILT_AUTOCOMP_TREE_KEY    "filter_autocomplete_tree"
 
 
-static GtkWidget *filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name);
+static GtkWidget *filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name, 
+                                          gboolean protocols_only, gboolean *stop_propagation);
 static void autocomplete_protocol_string(GtkWidget  *filter_te, gchar* selected_str);
-static void autoc_filter_row_activated_cb(GtkTreeView *treeview, 
-                      GtkTreePath *path, 
-                      GtkTreeViewColumn *column, 
-                      gpointer data);
+static void autoc_filter_row_activated_cb(GtkTreeView *treeview, GtkTreePath *path, 
+                                          GtkTreeViewColumn *column, gpointer data);
 static gint filter_te_focus_out_cb(GtkWidget *filter_te, GdkEvent *event, gpointer data);
 static void init_autocompletion_list(GtkWidget *list);
 static void add_to_autocompletion_list(GtkWidget *list, const gchar *str);
-static gboolean autocompletion_list_lookup(GtkWidget *popup_win, GtkWidget *list, const gchar *str);
-static void filter_autocomplete_handle_backspace(GtkWidget *list, 
-                         GtkWidget *popup_win,
-                         gchar *prefix, 
-                         GtkWidget *main_win);
+static gboolean autocompletion_list_lookup(GtkWidget *filter_te, GtkWidget *popup_win, GtkWidget *list,
+                                           const gchar *str, gboolean *stop_propagation);
+static void filter_autocomplete_handle_backspace(GtkWidget *filter_te, GtkWidget *list, GtkWidget *popup_win,
+                                                 gchar *prefix, GtkWidget *main_win);
 static void filter_autocomplete_win_destroy_cb(GtkWidget *win, gpointer data);
+static gboolean is_protocol_name_being_typed(GtkWidget *filter_te, int str_len);
 
 
+/*
+ * Check if the string at the cursor position is a beginning of a protocol name.
+ * Possible false positives:
+ *      "NOT" at the beginning of the display filter editable text.
+ *      "NOT" adjacent to another logical operation. (e.g: exp1 AND NOT exp2).
+ **/
+static gboolean
+is_protocol_name_being_typed(GtkWidget *filter_te, int str_len)
+{
+  unsigned int i;
+  int op_len, cursor_pos;
+  gchar *start;
+  gchar *pos;
+  static gchar *logic_ops[] = { "!", "not",
+                                "||", "or",
+                                "&&", "and",
+                                "^^", "xor" };
+  
+  /* If the cursor is located at the beginning of the filter editable text,
+   * then it's _probably_ a protocol name.
+   **/
+  if(!(cursor_pos = gtk_editable_get_position(GTK_EDITABLE(filter_te))))
+    return TRUE;
+  
+  start = gtk_editable_get_chars(GTK_EDITABLE(filter_te), 0, cursor_pos);
+  
+  /* Point to one char before the current string in the filter editable text */
+  pos = start + (cursor_pos - str_len);
+  
+  /* Walk back through string to find last char which isn't ' ' or '(' */
+  while(pos > start) {
+    if(*pos != ' ' && *pos != '(') {
+      /* Check if we have one of the logical operations */
+      for(i = 0; i < (sizeof(logic_ops)/sizeof(logic_ops[0])); i++) {
+        op_len = strlen(logic_ops[i]);
+        
+        if(pos-start+1 < op_len)
+          continue;
+        
+        /* If one of the logical operations is found, then the current string is _probably_ a protocol name */
+        if(!strncmp(pos-op_len+1, logic_ops[i], op_len))
+          return TRUE;
+      }
+
+      /* If none of the logical operations was found, then the current string is not a protocol */
+      return FALSE;
+    }
+    pos--;
+  }
+  
+  /* The "str" preceded only by ' ' or '(' chars, 
+   * which means that the str is _probably_ a protocol name.
+   **/
+  return TRUE;
+}
+
 
 static void
 autocomplete_protocol_string(GtkWidget *filter_te, gchar *selected_str)
@@ -141,6 +199,26 @@ filter_te_focus_out_cb(GtkWidget *filter_te _U_,
   return FALSE;
 }
 
+static gboolean
+check_select_region (GtkWidget *filter_te, GtkWidget *popup_win, 
+                     const gchar *string, unsigned int str_len)
+{
+  gint pos1 = gtk_editable_get_position(GTK_EDITABLE(filter_te));
+  gint pos2 = pos1 + strlen(string) - str_len;
+  gint pos3 = pos1;
+
+  if (pos2 > pos1) {
+    gtk_editable_insert_text(GTK_EDITABLE(filter_te), &string[str_len-1],
+                             pos2-pos1+1, &pos3);
+    gtk_editable_set_position(GTK_EDITABLE(filter_te), pos1+1);
+    gtk_editable_select_region(GTK_EDITABLE(filter_te), pos1+1, pos2+1);
+    gtk_widget_hide (popup_win);
+    return TRUE;
+  }
+
+  return FALSE;
+}
+
 static void
 init_autocompletion_list(GtkWidget *list)
 {
@@ -174,14 +252,19 @@ add_to_autocompletion_list(GtkWidget *list, const gchar *str)
 }
 
 static gboolean
-autocompletion_list_lookup(GtkWidget *popup_win, GtkWidget *list, const gchar *str)
+autocompletion_list_lookup(GtkWidget *filter_te, GtkWidget *popup_win, GtkWidget *list, 
+			   const gchar *str, gboolean *stop_propagation)
 {
   GtkRequisition requisition;
   GtkListStore *store;
   GtkTreeIter iter;
   GtkTreeSelection *selection;
   gchar *curr_str;
+  unsigned int str_len = strlen(str);
+  gchar *first = NULL;
+  gint count = 0;
   gboolean loop = TRUE;
+  gboolean exact_match = FALSE;
 
   store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(list)));
 
@@ -193,24 +276,42 @@ autocompletion_list_lookup(GtkWidget *popup_win, GtkWidget *list, const gchar *s
 
       gtk_tree_model_get(GTK_TREE_MODEL(store), &iter, 0, &curr_str,  -1);
 
-      if( !g_ascii_strncasecmp(str, curr_str, strlen(str)) )
+      if( !g_ascii_strncasecmp(str, curr_str, str_len) ) {
         loop = gtk_tree_model_iter_next(GTK_TREE_MODEL(store), &iter);
-      else
+        if (strlen(curr_str) == str_len) {
+          exact_match = TRUE;
+        }
+        count++;
+        if (count == 1) 
+          first = g_strdup (curr_str);
+      } else {
         loop = gtk_list_store_remove(store, &iter);
+      }
 
       g_free(curr_str);
 
     } while( loop );
 
-    if(!gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter))
-      return FALSE;
+    if (count == 1 && !exact_match && strncmp(str, first, str_len) == 0) {
+      /* Only one match (not exact) with correct case */
+      *stop_propagation = check_select_region(filter_te, popup_win, first, str_len);
+    }
 
-    gtk_tree_selection_select_iter(GTK_TREE_SELECTION(selection), &iter);
+    /* Don't show an autocompletion-list with only one entry with exact match */
+    if ((count == 1 && exact_match && strncmp(str, first, str_len) == 0) ||
+        !gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter))
+    {
+      g_free (first);
+      return FALSE;
+    }
+
+    if (first)
+      g_free (first);
 
     gtk_widget_size_request(list, &requisition);
 
-    gtk_widget_set_size_request(popup_win, requisition.width+25, (requisition.height<200? requisition.height+20:200));
-    gtk_window_resize(GTK_WINDOW(popup_win), requisition.width+25, (requisition.height<200? requisition.height+20:200));
+    gtk_widget_set_size_request(popup_win, popup_win->allocation.width, (requisition.height<200? requisition.height+8:200));
+    gtk_window_resize(GTK_WINDOW(popup_win), popup_win->allocation.width, (requisition.height<200? requisition.height+8:200));
 
     return TRUE;
   }
@@ -226,11 +327,11 @@ filter_string_te_key_pressed_cb(GtkWidget *filter_te, GdkEventKey *event)
   GtkWidget *treeview;
   GtkTreeModel *model;
   GtkTreeSelection *selection;
-/*  GtkListStore *store; */
   GtkTreeIter iter;
   const gchar *filter_te_str = "";
   gchar* prefix = "";
   gchar* prefix_start;
+  gboolean stop_propagation = FALSE;
   guint k;
   gchar ckey;
   gint pos;
@@ -242,16 +343,25 @@ filter_string_te_key_pressed_cb(GtkWidget *filter_te, GdkEventKey *event)
   k = event->keyval;
   ckey = event->string[0];
 
-  /* If the popup window hasn't been constructed yet or if the pressed key is SHIFT 
-   * then we have nothing to do with the pressed key, but if the the pressed key is 
-   * a period or decimal then complete execution.
-   **/
-  if( (popup_win == NULL && (k != GDK_KP_Decimal && k != GDK_period))
-      || k == GDK_Shift_L || k == GDK_Shift_R )
+  /* If the pressed key is SHIFT then we have nothing to do with the pressed key. */
+  if( k == GDK_Shift_L || k == GDK_Shift_R)
     return FALSE;
 
-  /* get the string from filter_te, start from 0 till cursor's position */
+  if (popup_win)
+    gtk_widget_show(popup_win);
+
   pos = gtk_editable_get_position(GTK_EDITABLE(filter_te));
+  if (g_ascii_isalnum(ckey) ||      
+      k == GDK_KP_Decimal || k == GDK_period ||
+      k == GDK_underscore || k == GDK_minus) 
+  {
+    /* Ensure we delete the selected text */
+    gtk_editable_delete_selection(GTK_EDITABLE(filter_te));
+  } else if (k == GDK_Return || k == GDK_KP_Enter) {
+    /* Remove selection */
+    gtk_editable_select_region(GTK_EDITABLE(filter_te), pos, pos);
+  }
+  /* get the string from filter_te, start from 0 till cursor's position */
   filter_te_str = gtk_editable_get_chars(GTK_EDITABLE(filter_te), 0, pos);
 
   /* If the pressed key is non-alphanumeric or one of the keys specified 
@@ -261,15 +371,17 @@ filter_string_te_key_pressed_cb(GtkWidget *filter_te, GdkEventKey *event)
       k != GDK_KP_Decimal && k != GDK_period && 
       k != GDK_underscore && k != GDK_minus &&
       k != GDK_space && k != GDK_Return && k != GDK_KP_Enter && 
-      k != GDK_Down && k != GDK_Up &&
+      k != GDK_Page_Down && k != GDK_Down && k != GDK_Page_Up && k != GDK_Up &&
       k != GDK_BackSpace)
   {
+    if (popup_win) {
       gtk_widget_destroy(popup_win);
       g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, NULL);
-      return FALSE;
+    }
+    return FALSE;
   }
 
-  /* let prefix points to the first char that is not aphanumeric,'.', '_' or '-',
+  /* Let prefix points to the first char that is not aphanumeric,'.', '_' or '-',
    * start from the end of filter_te_str.
    **/
   prefix = g_strdup(filter_te_str);
@@ -285,19 +397,71 @@ filter_string_te_key_pressed_cb(GtkWidget *filter_te, GdkEventKey *event)
 
   /* Now, if the pressed key is decimal or period, and there is no period or
    * decimal before it in prefix then construct the popup window.
+   *
+   * If the pressed key is backspace, and there is no existing popup window
+   * then construct the popup window again.
    **/
   if(k==GDK_period || k==GDK_KP_Decimal) {
-    if( !strchr(prefix, '.') ) {
+    if( !strchr(prefix, '.') || !popup_win) {
 
       gchar* name_with_period;
 
+      if (popup_win) {
+        gtk_widget_destroy (popup_win);
+      }
+
       name_with_period = g_strconcat(prefix, event->string, NULL);
-      popup_win = filter_autocomplete_new(filter_te, name_with_period);
+      popup_win = filter_autocomplete_new(filter_te, name_with_period, FALSE, &stop_propagation);
       g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, popup_win);
 
+      if(name_with_period)
+        g_free (name_with_period);
+
       if(prefix_start)
         g_free(prefix_start);
+
+      return stop_propagation;
     }
+  } else if(k==GDK_BackSpace && !popup_win) {
+
+    if(strlen(prefix) > 1) {
+      /* Delete the last character in the prefix string */
+      prefix[strlen(prefix)-1] = '\0';
+      if(strchr(prefix, '.')) {
+        popup_win = filter_autocomplete_new(filter_te, prefix, FALSE, NULL);
+        g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, popup_win);
+      } else if(strlen(prefix) && is_protocol_name_being_typed(filter_te, strlen(prefix)+2)) {
+        popup_win = filter_autocomplete_new(filter_te, prefix, TRUE, NULL);
+        g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, popup_win);
+      }
+    }
+
+    if(prefix_start)
+      g_free(prefix_start);
+
+    return FALSE;
+  } else if(g_ascii_isalnum(ckey) && !popup_win) {
+    gchar *name = g_strconcat(prefix, event->string, NULL);
+
+    if( !strchr(name, '.') && is_protocol_name_being_typed(filter_te, strlen(name)) ) {
+      popup_win = filter_autocomplete_new(filter_te, name, TRUE, &stop_propagation);
+      g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, popup_win);
+    }
+
+    if (name)
+      g_free (name);
+
+    if(prefix_start)
+      g_free(prefix_start);
+
+    return stop_propagation;
+  }
+
+  /* If the popup window hasn't been constructed yet then we have nothing to do */
+  if( !popup_win ) {
+    if(prefix_start)
+      g_free(prefix_start);
+
     return FALSE;
   }
 
@@ -312,37 +476,76 @@ filter_string_te_key_pressed_cb(GtkWidget *filter_te, GdkEventKey *event)
        * the treeview handle the up, down actions directly and return the control to the filter text once 
        * the user press Enter or any key except for UP, DOWN arrows. * I wasn't able to find a way to do that. *
        **/
+    case GDK_Page_Down:
     case GDK_Down:
-      if( gtk_tree_selection_get_selected(selection, &model, &iter) ) {
-        if(gtk_tree_model_iter_next(model, &iter)) {
+      if (gtk_tree_selection_get_selected(selection, &model, &iter)) {
+        if (gtk_tree_model_iter_next(model, &iter)) {
+          if (k == GDK_Page_Down) {
+            /* Skip up to 8 entries */
+            GtkTreeIter last_iter;
+            gint count = 0;
+            do {
+              last_iter = iter;
+            } while (++count < 8 && gtk_tree_model_iter_next(model, &iter));
+            iter = last_iter;
+          }
           gtk_tree_selection_select_iter(GTK_TREE_SELECTION(selection), &iter);
           gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(treeview), 
                                        gtk_tree_model_get_path(model, &iter),
                                        NULL, FALSE, 0, 0);
+        } else {
+          gtk_tree_selection_unselect_all(selection);
         }
-      } else {
-      if(gtk_tree_model_get_iter_first(model, &iter))
+      } else if (gtk_tree_model_get_iter_first(model, &iter)) {
         gtk_tree_selection_select_iter(GTK_TREE_SELECTION(selection), &iter);
+        gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(treeview), 
+                                     gtk_tree_model_get_path(model, &iter),
+                                     NULL, FALSE, 0, 0);
       }
 
+      if(prefix_start)
+        g_free(prefix_start);
+
       /* stop event propagation */
       return TRUE;
 
-    case GDK_Up: {
+    case GDK_Page_Up:
+    case GDK_Up:
+    {
       GtkTreePath* path;
+      GtkTreeIter last_iter;
 
-      if(gtk_tree_selection_get_selected(selection, &model, &iter) ) {
-          path = gtk_tree_model_get_path(model, &iter);
+      if (gtk_tree_selection_get_selected(selection, &model, &iter) ) {
+        path = gtk_tree_model_get_path(model, &iter);
 
-        if(gtk_tree_path_prev(path)) {
+        if (gtk_tree_path_prev(path)) {
+          if (k == GDK_Page_Up) {
+            /* Skip up to 8 entries */
+            GtkTreePath *last_path;
+            gint count = 0;
+            do {
+              last_path = path;
+            } while (++count < 8 && gtk_tree_path_prev(path));
+            path = last_path;
+          }
           gtk_tree_selection_select_path(GTK_TREE_SELECTION(selection), path);
           gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(treeview), path, NULL, FALSE, 0, 0);
+        } else {
+          gtk_tree_selection_unselect_iter(selection, &iter);
         }
-      } else {
-      if(gtk_tree_model_get_iter_first(model, &iter))
-        gtk_tree_selection_select_iter(GTK_TREE_SELECTION(selection), &iter);
+      } else if (gtk_tree_model_get_iter_first(model, &iter)) {
+        do {
+          last_iter = iter;
+        } while (gtk_tree_model_iter_next(model, &iter));
+        gtk_tree_selection_select_iter(GTK_TREE_SELECTION(selection), &last_iter);
+        gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(treeview), 
+                                     gtk_tree_model_get_path(model, &last_iter),
+                                     NULL, FALSE, 0, 0);
       }
 
+      if(prefix_start)
+        g_free(prefix_start);
+
       /* stop event propagation */
       return TRUE;
     }
@@ -356,26 +559,31 @@ filter_string_te_key_pressed_cb(GtkWidget *filter_te, GdkEventKey *event)
       if(gtk_tree_selection_get_selected(selection, &model, &iter) ) {
         gchar *value;
 
-        /* Use chosen string */
-        gtk_tree_model_get(model, &iter, 0, &value,  -1);
-        autocomplete_protocol_string(filter_te, value);
-        g_free(value);
-
-        /* Lose popup */
-        gtk_widget_destroy(popup_win);
-        g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+        /* Do not autocomplete protocols with space yet, because we can be in
+         * a operator or a value field.
+         **/
+        if(k != GDK_space || strchr(prefix, '.')) {
+          /* Use chosen string */
+          gtk_tree_model_get(model, &iter, 0, &value,  -1);
+          autocomplete_protocol_string(filter_te, value);
+          g_free(value);
+        }
       }
+
+      /* Lose popup */
+      gtk_widget_destroy(popup_win);
+      g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, NULL);
       break;
 
     case GDK_BackSpace:
-      filter_autocomplete_handle_backspace(treeview, popup_win, prefix, w_toplevel);
+      filter_autocomplete_handle_backspace(filter_te, treeview, popup_win, prefix, w_toplevel);
       break;
 
     default: {
       gchar* updated_str;
 
       updated_str = g_strconcat(prefix, event->string, NULL);
-      if( !autocompletion_list_lookup(popup_win, treeview, updated_str) ) {
+      if( !autocompletion_list_lookup(filter_te, popup_win, treeview, updated_str, &stop_propagation) ) {
         /* function returned false, ie the list is empty -> close popup  */
         gtk_widget_destroy(popup_win);
         g_object_set_data(G_OBJECT(w_toplevel), E_FILT_AUTOCOMP_PTR_KEY, NULL);
@@ -394,26 +602,105 @@ filter_string_te_key_pressed_cb(GtkWidget *filter_te, GdkEventKey *event)
   if(k == GDK_Return || k == GDK_KP_Enter)
     return TRUE;    /* stop event propagation */
 
-  return FALSE;
+  return stop_propagation;
+}
+
+/*
+ * In my implementation, I'm looking for fields that match the protocol name in the whole fields list
+ * and not only restrict the process by returning all the fields of the protocol that match the prefix using
+ * 'proto_get_id_by_filter_name(protocol_name)'; because I have noticed that some of the fields
+ * have a prefix different than its parent protocol; for example SIP protocol had this field raw_sip.line despite
+ * that there is a protocol called RAW_SIP which it should be associated with it.
+ * so the unorganized fields and nonexistent of a standardized protocols and fields naming rules prevent me from
+ * implementing the autocomplete in an optimized way.
+ **/
+static gboolean
+build_autocompletion_list(GtkWidget *filter_te, GtkWidget *treeview, GtkWidget *popup_win, 
+			  const gchar *protocol_name, gboolean protocols_only, gboolean *stop_propagation)
+{
+  void *cookie, *cookie2;
+  protocol_t *protocol;
+  unsigned int protocol_name_len;
+  header_field_info *hfinfo;
+  gint count = 0;
+  gboolean exact_match = FALSE;
+  const gchar *first = NULL;
+  int i;
+
+  protocol_name_len = strlen(protocol_name);
+
+  /* Walk protocols list */
+  for (i = proto_get_first_protocol(&cookie); i != -1; i = proto_get_next_protocol(&cookie)) {
+
+    protocol = find_protocol_by_id(i);
+
+    if (!proto_is_protocol_enabled(protocol))
+      continue;
+
+    if (protocols_only) {
+      const gchar *name = proto_get_protocol_filter_name (i);
+
+      if (!g_ascii_strncasecmp(protocol_name, name, protocol_name_len)) {
+        add_to_autocompletion_list(treeview, name);
+        if (strlen(name) == protocol_name_len) {
+          exact_match = TRUE;
+        }
+        count++;
+        if (count == 1) 
+          first = name;
+      }
+    } else {
+      hfinfo = proto_registrar_get_nth(i);
+
+      for (hfinfo = proto_get_first_protocol_field(i, &cookie2); 
+           hfinfo != NULL;
+           hfinfo = proto_get_next_protocol_field(&cookie2)) 
+      {
+        if (hfinfo->same_name_prev != NULL) /* ignore duplicate names */
+          continue;
+
+        if(!g_ascii_strncasecmp(protocol_name, hfinfo->abbrev, protocol_name_len)) {
+          add_to_autocompletion_list(treeview, hfinfo->abbrev);
+          if (strlen(hfinfo->abbrev) == protocol_name_len) {
+            exact_match = TRUE;
+          }
+          count++;
+          if (count == 1) 
+            first = hfinfo->abbrev;
+        }
+      }
+    }
+  }
+
+  if (count == 1 && !exact_match && stop_propagation && 
+      strncmp(protocol_name, first, protocol_name_len) == 0)
+  {
+    /* Only one match (not exact) with correct case */
+    *stop_propagation = check_select_region(filter_te, popup_win, first, protocol_name_len);
+  }
+
+  /* Don't show an empty autocompletion-list or
+   * an autocompletion-list with only one entry with exact match 
+   **/
+  if (count == 0 || (count == 1 && exact_match && 
+		     strncmp(protocol_name, first, protocol_name_len) == 0))
+    return FALSE;
+
+  return TRUE;
 }
 
 static GtkWidget *
-filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name)
+filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name, gboolean protocols_only, gboolean *stop_propagation)
 {
   GtkWidget *popup_win;
   GtkWidget *treeview;
   GtkWidget *filter_sc;
-  void *cookie, *cookie2;
-  protocol_t *protocol;
-  int i, protocol_name_len;
-  header_field_info *hfinfo;
   gint x_pos, y_pos;
   GtkTreeModel *model;
   GtkSortType order;
+  GtkTreeSelection *selection;
   GtkRequisition requisition;
   GtkWidget *w_toplevel;
-  GtkListStore *store;
-  GtkTreeIter iter;
 
   w_toplevel = gtk_widget_get_toplevel(filter_te);
 
@@ -428,52 +715,19 @@ filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name)
 
   /* Create tree view */
   treeview = gtk_tree_view_new();
+#if GTK_CHECK_VERSION(2,6,0)
+  gtk_tree_view_set_hover_selection(GTK_TREE_VIEW(treeview), TRUE);
+#endif
   init_autocompletion_list(treeview);
   g_object_set_data(G_OBJECT(popup_win), E_FILT_AUTOCOMP_TREE_KEY, treeview);
 
-  /*
-   * In my implementation, I'm looking for fields that match the protocol name in the whole fields list
-   * and not only restrict the process by returning all the fields of the protocol that match the prefix using
-   * 'proto_get_id_by_filter_name(protocol_name)'; because I have noticed that some of the fields
-   * have a prefix different than its parent protocol; for example SIP protocol had this field raw_sip.line despite
-   * that there is a protocol called RAW_SIP which it should be associated with it.
-   * so the unorganized fields and nonexistent of a standardized protocols and fields naming rules prevent me from
-   * implementing the autocomplete in an optimized way.
-   **/
-  protocol_name_len = strlen(protocol_name);
-
-  /* Walk protocols list */
-  for (i = proto_get_first_protocol(&cookie); i != -1; i = proto_get_next_protocol(&cookie)) {
-
-    protocol = find_protocol_by_id(i);
-
-    if (!proto_is_protocol_enabled(protocol))
-      continue;
-
-    hfinfo = proto_registrar_get_nth(i);
-
-    for (hfinfo = proto_get_first_protocol_field(i, &cookie2); 
-         hfinfo != NULL;
-         hfinfo = proto_get_next_protocol_field(&cookie2)) 
-    {
-      if (hfinfo->same_name_prev != NULL) /* ignore duplicate names */
-        continue;
-
-      if(!g_ascii_strncasecmp(protocol_name, hfinfo->abbrev, protocol_name_len))
-        add_to_autocompletion_list(treeview, hfinfo->abbrev);
-    }
-  }
-
-  /* Don't show an empty autocompletion-list */
-  store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(treeview)));
-  if( !gtk_tree_model_get_iter_first(GTK_TREE_MODEL(store), &iter) ) {
+  /* Build list */
+  if (!build_autocompletion_list(filter_te, treeview, popup_win, protocol_name, protocols_only, stop_propagation)) {
     gtk_widget_destroy(popup_win);
     return NULL;
   }
 
-  gtk_widget_size_request(treeview, &requisition);
-
-  /* sort treeview */
+  /* Sort treeview */
   model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
   order = GTK_SORT_ASCENDING;
   if(model)
@@ -485,7 +739,10 @@ filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name)
   g_signal_connect(filter_te, "focus-out-event", G_CALLBACK(filter_te_focus_out_cb), w_toplevel);
   g_signal_connect(popup_win, "destroy", G_CALLBACK(filter_autocomplete_win_destroy_cb), NULL);
 
-  gtk_widget_set_size_request (popup_win, requisition.width+25, (requisition.height<200? requisition.height+8:200));
+  gtk_widget_size_request(treeview, &requisition);
+
+  gtk_widget_set_size_request(popup_win, filter_te->allocation.width, (requisition.height<200? requisition.height+8:200));
+  gtk_window_resize(GTK_WINDOW(popup_win), filter_te->allocation.width, (requisition.height<200? requisition.height+8:200));
 
   gtk_window_get_position(GTK_WINDOW(w_toplevel), &x_pos, &y_pos); 
   x_pos = x_pos + filter_te->allocation.x;
@@ -495,63 +752,48 @@ filter_autocomplete_new(GtkWidget *filter_te, const gchar *protocol_name)
 
   gtk_widget_show_all (popup_win);
 
+  selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(treeview));
+  gtk_tree_selection_unselect_all(selection);
+
   return popup_win;
 }
 
-static void 
-filter_autocomplete_handle_backspace(GtkWidget *list, GtkWidget *popup_win, gchar *prefix, GtkWidget *main_win)
+static void
+filter_autocomplete_handle_backspace(GtkWidget *filter_te, GtkWidget *list, GtkWidget *popup_win, gchar *prefix, GtkWidget *main_win)
 {
-  GtkRequisition requisition;
   GtkListStore *store;
-  void *cookie, *cookie2;
-  protocol_t *protocol;
-  int i;
-  header_field_info *hfinfo;
+  GtkRequisition requisition;
   gint prefix_len;
+  gboolean protocols_only = FALSE;
 
   /* Delete the last character in the prefix string */
   prefix_len = strlen(prefix)-1;
   prefix[prefix_len] = '\0';
 
-  /* Dismiss if there are no dots left in the string */
-  if(strchr(prefix, '.') == NULL) {
+  if (prefix_len == 0) {
+    /* Remove the popup window for protocols */
     gtk_widget_destroy(popup_win);
     g_object_set_data(G_OBJECT(main_win), E_FILT_AUTOCOMP_PTR_KEY, NULL);
     return;
+  } else if(strchr(prefix, '.') == NULL) {
+    protocols_only = TRUE;
   }
 
   /* Empty list */
   store = GTK_LIST_STORE(gtk_tree_view_get_model(GTK_TREE_VIEW(list)));
   gtk_list_store_clear(store);
 
-  /* Look through enabled protocols for matching fields to show in list */
-  for (i = proto_get_first_protocol(&cookie); i != -1; i = proto_get_next_protocol(&cookie)) {
-
-    protocol = find_protocol_by_id(i);
-
-    if (!proto_is_protocol_enabled(protocol))
-      continue;
-
-    hfinfo = proto_registrar_get_nth(i);
-
-    /* Try all fields in this protocol */
-    for (hfinfo = proto_get_first_protocol_field(i, &cookie2); 
-         hfinfo != NULL;
-         hfinfo = proto_get_next_protocol_field(&cookie2)) 
-    {
-      if (hfinfo->same_name_prev != NULL) /* ignore duplicate names */
-        continue;
-
-      /* Add if prefix matches */
-      if(!g_ascii_strncasecmp(prefix, hfinfo->abbrev, prefix_len))
-        add_to_autocompletion_list(list, hfinfo->abbrev);
-    }
+  /* Build new list */
+  if (!build_autocompletion_list(filter_te, list, popup_win, prefix, protocols_only, NULL)) {
+    gtk_widget_destroy(popup_win);
+    g_object_set_data(G_OBJECT(main_win), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+    return;
   }
 
   gtk_widget_size_request(list, &requisition);
 
-  gtk_widget_set_size_request(popup_win, requisition.width+25, (requisition.height<200? requisition.height+20:200));
-  gtk_window_resize(GTK_WINDOW(popup_win), requisition.width+25, (requisition.height<200? requisition.height+20:200));
+  gtk_widget_set_size_request(popup_win, popup_win->allocation.width, (requisition.height<200? requisition.height+8:200));
+  gtk_window_resize(GTK_WINDOW(popup_win), popup_win->allocation.width, (requisition.height<200? requisition.height+8:200));
 }
 
 static void 
