@@ -1,7 +1,7 @@
 /* find_dlg.c
  * Routines for "find frame" window
  *
- * $Id: find_dlg.c 24183 2008-01-24 22:12:10Z wmeier $
+ * $Id: find_dlg.c 25788 2008-07-22 15:19:10Z martinm $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -34,19 +34,21 @@
 #include <epan/proto.h>
 #include <epan/dfilter/dfilter.h>
 #include <epan/strutil.h>
-#include "globals.h"
-
-#include "gui_utils.h"
-#include "find_dlg.h"
-#include "filter_dlg.h"
-#include "alert_box.h"
-#include "simple_dialog.h"
-#include "dlg_utils.h"
-#include "compat_macros.h"
 #include <epan/prefs.h>
-#include "prefs_dlg.h"
-#include "keys.h"
-#include "help_dlg.h"
+
+#include "../globals.h"
+#include "../alert_box.h"
+#include "../simple_dialog.h"
+
+#include "gtk/gui_utils.h"
+#include "gtk/find_dlg.h"
+#include "gtk/filter_dlg.h"
+#include "gtk/dlg_utils.h"
+#include "gtk/stock_icons.h"
+#include "gtk/prefs_dlg.h"
+#include "gtk/keys.h"
+#include "gtk/help_dlg.h"
+#include "gtk/filter_autocomplete.h"
 
 /* Capture callback data keys */
 #define E_FIND_FILT_KEY       "find_filter_te"
@@ -116,9 +118,6 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
 
                 *bbox, *ok_bt, *cancel_bt, *help_bt;
   GtkTooltips   *tooltips;
-#if GTK_MAJOR_VERSION < 2
-  GtkAccelGroup *accel_group;
-#endif
   GList *glist = NULL;
   /* No Apply button, but "OK" not only sets our text widget, it
      activates it (i.e., it causes us to do the search). */
@@ -139,17 +138,9 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
 
   tooltips = gtk_tooltips_new ();
 
-#if GTK_MAJOR_VERSION < 2
-  /* Accelerator group for the accelerators (or, as they're called in
-     Windows and, I think, in Motif, "mnemonics"; Alt+<key> is a mnemonic,
-     Ctrl+<key> is an accelerator). */
-  accel_group = gtk_accel_group_new();
-  gtk_window_add_accel_group(GTK_WINDOW(find_frame_w), accel_group);
-#endif
-
   /* Container for each row of widgets */
   main_vb = gtk_vbox_new(FALSE, 3);
-  gtk_container_border_width(GTK_CONTAINER(main_vb), 5);
+  gtk_container_set_border_width(GTK_CONTAINER(main_vb), 5);
   gtk_container_add(GTK_CONTAINER(find_frame_w), main_vb);
   gtk_widget_show(main_vb);
 
@@ -166,7 +157,7 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
   gtk_widget_show(find_type_frame);
 
   find_type_vb = gtk_vbox_new(FALSE, 3);
-  gtk_container_border_width(GTK_CONTAINER(find_type_vb), 3);
+  gtk_container_set_border_width(GTK_CONTAINER(find_type_vb), 3);
   gtk_container_add(GTK_CONTAINER(find_type_frame), find_type_vb);
   gtk_widget_show(find_type_vb);
 
@@ -180,24 +171,21 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
   gtk_widget_show(find_type_lb);
 
   /* Filter */
-  filter_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(NULL,
-               "_Display filter", accel_group);
+  filter_rb = gtk_radio_button_new_with_mnemonic_from_widget(NULL, "_Display filter");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(filter_rb), !cfile.hex && !cfile.string);
   gtk_box_pack_start(GTK_BOX(find_type_hb), filter_rb, FALSE, FALSE, 0);
   gtk_tooltips_set_tip (tooltips, filter_rb, ("Search for data by display filter syntax.\ne.g. ip.addr==10.1.1.1"), NULL);
   gtk_widget_show(filter_rb);
 
   /* Hex */
-  hex_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(filter_rb,
-               "_Hex value", accel_group);
+  hex_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(filter_rb), "_Hex value");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hex_rb), cfile.hex);
   gtk_box_pack_start(GTK_BOX(find_type_hb), hex_rb, FALSE, FALSE, 0);
   gtk_tooltips_set_tip (tooltips, hex_rb, ("Search for data by hex string.\ne.g. fffffda5"), NULL);
   gtk_widget_show(hex_rb);
 
   /* ASCII Search */
-  string_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(filter_rb,
-               "_String", accel_group);
+  string_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(filter_rb), "_String");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(string_rb), cfile.string);
   gtk_box_pack_start(GTK_BOX(find_type_hb), string_rb, FALSE, FALSE, 0);
   gtk_tooltips_set_tip (tooltips, string_rb, ("Search for data by string value.\ne.g. My String"), NULL);
@@ -208,20 +196,23 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
   gtk_box_pack_start(GTK_BOX(find_type_vb), filter_hb, FALSE, FALSE, 0);
   gtk_widget_show(filter_hb);
 
-  filter_bt = BUTTON_NEW_FROM_STOCK(WIRESHARK_STOCK_DISPLAY_FILTER_ENTRY);
-  SIGNAL_CONNECT(filter_bt, "clicked", display_filter_construct_cb, &args);
-  SIGNAL_CONNECT(filter_bt, "destroy", filter_button_destroy_cb, NULL);
-  OBJECT_SET_DATA(filter_bt, E_FILT_TE_BUTTON_KEY, filter_bt);
+  filter_bt = gtk_button_new_from_stock(WIRESHARK_STOCK_DISPLAY_FILTER_ENTRY);
+  g_signal_connect(filter_bt, "clicked", G_CALLBACK(display_filter_construct_cb), &args);
+  g_signal_connect(filter_bt, "destroy", G_CALLBACK(filter_button_destroy_cb), NULL);
+  g_object_set_data(G_OBJECT(filter_bt), E_FILT_TE_BUTTON_KEY, filter_bt);
   gtk_box_pack_start(GTK_BOX(filter_hb), filter_bt, FALSE, TRUE, 0);
   gtk_tooltips_set_tip (tooltips, filter_bt, ("Click on the filter button to select a display filter,\nor enter your search criteria into the text box"), NULL);
   gtk_widget_show(filter_bt);
 
   filter_text_box = gtk_entry_new();
   if (cfile.sfilter) gtk_entry_set_text(GTK_ENTRY(filter_text_box), cfile.sfilter);
-  OBJECT_SET_DATA(filter_bt, E_FILT_TE_PTR_KEY, filter_text_box);
-  OBJECT_SET_DATA(find_frame_w, E_FILT_TE_PTR_KEY, filter_text_box);
+  g_object_set_data(G_OBJECT(filter_bt), E_FILT_TE_PTR_KEY, filter_text_box);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FILT_TE_PTR_KEY, filter_text_box);
   gtk_box_pack_start(GTK_BOX(filter_hb), filter_text_box, TRUE, TRUE, 0);
-  SIGNAL_CONNECT(filter_text_box, "changed", find_filter_te_syntax_check_cb, find_frame_w);
+  g_signal_connect(filter_text_box, "changed", G_CALLBACK(find_filter_te_syntax_check_cb), find_frame_w);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+  g_signal_connect(filter_text_box, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+  g_signal_connect(find_frame_w, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
   gtk_widget_show(filter_text_box);
 
 
@@ -238,29 +229,26 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
 
   /* search in row */
   data_vb = gtk_vbox_new(TRUE, 0);
-  gtk_container_border_width(GTK_CONTAINER(data_vb), 3);
+  gtk_container_set_border_width(GTK_CONTAINER(data_vb), 3);
   gtk_container_add(GTK_CONTAINER(data_frame), data_vb);
   gtk_widget_show(data_vb);
 
   /* Packet list */
-  summary_data_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(NULL,
-               "Packet list", accel_group);
+  summary_data_rb = gtk_radio_button_new_with_mnemonic_from_widget(NULL, "Packet list");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(summary_data_rb), summary_data);
   gtk_box_pack_start(GTK_BOX(data_vb), summary_data_rb, TRUE, TRUE, 0);
   gtk_tooltips_set_tip (tooltips, summary_data_rb, ("Search for string in the Info column of the packet summary (top pane)"), NULL);
   gtk_widget_show(summary_data_rb);
 
   /* Packet details */
-  decode_data_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(summary_data_rb,
-               "Packet details", accel_group);
+  decode_data_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(summary_data_rb), "Packet details");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(decode_data_rb), decode_data);
   gtk_box_pack_start(GTK_BOX(data_vb), decode_data_rb, TRUE, TRUE, 0);
   gtk_tooltips_set_tip (tooltips, decode_data_rb, ("Search for string in the decoded packet display (middle pane)"), NULL);
   gtk_widget_show(decode_data_rb);
 
   /* Packet bytes */
-  hex_data_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(summary_data_rb,
-                "Packet bytes", accel_group);
+  hex_data_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(summary_data_rb), "Packet bytes");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(hex_data_rb), !decode_data && !summary_data);
   gtk_box_pack_start(GTK_BOX(data_vb), hex_data_rb, TRUE, TRUE, 0);
   gtk_tooltips_set_tip (tooltips, hex_data_rb, ("Search for string in the packet data"), NULL);
@@ -273,11 +261,10 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
 
   string_opt_vb = gtk_vbox_new(FALSE, 0);
   gtk_container_add(GTK_CONTAINER(string_opt_frame), string_opt_vb);
-  gtk_container_border_width(GTK_CONTAINER(string_opt_vb), 3);
+  gtk_container_set_border_width(GTK_CONTAINER(string_opt_vb), 3);
   gtk_widget_show(string_opt_vb);
 
-  case_cb = CHECK_BUTTON_NEW_WITH_MNEMONIC(
-		"Case sensitive", accel_group);
+  case_cb = gtk_check_button_new_with_mnemonic("Case sensitive");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(case_cb), !case_type);
   gtk_container_add(GTK_CONTAINER(string_opt_vb), case_cb);
   gtk_tooltips_set_tip (tooltips, case_cb, ("Search by mixed upper/lower case?"), NULL);
@@ -312,54 +299,48 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
 
   /* Direction row: Forward and reverse radio buttons */
   direction_vb = gtk_vbox_new(FALSE, 0);
-  gtk_container_border_width(GTK_CONTAINER(direction_vb), 3);
+  gtk_container_set_border_width(GTK_CONTAINER(direction_vb), 3);
   gtk_container_add(GTK_CONTAINER(direction_frame), direction_vb);
   gtk_widget_show(direction_vb);
 
-  up_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(NULL, "_Up", accel_group);
+  up_rb = gtk_radio_button_new_with_mnemonic_from_widget(NULL, "_Up");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(up_rb), cfile.sbackward);
   gtk_box_pack_start(GTK_BOX(direction_vb), up_rb, FALSE, FALSE, 0);
   gtk_widget_show(up_rb);
 
-  down_rb = RADIO_BUTTON_NEW_WITH_MNEMONIC(up_rb, "_Down", accel_group);
+  down_rb = gtk_radio_button_new_with_mnemonic_from_widget(GTK_RADIO_BUTTON(up_rb), "_Down");
   gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(down_rb), !cfile.sbackward);
   gtk_box_pack_start(GTK_BOX(direction_vb), down_rb, FALSE, FALSE, 0);
   gtk_widget_show(down_rb);
 
 
   /* Button row */
-  if(topic_available(HELP_FIND_DIALOG)) {
-    bbox = dlg_button_row_new(GTK_STOCK_FIND, GTK_STOCK_CANCEL, GTK_STOCK_HELP, NULL);
-  } else {
-    bbox = dlg_button_row_new(GTK_STOCK_FIND, GTK_STOCK_CANCEL, NULL);
-  }
+  bbox = dlg_button_row_new(GTK_STOCK_FIND, GTK_STOCK_CANCEL, GTK_STOCK_HELP, NULL);
   gtk_box_pack_start(GTK_BOX(main_vb), bbox, FALSE, FALSE, 0);
   gtk_widget_show(bbox);
 
-  ok_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_FIND);
-  SIGNAL_CONNECT(ok_bt, "clicked", find_frame_ok_cb, find_frame_w);
+  ok_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_FIND);
+  g_signal_connect(ok_bt, "clicked", G_CALLBACK(find_frame_ok_cb), find_frame_w);
 
-  cancel_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CANCEL);
-  SIGNAL_CONNECT(cancel_bt, "clicked", find_frame_close_cb, find_frame_w);
+  cancel_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CANCEL);
+  g_signal_connect(cancel_bt, "clicked", G_CALLBACK(find_frame_close_cb), find_frame_w);
 
-  if(topic_available(HELP_FIND_DIALOG)) {
-      help_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_HELP);
-      SIGNAL_CONNECT(help_bt, "clicked", topic_cb, HELP_FIND_DIALOG);
-  }
+  help_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_HELP);
+  g_signal_connect(help_bt, "clicked", G_CALLBACK(topic_cb), (gpointer)HELP_FIND_DIALOG);
 
   /* Attach pointers to needed widgets to the capture prefs window/object */
-  OBJECT_SET_DATA(find_frame_w, E_FIND_FILT_KEY, filter_text_box);
-  OBJECT_SET_DATA(find_frame_w, E_FIND_BACKWARD_KEY, up_rb);
-  OBJECT_SET_DATA(find_frame_w, E_FIND_FILTERDATA_KEY, filter_rb);
-  OBJECT_SET_DATA(find_frame_w, E_FIND_HEXDATA_KEY, hex_rb);
-  OBJECT_SET_DATA(find_frame_w, E_FIND_STRINGDATA_KEY, string_rb);
-  OBJECT_SET_DATA(find_frame_w, E_FIND_STRINGTYPE_LABEL_KEY, combo_lb);
-  OBJECT_SET_DATA(find_frame_w, E_FIND_STRINGTYPE_KEY, combo_cb);
-  OBJECT_SET_DATA(find_frame_w, E_CASE_SEARCH_KEY, case_cb);
-  OBJECT_SET_DATA(find_frame_w, E_SOURCE_HEX_KEY, hex_data_rb);
-  OBJECT_SET_DATA(find_frame_w, E_SOURCE_DECODE_KEY, decode_data_rb);
-  OBJECT_SET_DATA(find_frame_w, E_SOURCE_SUMMARY_KEY, summary_data_rb);
-  OBJECT_SET_DATA(find_frame_w, E_FILT_TE_BUTTON_KEY, filter_bt);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FIND_FILT_KEY, filter_text_box);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FIND_BACKWARD_KEY, up_rb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FIND_FILTERDATA_KEY, filter_rb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FIND_HEXDATA_KEY, hex_rb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FIND_STRINGDATA_KEY, string_rb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FIND_STRINGTYPE_LABEL_KEY, combo_lb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FIND_STRINGTYPE_KEY, combo_cb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_CASE_SEARCH_KEY, case_cb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_SOURCE_HEX_KEY, hex_data_rb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_SOURCE_DECODE_KEY, decode_data_rb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_SOURCE_SUMMARY_KEY, summary_data_rb);
+  g_object_set_data(G_OBJECT(find_frame_w), E_FILT_TE_BUTTON_KEY, filter_bt);
 
   /*
    * Now that we've attached the pointers, connect the signals - if
@@ -367,9 +348,9 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
    * be delivered before the pointers are attached; the signal
    * handlers expect the pointers to be attached, and won't be happy.
    */
-  SIGNAL_CONNECT(hex_rb, "clicked", hex_selected_cb, find_frame_w);
-  SIGNAL_CONNECT(string_rb, "clicked", string_selected_cb, find_frame_w);
-  SIGNAL_CONNECT(filter_rb, "clicked", filter_selected_cb, find_frame_w);
+  g_signal_connect(hex_rb, "clicked", G_CALLBACK(hex_selected_cb), find_frame_w);
+  g_signal_connect(string_rb, "clicked", G_CALLBACK(string_selected_cb), find_frame_w);
+  g_signal_connect(filter_rb, "clicked", G_CALLBACK(filter_selected_cb), find_frame_w);
 
   string_selected_cb(NULL, find_frame_w);
   filter_selected_cb(NULL, find_frame_w);
@@ -387,8 +368,8 @@ find_frame_cb(GtkWidget *w _U_, gpointer d _U_)
   /* Give the initial focus to the "Filter" entry box. */
   gtk_widget_grab_focus(filter_text_box);
 
-  SIGNAL_CONNECT(find_frame_w, "delete_event", window_delete_event_cb, NULL);
-  SIGNAL_CONNECT(find_frame_w, "destroy", find_frame_destroy_cb, NULL);
+  g_signal_connect(find_frame_w, "delete_event", G_CALLBACK(window_delete_event_cb), NULL);
+  g_signal_connect(find_frame_w, "destroy", G_CALLBACK(find_frame_destroy_cb), NULL);
 
   gtk_widget_show(find_frame_w);
   window_present(find_frame_w);
@@ -413,8 +394,8 @@ find_filter_te_syntax_check_cb(GtkWidget *w, gpointer parent_w)
   guint8          *bytes = NULL;
   size_t           nbytes;
 
-  hex_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_HEXDATA_KEY);
-  string_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_STRINGDATA_KEY);
+  hex_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_HEXDATA_KEY);
+  string_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_STRINGDATA_KEY);
 
   if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (hex_rb))) {
     /*
@@ -463,7 +444,7 @@ hex_selected_cb(GtkWidget *button_rb _U_, gpointer parent_w)
 {
     GtkWidget   *filter_text_box;
 
-    filter_text_box = (GtkWidget *) OBJECT_GET_DATA(parent_w, E_FILT_TE_PTR_KEY);
+    filter_text_box = (GtkWidget *) g_object_get_data(G_OBJECT(parent_w), E_FILT_TE_PTR_KEY);
 
     /* Re-check the display filter. */
     find_filter_te_syntax_check_cb(filter_text_box, parent_w);
@@ -480,15 +461,15 @@ string_selected_cb(GtkWidget *button_rb _U_, gpointer parent_w)
     GtkWidget   *string_rb, *hex_data_rb, *decode_data_rb, *summary_data_rb,
                 *data_combo_lb, *data_combo_cb, *data_case_cb, *filter_text_box;
 
-    string_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_STRINGDATA_KEY);
-    hex_data_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_SOURCE_HEX_KEY);
-    decode_data_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_SOURCE_DECODE_KEY);
-    summary_data_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_SOURCE_SUMMARY_KEY);
+    string_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_STRINGDATA_KEY);
+    hex_data_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_SOURCE_HEX_KEY);
+    decode_data_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_SOURCE_DECODE_KEY);
+    summary_data_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_SOURCE_SUMMARY_KEY);
 
-    data_combo_lb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_STRINGTYPE_LABEL_KEY);
-    data_combo_cb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_STRINGTYPE_KEY);
-    data_case_cb = (GtkWidget *) OBJECT_GET_DATA(parent_w, E_CASE_SEARCH_KEY);
-    filter_text_box = (GtkWidget *) OBJECT_GET_DATA(parent_w, E_FILT_TE_PTR_KEY);
+    data_combo_lb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_STRINGTYPE_LABEL_KEY);
+    data_combo_cb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_STRINGTYPE_KEY);
+    data_case_cb = (GtkWidget *) g_object_get_data(G_OBJECT(parent_w), E_CASE_SEARCH_KEY);
+    filter_text_box = (GtkWidget *) g_object_get_data(G_OBJECT(parent_w), E_FILT_TE_PTR_KEY);
 
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(string_rb))) {
         gtk_widget_set_sensitive(GTK_WIDGET(hex_data_rb), TRUE);
@@ -519,8 +500,8 @@ filter_selected_cb(GtkWidget *button_rb _U_, gpointer parent_w)
 {
     GtkWidget   *filter_bt, *filter_rb;
 
-    filter_bt = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FILT_TE_BUTTON_KEY);
-    filter_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_FILTERDATA_KEY);
+    filter_bt = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FILT_TE_BUTTON_KEY);
+    filter_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_FILTERDATA_KEY);
 
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(filter_rb)))
     {
@@ -546,14 +527,14 @@ find_frame_ok_cb(GtkWidget *ok_bt _U_, gpointer parent_w)
   dfilter_t       *sfcode = NULL;
   gboolean        found_packet=FALSE;
 
-  filter_te = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_FILT_KEY);
-  up_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_BACKWARD_KEY);
-  hex_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_HEXDATA_KEY);
-  string_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_STRINGDATA_KEY);
-  combo_cb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_FIND_STRINGTYPE_KEY);
-  case_cb = (GtkWidget *) OBJECT_GET_DATA(parent_w, E_CASE_SEARCH_KEY);
-  decode_data_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_SOURCE_DECODE_KEY);
-  summary_data_rb = (GtkWidget *)OBJECT_GET_DATA(parent_w, E_SOURCE_SUMMARY_KEY);
+  filter_te = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_FILT_KEY);
+  up_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_BACKWARD_KEY);
+  hex_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_HEXDATA_KEY);
+  string_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_STRINGDATA_KEY);
+  combo_cb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_FIND_STRINGTYPE_KEY);
+  case_cb = (GtkWidget *) g_object_get_data(G_OBJECT(parent_w), E_CASE_SEARCH_KEY);
+  decode_data_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_SOURCE_DECODE_KEY);
+  summary_data_rb = (GtkWidget *)g_object_get_data(G_OBJECT(parent_w), E_SOURCE_SUMMARY_KEY);
 
   filter_text = gtk_entry_get_text(GTK_ENTRY(filter_te));
   string_type = gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(combo_cb)->entry));
