@@ -1,7 +1,7 @@
 /* follow_ssl.c
  * SSL specific routines for following traffic streams
  *
- * $Id: follow_ssl.c 25354 2008-05-22 15:46:27Z morriss $
+ * $Id: follow_ssl.c 27086 2008-12-22 16:05:24Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -173,6 +173,7 @@ follow_ssl_stream_cb(GtkWidget * w, gpointer data _U_)
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
                       "Error creating filter for this stream.\n"
                       "A network layer header is needed");
+	g_free(follow_info);
         return;
     }
 
@@ -208,6 +209,9 @@ follow_ssl_stream_cb(GtkWidget * w, gpointer data _U_)
     {
         simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
             "Can't register ssl tap: %s\n",msg->str);
+	g_free(follow_info->filter_out_filter);
+	g_free(follow_info);
+	g_free(follow_filter);
         return;
     }
     gtk_entry_set_text(GTK_ENTRY(filter_te), follow_filter);
