@@ -5,7 +5,7 @@
  *
  * MUCH code modified from service_response_time_table.c.
  *
- * $Id: gsm_a_stat.c 25915 2008-08-04 16:11:17Z etxrab $
+ * $Id: gsm_a_stat.c 26730 2008-11-07 17:37:22Z etxrab $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -81,6 +81,8 @@ typedef struct _gsm_a_stat_t {
     int		dtap_sms_message_type[0xff];
     int		dtap_sm_message_type[0xff];
     int		dtap_ss_message_type[0xff];
+    int		dtap_tp_message_type[0xff];
+    int		sacch_rr_message_type[0xff];
 } gsm_a_stat_t;
 
 
@@ -92,6 +94,8 @@ static gsm_a_stat_dlg_t		dlg_dtap_gmm;
 static gsm_a_stat_dlg_t		dlg_dtap_sms;
 static gsm_a_stat_dlg_t		dlg_dtap_sm;
 static gsm_a_stat_dlg_t		dlg_dtap_ss;
+static gsm_a_stat_dlg_t		dlg_dtap_tp;
+static gsm_a_stat_dlg_t		dlg_sacch_rr;
 static gsm_a_stat_t		gsm_a_stat;
 
 
@@ -145,6 +149,9 @@ gsm_a_stat_packet(
 	case PD_SS:
 	    stat_p->dtap_ss_message_type[data_p->message_type]++;
 	    break;
+	case PD_TP:
+	    stat_p->dtap_tp_message_type[data_p->message_type]++;
+	    break;
 	default:
 	    /*
 	     * unsupported PD
@@ -153,6 +160,18 @@ gsm_a_stat_packet(
 	}
 	break;
 
+   case GSM_A_PDU_TYPE_SACCH:
+   switch (data_p->protocol_disc)
+   {
+   case 0:
+      stat_p->sacch_rr_message_type[data_p->message_type]++;
+      break;
+   default:
+      /* unknown Short PD */
+      break;
+   }
+   break;
+
     default:
 	/*
 	 * unknown PDU type !!!
@@ -256,6 +275,20 @@ gsm_a_stat_draw(
 	    stat_p->dtap_ss_message_type,
 	    gsm_a_dtap_msg_ss_strings);
     }
+
+    if (dlg_dtap_tp.win != NULL)
+    {
+	gsm_a_stat_draw_aux(&dlg_dtap_tp,
+	    stat_p->dtap_tp_message_type,
+	    gsm_a_dtap_msg_tp_strings);
+    }
+
+    if (dlg_sacch_rr.win != NULL)
+    {
+	gsm_a_stat_draw_aux(&dlg_sacch_rr,
+	    stat_p->sacch_rr_message_type,
+	    gsm_a_sacch_msg_rr_strings);
+    }
 }
 
 
@@ -661,6 +694,70 @@ gsm_a_stat_gtk_dtap_ss_init(
     gsm_a_stat_gtk_dtap_ss_cb(NULL, NULL);
 }
 
+static void
+gsm_a_stat_gtk_dtap_tp_cb(
+    GtkWidget		*w _U_,
+    gpointer		d _U_)
+{
+    gsm_a_stat_gtk_dtap_cb(w, d, &dlg_dtap_tp,
+	"GSM A-I/F DTAP Special Conformance Testing Functions Statistics",
+	gsm_a_dtap_msg_tp_strings);
+}
+
+static void
+gsm_a_stat_gtk_dtap_tp_init(
+    const char		*optarg _U_,
+    void		*userdata _U_)
+{
+    gsm_a_stat_gtk_dtap_tp_cb(NULL, NULL);
+}
+
+static void
+gsm_a_stat_gtk_sacch_rr_cb(
+    GtkWidget		*w _U_,
+    gpointer		d _U_)
+{
+    int			i;
+
+
+    /*
+     * if the window is already open, bring it to front
+     */
+    if (dlg_sacch_rr.win)
+    {
+	gdk_window_raise(dlg_sacch_rr.win->window);
+	return;
+    }
+
+    gsm_a_stat_gtk_win_create(&dlg_sacch_rr, "GSM A-I/F SACCH Statistics");
+
+    i = 0;
+    while (gsm_a_sacch_msg_rr_strings[i].strptr)
+    {
+	dlg_sacch_rr.entries[0] = g_strdup_printf("0x%02x",
+						gsm_a_sacch_msg_rr_strings[i].value);
+
+	dlg_sacch_rr.entries[1] = g_strdup(gsm_a_sacch_msg_rr_strings[i].strptr);
+
+	dlg_sacch_rr.entries[2] = g_strdup("0");
+
+	gtk_clist_insert(GTK_CLIST(dlg_sacch_rr.table), i, dlg_sacch_rr.entries);
+	gtk_clist_set_row_data(GTK_CLIST(dlg_sacch_rr.table), i, (gpointer)(long)  i);
+
+	i++;
+    }
+
+    gsm_a_stat_draw(&gsm_a_stat);
+}
+
+
+static void
+gsm_a_stat_gtk_sacch_rr_init(
+    const char		*optarg _U_,
+    void* userdata _U_)
+{
+    gsm_a_stat_gtk_sacch_rr_cb(NULL, NULL);
+}
 
 void
 register_tap_listener_gtkgsm_a_stat(void)
@@ -678,7 +775,7 @@ register_tap_listener_gtkgsm_a_stat(void)
 
     if (err_p != NULL)
     {
-	simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, err_p->str);
+	simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", err_p->str);
 	g_string_free(err_p, TRUE);
 
 	exit(1);
@@ -715,4 +812,12 @@ register_tap_listener_gtkgsm_a_stat(void)
     register_stat_menu_item("GSM/A-Interface DTAP/Supplementary Services", REGISTER_STAT_GROUP_TELEPHONY,
 	gsm_a_stat_gtk_dtap_ss_cb, NULL, NULL, NULL);
     register_stat_cmd_arg("gsm_a,dtap_ss", gsm_a_stat_gtk_dtap_ss_init,NULL);
+
+    register_stat_menu_item("GSM/A-Interface DTAP/Special Conformance Testing Functions", REGISTER_STAT_GROUP_TELEPHONY,
+	gsm_a_stat_gtk_dtap_tp_cb, NULL, NULL, NULL);
+    register_stat_cmd_arg("gsm_a,dtap_tp", gsm_a_stat_gtk_dtap_tp_init,NULL);
+
+    register_stat_menu_item("GSM/A-Interface SACCH", REGISTER_STAT_GROUP_TELEPHONY,
+	gsm_a_stat_gtk_sacch_rr_cb, NULL, NULL, NULL);
+    register_stat_cmd_arg("gsm_a,sacch", gsm_a_stat_gtk_sacch_rr_init,NULL);
 }
