@@ -5,7 +5,7 @@
  *
  * MUCH code modified from service_response_time_table.c.
  *
- * $Id: gsm_map_stat.c 24968 2008-04-13 01:54:20Z ulfl $
+ * $Id: gsm_map_stat.c 26641 2008-10-31 09:53:56Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -472,7 +472,7 @@ register_tap_listener_gtkgsm_map_stat(void)
 
     if (err_p != NULL)
     {
-	simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, err_p->str);
+	simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", err_p->str);
 	g_string_free(err_p, TRUE);
 
 	exit(1);
