@@ -3,7 +3,7 @@
  * and some with GUI-independent APIs, with this file containing the GTK+
  * implementations of them (declared in ui_util.h)
  *
- * $Id: gui_utils.c 25672 2008-07-08 02:25:30Z wmeier $
+ * $Id: gui_utils.c 26535 2008-10-24 00:42:09Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -45,6 +45,9 @@
 
 #include "image/wsicon16.xpm"
 
+#ifdef _WIN32
+#include <windows.h>
+#endif
 
 #define WINDOW_GEOM_KEY "window_geom"
 
@@ -169,14 +172,14 @@ window_new_with_geom(GtkWindowType type, const gchar *title, const gchar *geom_n
 }
 
 
-/* Create a new window for a splash screen; it's a main window, with no title,
+/* Create a new window for a splash screen; it's a main window, without decoration,
    positioned in the center of the screen. */
 GtkWidget *
 splash_window_new(void)
 {
   GtkWidget *win;
 
-  win = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+  win = window_new(GTK_WINDOW_TOPLEVEL, "Wireshark");
   gtk_window_set_decorated(GTK_WINDOW(win), FALSE);
 
   /* set the initial position (must be done, before show is called!) */
