@@ -1,7 +1,7 @@
 /* io_stat.c
  * io_stat   2002 Ronnie Sahlberg
  *
- * $Id: io_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: io_stat.c 27070 2008-12-20 01:39:16Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -59,6 +59,7 @@
 #include "gtk/help_dlg.h"
 #include "gtk/pixmap_save.h"
 #include "gtk/main.h"
+#include "gtk/filter_autocomplete.h"
 
 
 #define MAX_GRAPHS 5
@@ -123,6 +124,12 @@ typedef struct _io_item_t {
 	gint32 int_max;
 	gint32 int_min;
 	gint32 int_tot;
+	gfloat float_max;
+	gfloat float_min;
+	gfloat float_tot;
+	gdouble double_max;
+	gdouble double_min;
+	gdouble double_tot;
 	nstime_t time_max;
 	nstime_t time_min;
 	nstime_t time_tot;
@@ -207,6 +214,12 @@ io_stat_reset(io_stat_t *io)
 			ioi->int_max=0;
 			ioi->int_min=0;
 			ioi->int_tot=0;
+			ioi->float_max=0;
+			ioi->float_min=0;
+			ioi->float_tot=0;
+			ioi->double_max=0;
+			ioi->double_min=0;
+			ioi->double_tot=0;
 			nstime_set_zero(&ioi->time_max);
 			nstime_set_zero(&ioi->time_min);
 			nstime_set_zero(&ioi->time_tot);
@@ -311,6 +324,8 @@ gtk_iostat_packet(void *g, packet_info *pinfo, epan_dissect_t *edt, const void *
 		 */
 		for(i=0;i<gp->len;i++){
 			int new_int;
+			float new_float;
+			double new_double;
 			nstime_t *new_time;
 
 			switch(proto_registrar_get_ftype(git->hf_index)){
@@ -343,6 +358,28 @@ gtk_iostat_packet(void *g, packet_info *pinfo, epan_dissect_t *edt, const void *
 				it->int_tot+=new_int;
 				it->fields++;
 				break;
+			case FT_FLOAT:
+				new_float=(gfloat)fvalue_get_floating(&((field_info *)gp->pdata[i])->value);
+				if((new_float>it->float_max)||(it->fields==0)){
+					it->float_max=new_float;
+				}
+				if((new_float<it->float_min)||(it->fields==0)){
+					it->float_min=new_float;
+				}
+				it->float_tot+=new_float;
+				it->fields++;
+				break;
+			case FT_DOUBLE:
+				new_double=fvalue_get_floating(&((field_info *)gp->pdata[i])->value);
+				if((new_double>it->double_max)||(it->fields==0)){
+					it->double_max=new_double;
+				}
+				if((new_double<it->double_min)||(it->fields==0)){
+					it->double_min=new_double;
+				}
+				it->double_tot+=new_double;
+				it->fields++;
+				break;
 			case FT_RELATIVE_TIME:
 				new_time=fvalue_get(&((field_info *)gp->pdata[0])->value);
 
@@ -449,7 +486,7 @@ get_frame_num(io_stat_t *io, guint32 idx, gboolean first)
 static guint32
 get_it_value(io_stat_t *io, int graph_id, int idx)
 {
-	guint32 value=0;
+	double value=0;
 	int adv_type;
 	io_item_t *it;
 
@@ -508,6 +545,56 @@ get_it_value(io_stat_t *io, int graph_id, int idx)
 			break;
 		}
 		break;
+	case FT_FLOAT:
+		switch(io->graphs[graph_id].calc_type){
+		case CALC_TYPE_SUM:
+			value=it->float_tot;
+			break;
+		case CALC_TYPE_COUNT:
+			value=it->frames;
+			break;
+		case CALC_TYPE_MAX:
+			value=it->float_max;
+			break;
+		case CALC_TYPE_MIN:
+			value=it->float_min;
+			break;
+		case CALC_TYPE_AVG:
+			if(it->fields){
+				value=it->float_tot/it->fields;
+			} else {
+				value=0;
+			}
+			break;
+		default:
+			break;
+		}
+		break;
+	case FT_DOUBLE:
+		switch(io->graphs[graph_id].calc_type){
+		case CALC_TYPE_SUM:
+			value=it->double_tot;
+			break;
+		case CALC_TYPE_COUNT:
+			value=it->frames;
+			break;
+		case CALC_TYPE_MAX:
+			value=it->double_max;
+			break;
+		case CALC_TYPE_MIN:
+			value=it->double_min;
+			break;
+		case CALC_TYPE_AVG:
+			if(it->fields){
+				value=it->double_tot/it->fields;
+			} else {
+				value=0;
+			}
+			break;
+		default:
+			break;
+		}
+		break;
 	case FT_RELATIVE_TIME:
 		switch(io->graphs[graph_id].calc_type){
 		case CALC_TYPE_COUNT:
@@ -543,7 +630,7 @@ get_it_value(io_stat_t *io, int graph_id, int idx)
 	default:
 		break;
 	}
-	return value;
+	return (guint32)value; /* FIXME: loss of precision, visible on the graph for small values */
 }
 
 
@@ -1038,9 +1125,15 @@ io_stat_draw(io_stat_t *io)
 
 
 	/* update the scrollbar */
-	io->scrollbar_adjustment->upper=(gfloat) io->max_interval;
-	io->scrollbar_adjustment->step_increment=(gfloat) ((last_interval-first_interval)/10);
-	io->scrollbar_adjustment->page_increment=(gfloat) (last_interval-first_interval);
+	if (io->max_interval == 0) {
+		io->scrollbar_adjustment->upper=(gfloat) io->interval;
+		io->scrollbar_adjustment->step_increment=(gfloat) (io->interval/10);
+		io->scrollbar_adjustment->page_increment=(gfloat) io->interval;
+	} else {
+		io->scrollbar_adjustment->upper=(gfloat) io->max_interval;
+		io->scrollbar_adjustment->step_increment=(gfloat) ((last_interval-first_interval)/10);
+		io->scrollbar_adjustment->page_increment=(gfloat) (last_interval-first_interval);
+	}
 	io->scrollbar_adjustment->page_size=io->scrollbar_adjustment->page_increment;
 	io->scrollbar_adjustment->value=(gfloat)first_interval;
 	gtk_adjustment_changed(io->scrollbar_adjustment);
@@ -1208,6 +1301,7 @@ gtk_iostat_init(const char *optarg _U_, void* userdata _U_)
 	init_io_stat_window(io);
 
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(io->window->window);
 	io_stat_redraw(io);
 }
 
@@ -1409,6 +1503,7 @@ tick_interval_select(GtkWidget *item, gpointer key)
 
 	io->interval=val;
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(io->window->window);
 	io_stat_redraw(io);
 }
 
@@ -1713,6 +1808,8 @@ filter_callback(GtkWidget *widget _U_, io_stat_graph_t *gio)
 		case FT_INT16:
 		case FT_INT24:
 		case FT_INT32:
+		case FT_FLOAT:
+		case FT_DOUBLE:
 			/* these values support all calculations except LOAD */
 			switch(gio->calc_type){
 			case CALC_TYPE_LOAD:
@@ -1761,13 +1858,9 @@ filter_callback(GtkWidget *widget _U_, io_stat_graph_t *gio)
 			}
 			break;
 		default:
-			/*
-			 * XXX - support all operations on floating-point
-			 * numbers?
-			 */
 			if(gio->calc_type!=CALC_TYPE_COUNT){
 				simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK,
-				    "%s doesn't have integral values, so %s calculations are not supported on it.",
+				    "%s doesn't have integral or float values, so %s calculations are not supported on it.",
 				    field,
 				    calc_type_names[gio->calc_type]);
 				disable_graph(gio);
@@ -1800,6 +1893,7 @@ filter_callback(GtkWidget *widget _U_, io_stat_graph_t *gio)
 	io_stat_reset(gio->io);
 	enable_graph(gio, filter, field);
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(gio->io->window->window);
 	io_stat_redraw(gio->io);
 
 	return 0;
@@ -1871,6 +1965,12 @@ create_advanced_field(io_stat_graph_t *gio, GtkWidget *box)
 	gtk_box_pack_start(GTK_BOX(box), gio->calc_field, TRUE, TRUE, 0);
 	gtk_widget_show(gio->calc_field);
 	g_signal_connect(gio->calc_field, "activate", G_CALLBACK(filter_callback), gio);
+	g_object_set_data (G_OBJECT(gio->calc_field), E_FILT_FIELD_NAME_ONLY_KEY, "");
+	g_signal_connect(gio->calc_field, "changed", G_CALLBACK(filter_te_syntax_check_cb), NULL);
+	g_object_set_data(G_OBJECT(box), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+	g_signal_connect(gio->calc_field, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+	g_signal_connect(gio->io->window, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
+	colorize_filter_te_as_empty(gio->calc_field);
 }
 
 
@@ -1960,6 +2060,10 @@ create_filter_box(io_stat_graph_t *gio, GtkWidget *box, int num)
 	gtk_widget_show(gio->filter_field);
 	g_signal_connect(gio->filter_field, "activate", G_CALLBACK(filter_callback), gio);
 	g_signal_connect(gio->filter_field, "changed", G_CALLBACK(filter_te_syntax_check_cb), NULL);
+	g_object_set_data(G_OBJECT(box), E_FILT_AUTOCOMP_PTR_KEY, NULL);
+	g_signal_connect(gio->filter_field, "key-press-event", G_CALLBACK (filter_string_te_key_pressed_cb), NULL);
+	g_signal_connect(gio->io->window, "key-press-event", G_CALLBACK (filter_parent_dlg_key_pressed_cb), NULL);
+	colorize_filter_te_as_empty(gio->filter_field);
 
 	create_advanced_box(gio, hbox);
 
@@ -2109,7 +2213,7 @@ init_io_stat_window(io_stat_t *io)
 
 	copy_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_COPY);
 	gtk_tooltips_set_tip(tooltips, copy_bt,
-			     "Copy values from selected graphs to the clipboard in CSV (Comma Seperated Values) format", NULL);
+			     "Copy values from selected graphs to the clipboard in CSV (Comma Separated Values) format", NULL);
 	g_signal_connect(copy_bt, "clicked", G_CALLBACK(copy_as_csv_cb), io);
 
 	help_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_HELP);
