@@ -1,7 +1,7 @@
 /* proto_draw.c
  * Routines for GTK+ packet display
  *
- * $Id: main_proto_draw.c 25634 2008-06-29 15:51:43Z wmeier $
+ * $Id: main_proto_draw.c 26835 2008-11-24 20:27:57Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -185,8 +185,10 @@ redraw_hex_dump_all(void)
      gtk_text_buffer doesn't seem to trigger an update.
      The only workaround is to freshly select the frame, which will remove any
      existing notebook tabs and "restart" the whole byte view again. */
-  if (cfile.current_frame != NULL)
+  if (cfile.current_frame != NULL) {
+    cfile.current_row = -1;
     cf_goto_frame(&cfile, cfile.current_frame->num);
+  }
 }
 
 static void
