@@ -1,6 +1,6 @@
 /* main_welcome.c
  *
- * $Id: main_welcome.c 26371 2008-10-07 15:18:40Z stig $
+ * $Id: main_welcome.c 26899 2008-12-02 08:11:23Z jmayer $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -57,6 +57,11 @@
 #include "../image/wssplash-dev.xpm"
 #include "../version_info.h"
 
+#ifdef HAVE_AIRPCAP
+#include "airpcap.h"
+#include "airpcap_loader.h"
+#include "airpcap_gui_utils.h"
+#endif
 
 /* XXX */
 extern gint if_list_comparator_alph (const void *first_arg, const void *second_arg);
@@ -275,7 +280,7 @@ welcome_header_new(void)
     g_string_append(message, "</span>");
 
     if (prefs.gui_version_in_start_page) {
-        g_string_append_printf(message, "\n<span size=\"large\">Version " VERSION "%s</span>",
+        g_string_append_printf(message, "\n<span size=\"large\" foreground=\"black\">Version " VERSION "%s</span>",
                                wireshark_svnversion);
     }
 
@@ -423,7 +428,7 @@ welcome_filename_link_new(const gchar *filename, GtkWidget **label)
 
 /* reset the list of recent files */
 void
-main_welcome_reset_recent_capture_files()
+main_welcome_reset_recent_capture_files(void)
 {
     GtkWidget *child_box;
     GList* child_list;
@@ -485,6 +490,12 @@ welcome_if_press_cb(GtkWidget *widget _U_, GdkEvent *event _U_, gpointer data)
         global_capture_opts.save_file = NULL;
     }
 
+#ifdef HAVE_AIRPCAP
+    airpcap_if_active = get_airpcap_if_from_name(airpcap_if_list, global_capture_opts.iface);
+    airpcap_if_selected = airpcap_if_active;
+    airpcap_set_toolbar_start_capture(airpcap_if_active);
+#endif
+
     capture_start_cb(NULL, NULL);
 
     return FALSE;
