@@ -2,7 +2,7 @@
  * Routines for saving pixmaps using the Gdk-Pixmap library
  * Copyright 2007, Stephen Fisher <stephentfisher@yahoo.com>
  *
- * $Id: pixmap_save.c 24145 2008-01-20 16:53:53Z stig $
+ * $Id: pixmap_save.c 24969 2008-04-13 03:32:24Z ulfl $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -27,22 +27,21 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
+#include <errno.h>
 
-#include <glib.h>
 #include <gtk/gtk.h>
 
-/* This feature is not available in GTK1 and includes some functions that
- * are only available in GTK 2.6+ */
 #if GTK_CHECK_VERSION(2,6,0)
 
-#include "pixmap_save.h"
-#include "simple_dialog.h"
-#include "gui_utils.h"
-#include "file_dlg.h"
-#include "compat_macros.h"
-#include <errno.h>
 #include <epan/filesystem.h>
 
+#include "../simple_dialog.h"
+
+#include "gtk/pixmap_save.h"
+#include "gtk/gui_utils.h"
+#include "gtk/file_dlg.h"
+
+
 static GtkWidget *save_as_w;
 
 static void
@@ -61,7 +60,7 @@ pixbuf_save_button_cb(GtkWidget *save_as_w, GdkPixbuf *pixbuf)
 	gboolean ret;
 
 	filename = g_strdup(gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(save_as_w)));
-	type_cm = OBJECT_GET_DATA(save_as_w, "type_cm");
+	type_cm = g_object_get_data(G_OBJECT(save_as_w), "type_cm");
 	file_type = gtk_combo_box_get_active_text(GTK_COMBO_BOX(type_cm));
 	
 	/* Perhaps the user specified a directory instead of a file.
@@ -95,7 +94,7 @@ pixbuf_save_button_cb(GtkWidget *save_as_w, GdkPixbuf *pixbuf)
 void
 pixmap_save_cb(GtkWidget *w, gpointer pixmap_ptr _U_)
 {
-	GdkPixmap *pixmap = OBJECT_GET_DATA(w, "pixmap");
+        GdkPixmap *pixmap = g_object_get_data(G_OBJECT(w), "pixmap");
 	GdkPixbuf *pixbuf;
 	GdkPixbufFormat *pixbuf_format;
 	GtkWidget *main_vb, *save_as_type_hb, *type_lb, *type_cm;
@@ -154,10 +153,10 @@ pixmap_save_cb(GtkWidget *w, gpointer pixmap_ptr _U_)
 	g_slist_free(file_formats);
 
 	gtk_combo_box_set_active(GTK_COMBO_BOX(type_cm), 0);
-	OBJECT_SET_DATA(save_as_w, "type_cm", type_cm);
+	g_object_set_data(G_OBJECT(save_as_w), "type_cm", type_cm);
 	gtk_widget_show(type_cm);
 
-	SIGNAL_CONNECT(save_as_w, "destroy", pixbuf_save_destroy_cb, NULL);
+	g_signal_connect(save_as_w, "destroy", G_CALLBACK(pixbuf_save_destroy_cb), NULL);
 
 	gtk_widget_show(save_as_w);
 	window_present(save_as_w);
