@@ -1,7 +1,7 @@
 /* gui_prefs.c
  * Dialog box for GUI preferences
  *
- * $Id: prefs_gui.c 25968 2008-08-09 16:14:34Z stig $
+ * $Id: prefs_gui.c 27070 2008-12-20 01:39:16Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -64,6 +64,8 @@ static gint recent_df_entries_changed_cb(GtkWidget *recent_df_entry _U_,
 #define GEOMETRY_SIZE_KEY		"geometry_size"
 #define GEOMETRY_MAXIMIZED_KEY		"geometry_maximized"
 
+#define MACOSX_STYLE_KEY		"macosx_style"
+
 #define GUI_CONSOLE_OPEN_KEY "console_open"
 #define GUI_FILEOPEN_KEY	"fileopen_behavior"
 #define GUI_FILEOPEN_PREVIEW_KEY "fileopen_preview_timeout"
@@ -74,6 +76,7 @@ static gint recent_df_entries_changed_cb(GtkWidget *recent_df_entry _U_,
 #define GUI_WEBBROWSER_KEY	    "webbrowser"
 #define GUI_FIND_WRAP_KEY       "find_wrap"
 #define GUI_USE_PREF_SAVE_KEY   "use_pref_save"
+#define GUI_SHOW_VERSION_KEY    "show_version"
 
 static const enum_val_t scrollbar_placement_vals[] _U_ = {
 	{ "FALSE", "Left", FALSE },
@@ -163,8 +166,12 @@ gui_prefs_show(void)
 	GtkWidget *fileopen_rb, *fileopen_dir_te, *fileopen_preview_te;
 	GtkWidget *recent_files_count_max_te, *recent_df_entries_max_te, *ask_unsaved_cb, *find_wrap_cb;
 	GtkWidget *use_pref_save_cb;
+	GtkWidget *show_version_cb;
 	GtkWidget *webbrowser_te;
 	GtkWidget *save_position_cb, *save_size_cb, *save_maximized_cb;
+#ifdef HAVE_IGE_MAC_INTEGRATION
+	GtkWidget *macosx_style_cb;
+#endif
 
 	GtkTooltips *tooltips = gtk_tooltips_new();
 
@@ -219,9 +226,19 @@ gui_prefs_show(void)
 	save_maximized_cb = create_preference_check_button(main_tb, pos++,
 	    "Save maximized state:", NULL, prefs.gui_geometry_save_maximized);
 	gtk_tooltips_set_tip(tooltips, save_maximized_cb, "Whether to save the "
-		"maximed state of the main window.", NULL);
+		"maximized state of the main window.", NULL);
 	g_object_set_data(G_OBJECT(main_vb), GEOMETRY_MAXIMIZED_KEY, save_maximized_cb);
 
+#ifdef HAVE_IGE_MAC_INTEGRATION
+	macosx_style_cb = create_preference_check_button(main_tb, pos++,
+	    "MacOS X style", NULL, prefs.gui_macosx_style);
+	gtk_tooltips_set_tip(tooltips, macosx_style_cb, "Whether to create a "
+	   "MacOS X look and feel. Checking this box will move the menu bar to "
+           "the top of the screen instead of the top of the Wireshark window. "
+           "Requires a restart of Wireshark to take effect.", NULL);
+	g_object_set_data(G_OBJECT(main_vb), MACOSX_STYLE_KEY, macosx_style_cb);
+#endif
+
 #ifdef _WIN32
 	/* How the console window should be opened */
 	console_open_om = create_preference_option_menu(main_tb, pos++,
@@ -302,6 +319,13 @@ gui_prefs_show(void)
 		"use an explicit save button - for advanced users.", NULL);
 	g_object_set_data(G_OBJECT(main_vb), GUI_USE_PREF_SAVE_KEY, use_pref_save_cb);
 
+	/* Show version in welcome screen */
+	show_version_cb = create_preference_check_button(main_tb, pos++,
+	    "Welcome screen shows version:", NULL, prefs.gui_version_in_start_page );
+	gtk_tooltips_set_tip(tooltips, show_version_cb, 
+                "Whether version should be shown in the start page or not", NULL);
+	g_object_set_data(G_OBJECT(main_vb), GUI_SHOW_VERSION_KEY, show_version_cb);
+
 	/* Webbrowser */
 	if (browser_needs_pref()) {
 	    webbrowser_te = create_preference_entry(main_tb, pos++, 
@@ -379,6 +403,11 @@ gui_prefs_fetch(GtkWidget *w)
 	prefs.gui_geometry_save_maximized =
 	    gtk_toggle_button_get_active(g_object_get_data(G_OBJECT(w), GEOMETRY_MAXIMIZED_KEY));
 
+#ifdef HAVE_IGE_MAC_INTEGRATION
+	prefs.gui_macosx_style =
+	    gtk_toggle_button_get_active(g_object_get_data(G_OBJECT(w), MACOSX_STYLE_KEY));
+#endif
+
 #ifdef _WIN32
 	prefs.gui_console_open = fetch_enum_value(
 	    g_object_get_data(G_OBJECT(w), GUI_CONSOLE_OPEN_KEY), gui_console_open_vals);
@@ -400,6 +429,9 @@ gui_prefs_fetch(GtkWidget *w)
     prefs.gui_use_pref_save = 
         gtk_toggle_button_get_active(g_object_get_data(G_OBJECT(w), GUI_USE_PREF_SAVE_KEY));
 
+	prefs.gui_version_in_start_page  = 
+        gtk_toggle_button_get_active(g_object_get_data(G_OBJECT(w), GUI_SHOW_VERSION_KEY));
+
     if (browser_needs_pref()) {
 		g_free(prefs.gui_webbrowser);
 	    prefs.gui_webbrowser = g_strdup(gtk_entry_get_text(
