@@ -2,7 +2,7 @@
  * radius-statistics for Wireshark
  * Copyright 2006 Alejandro Vaquero <alejandrovaquero@yahoo.com>
  *
- * $Id: radius_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: radius_stat.c 27070 2008-12-20 01:39:16Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -83,7 +83,7 @@ static const value_string radius_message_code[] = {
   {  2,	"Accounting"},
   {  3,	"Access Password"},
   {  4, "Ascend Access Event"},
-  {  5, "Diconnect"},
+  {  5, "Disconnect"},
   {  6, "Change Filter"},
   {  7, "Other"},
   {  0, NULL}
@@ -331,7 +331,7 @@ gtk_radiusstat_init(const char *optarg, void *userdata _U_)
 
 	error_string=register_tap_listener("radius", rs, filter, radiusstat_reset, radiusstat_packet, radiusstat_draw);
 	if(error_string){
-		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
+		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
 		g_string_free(error_string, TRUE);
 		g_free(rs->filter);
 		g_free(rs);
@@ -352,6 +352,7 @@ gtk_radiusstat_init(const char *optarg, void *userdata _U_)
 	window_present(rs->win);
 
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(rs->win->window);
 }
 
 static tap_dfilter_dlg radius_srt_dlg = {
