@@ -1,7 +1,7 @@
 /* 
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_assoc_analyse.c 25673 2008-07-08 02:43:40Z wmeier $
+ * $Id: sctp_assoc_analyse.c 26641 2008-10-31 09:53:56Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -838,7 +838,7 @@ static void sctp_analyse_cb(struct sctp_analyse* u_data, gboolean ext)
 
 	g_strlcpy(filter_text,"sctp",250);
 	if (!dfilter_compile(filter_text, &sfcode)) {
-		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, dfilter_error_msg);
+		simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", dfilter_error_msg);
 		return;
 	}
 
