@@ -1,7 +1,7 @@
 /*
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: sctp_stat.c 26641 2008-10-31 09:53:56Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -1260,7 +1260,7 @@ register_tap_listener_sctp_stat(void)
 	if (!sctp_tapinfo_struct.is_registered)
 	{
 		if ((error_string = register_tap_listener("sctp", &sctp_tapinfo_struct, NULL, reset, packet, sctp_update))) {
-			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
+			simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
 			g_string_free(error_string, TRUE);
 			return;
 		}
