@@ -1,7 +1,7 @@
 /* 
  * Copyright 2004, Irene Ruengeler <i.ruengeler [AT] fh-muenster.de>
  *
- * $Id: sctp_stat.h 20630 2007-01-30 19:30:25Z gerald $
+ * $Id: sctp_stat.h 26535 2008-10-24 00:42:09Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -24,10 +24,14 @@
  
 #include <epan/dissectors/packet-sctp.h>
 #include <epan/address.h>
-#ifndef WIN32
+#ifndef _WIN32
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
+#else
+#ifdef HAVE_WINSOCK2_H
+#include <winsock2.h>
+#endif
 #endif
 
 #define SCTP_DATA_CHUNK_ID               0
@@ -83,13 +87,13 @@
 #define MAX_ADDRESS_LEN                47
 #define NUM_CHUNKS                     13
 
-
 typedef struct _tsn {
 	guint32 frame_number;
 	guint32 secs;    /* Absolute seconds */
 	guint32 usecs;
 	address src;
 	address dst;
+	guint32	first_tsn;
 	GList   *tsns;
 } tsn_t;
 
@@ -122,6 +126,7 @@ struct tsn_sort{
 	guint32 usecs;
 	guint32 offset;
 	guint32 length;
+	guint32 framenumber;
 };
 
 typedef struct _sctp_addr_chunk {
