@@ -1,7 +1,7 @@
 /* simple_dialog.c
  * Simple message dialog box routines.
  *
- * $Id: simple_dialog.c 21549 2007-04-24 05:46:13Z sahlberg $
+ * $Id: simple_dialog.c 25634 2008-06-29 15:51:43Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -25,24 +25,25 @@
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
+#include <stdio.h>
 
 #include <gtk/gtk.h>
 
-#include <stdio.h>
-
-#include "gtkglobals.h"
-#include "simple_dialog.h"
-#include "dlg_utils.h"
-#include "gui_utils.h"
-#include "compat_macros.h"
-
 #include <epan/strutil.h>
 
+#include "../simple_dialog.h"
+
+#include "gtk/gtkglobals.h"
+#include "gtk/dlg_utils.h"
+#include "gtk/gui_utils.h"
+#include "gtk/stock_icons.h"
+
 #include "image/stock_dialog_error_48.xpm"
 #include "image/stock_dialog_info_48.xpm"
 #include "image/stock_dialog_warning_48.xpm"
 #include "image/stock_dialog_stop_48.xpm"
 
+
 static void simple_dialog_cancel_cb(GtkWidget *, gpointer);
 
 #define CALLBACK_FCT_KEY    "ESD_Callback_Fct"
@@ -137,7 +138,7 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
   }
 
   gtk_window_set_modal(GTK_WINDOW(win), TRUE);
-  gtk_container_border_width(GTK_CONTAINER(win), 6);
+  gtk_container_set_border_width(GTK_CONTAINER(win), 6);
 
   /* Container for our rows */
   main_vb = gtk_vbox_new(FALSE, 12);
@@ -146,7 +147,7 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
 
   /* Top row: Icon and message text */
   top_hb = gtk_hbox_new(FALSE, 12);
-  gtk_container_border_width(GTK_CONTAINER(main_vb), 6);
+  gtk_container_set_border_width(GTK_CONTAINER(main_vb), 6);
   gtk_container_add(GTK_CONTAINER(main_vb), top_hb);
   gtk_widget_show(top_hb);
 
@@ -169,11 +170,9 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
   /* message */
   msg_label = gtk_label_new(message);
 
-#if GTK_MAJOR_VERSION >= 2
   gtk_label_set_markup(GTK_LABEL(msg_label), message);
   gtk_label_set_selectable(GTK_LABEL(msg_label), TRUE);
-#endif
-#if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION >= 9) || GTK_MAJOR_VERSION > 2
+#if GTK_CHECK_VERSION(2,9,0)
   g_object_set(gtk_widget_get_settings(msg_label),
     "gtk-label-select-on-focus", FALSE, NULL);
 #endif
@@ -192,7 +191,7 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
   /* optional check button */
   ask_cb = gtk_check_button_new_with_label("replace with text...");
   gtk_container_add(GTK_CONTAINER(msg_vb), ask_cb);
-  OBJECT_SET_DATA(win, CHECK_BUTTON, ask_cb);
+  g_object_set_data(G_OBJECT(win), CHECK_BUTTON, ask_cb);
 
   /* Button row */
   switch(btn_mask) {
@@ -222,44 +221,44 @@ display_simple_dialog(gint type, gint btn_mask, char *message)
   gtk_container_add(GTK_CONTAINER(main_vb), bbox);
   gtk_widget_show(bbox);
 
-  ok_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_OK);
+  ok_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_OK);
   if(ok_bt) {
-      OBJECT_SET_DATA(ok_bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_OK));
-      SIGNAL_CONNECT(ok_bt, "clicked", simple_dialog_cancel_cb, win);
+      g_object_set_data(G_OBJECT(ok_bt), CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_OK));
+      g_signal_connect(ok_bt, "clicked", G_CALLBACK(simple_dialog_cancel_cb), win);
   }
 
-  save_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_SAVE);
+  save_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_SAVE);
   if (save_bt) {
-      OBJECT_SET_DATA(save_bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_SAVE));
-      SIGNAL_CONNECT(save_bt, "clicked", simple_dialog_cancel_cb, win);
+      g_object_set_data(G_OBJECT(save_bt), CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_SAVE));
+      g_signal_connect(save_bt, "clicked", G_CALLBACK(simple_dialog_cancel_cb), win);
   }
 
-  dont_save_bt = OBJECT_GET_DATA(bbox, WIRESHARK_STOCK_DONT_SAVE);
+  dont_save_bt = g_object_get_data(G_OBJECT(bbox), WIRESHARK_STOCK_DONT_SAVE);
   if (dont_save_bt) {
-      OBJECT_SET_DATA(dont_save_bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_DONT_SAVE));
-      SIGNAL_CONNECT(dont_save_bt, "clicked", simple_dialog_cancel_cb, win);
+      g_object_set_data(G_OBJECT(dont_save_bt), CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_DONT_SAVE));
+      g_signal_connect(dont_save_bt, "clicked", G_CALLBACK(simple_dialog_cancel_cb), win);
   }
-  bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CLEAR);
+  bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CLEAR);
   if(bt) {
-      OBJECT_SET_DATA(bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_CLEAR));
-      SIGNAL_CONNECT(bt, "clicked", simple_dialog_cancel_cb, win);
+      g_object_set_data(G_OBJECT(bt), CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_CLEAR));
+      g_signal_connect(bt, "clicked", G_CALLBACK(simple_dialog_cancel_cb), win);
   }
 
-  yes_bt = OBJECT_GET_DATA(bbox, GTK_STOCK_YES);
+  yes_bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_YES);
   if(yes_bt) {
-      OBJECT_SET_DATA(yes_bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_YES));
-      SIGNAL_CONNECT(yes_bt, "clicked", simple_dialog_cancel_cb, win);
+      g_object_set_data(G_OBJECT(yes_bt), CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_YES));
+      g_signal_connect(yes_bt, "clicked", G_CALLBACK(simple_dialog_cancel_cb), win);
   }
 
-  bt = OBJECT_GET_DATA(bbox, GTK_STOCK_NO);
+  bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_NO);
   if(bt) {
-      OBJECT_SET_DATA(bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_NO));
-      SIGNAL_CONNECT(bt, "clicked", simple_dialog_cancel_cb, win);
+      g_object_set_data(G_OBJECT(bt), CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_NO));
+      g_signal_connect(bt, "clicked", G_CALLBACK(simple_dialog_cancel_cb), win);
   }
 
-  bt = OBJECT_GET_DATA(bbox, GTK_STOCK_CANCEL);
+  bt = g_object_get_data(G_OBJECT(bbox), GTK_STOCK_CANCEL);
   if(bt) {
-      OBJECT_SET_DATA(bt, CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_CANCEL));
+      g_object_set_data(G_OBJECT(bt), CALLBACK_BTN_KEY, GINT_TO_POINTER(ESD_BTN_CANCEL));
       window_set_cancel_button(win, bt, simple_dialog_cancel_cb);
   }
 
@@ -312,22 +311,15 @@ vsimple_dialog(ESD_TYPE_E type, gint btn_mask, const gchar *msg_format, va_list
   gchar             *message;
   queued_message_t *queued_message;
   GtkWidget        *win;
-#if GTK_MAJOR_VERSION >= 2
   GdkWindowState state = 0;
-#endif
 
   /* Format the message. */
   vmessage = g_strdup_vprintf(msg_format, ap);
 
-#if GTK_MAJOR_VERSION >= 2
   /* convert character encoding from locale to UTF8 (using iconv) */
   message = g_locale_to_utf8(vmessage, -1, NULL, NULL, NULL);
   g_free(vmessage);
-#else
-  message = vmessage;
-#endif
 
-#if GTK_MAJOR_VERSION >= 2
   if (top_level != NULL) {
     state = gdk_window_get_state(top_level->window);
   }
@@ -336,12 +328,7 @@ vsimple_dialog(ESD_TYPE_E type, gint btn_mask, const gchar *msg_format, va_list
      dialog. If showing up a dialog, while main window is iconified, program
      will become unresponsive! */
   if (top_level == NULL || state & GDK_WINDOW_STATE_ICONIFIED) {
-#else
 
-  /* If we don't yet have a main window, queue up the message for later
-     display. */
-  if (top_level == NULL) {
-#endif
     queued_message = g_malloc(sizeof (queued_message_t));
     queued_message->type = type;
     queued_message->btn_mask = btn_mask;
@@ -376,9 +363,9 @@ simple_dialog(ESD_TYPE_E type, gint btn_mask, const gchar *msg_format, ...)
 
 static void
 simple_dialog_cancel_cb(GtkWidget *w, gpointer win) {
-  gint button = GPOINTER_TO_INT(    OBJECT_GET_DATA(w, CALLBACK_BTN_KEY));
-  simple_dialog_cb_t    callback_fct    = OBJECT_GET_DATA(win, CALLBACK_FCT_KEY);
-  gpointer              data            = OBJECT_GET_DATA(win, CALLBACK_DATA_KEY);
+  gint button                           = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(w), CALLBACK_BTN_KEY));
+  simple_dialog_cb_t    callback_fct    = g_object_get_data(G_OBJECT(win), CALLBACK_FCT_KEY);
+  gpointer              data            = g_object_get_data(G_OBJECT(win), CALLBACK_DATA_KEY);
 
   if (callback_fct)
     (callback_fct) (win, button, data);
@@ -389,40 +376,38 @@ simple_dialog_cancel_cb(GtkWidget *w, gpointer win) {
 void
 simple_dialog_close(gpointer dialog)
 {
-	window_destroy(GTK_WIDGET(dialog));
+    window_destroy(GTK_WIDGET(dialog));
 }
 
 void simple_dialog_set_cb(gpointer dialog, simple_dialog_cb_t callback_fct, gpointer data)
 {
 
-    OBJECT_SET_DATA(GTK_WIDGET(dialog), CALLBACK_FCT_KEY, callback_fct);
-    OBJECT_SET_DATA(GTK_WIDGET(dialog), CALLBACK_DATA_KEY, data);
+    g_object_set_data(G_OBJECT(GTK_WIDGET(dialog)), CALLBACK_FCT_KEY, callback_fct);
+    g_object_set_data(G_OBJECT(GTK_WIDGET(dialog)), CALLBACK_DATA_KEY, data);
 }
 
 void simple_dialog_check_set(gpointer dialog, gchar *text _U_) {
-    GtkWidget *ask_cb = OBJECT_GET_DATA(dialog, CHECK_BUTTON);
+    GtkWidget *ask_cb = g_object_get_data(G_OBJECT(dialog), CHECK_BUTTON);
 
-#if GTK_MAJOR_VERSION >= 2
     /* XXX - find a way to set the GtkButton label in GTK 1.x */
     gtk_button_set_label(GTK_BUTTON(ask_cb), text);
-#endif
     gtk_widget_show(ask_cb);
 }
 
 gboolean simple_dialog_check_get(gpointer dialog) {
-    GtkWidget *ask_cb = OBJECT_GET_DATA(GTK_WIDGET(dialog), CHECK_BUTTON);
+    GtkWidget *ask_cb = g_object_get_data(G_OBJECT(GTK_WIDGET(dialog)), CHECK_BUTTON);
 
     return gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(ask_cb));
 }
 
 char *
 simple_dialog_primary_start(void) {
-    return PRIMARY_TEXT_START;
+    return "<span weight=\"bold\" size=\"larger\">";
 }
 
 char *
 simple_dialog_primary_end(void) {
-    return PRIMARY_TEXT_END;
+    return "</span>";
 }
 
 char *
@@ -431,11 +416,7 @@ simple_dialog_format_message(const char *msg)
     char *str;
 
     if (msg) {
-#if GTK_MAJOR_VERSION < 2
-	str = g_strdup(msg);
-#else
 	str = xml_escape(msg);
-#endif
     } else {
 	str = NULL;
     }
