@@ -1,7 +1,7 @@
 /* sip_stat.c
  * sip_stat   2004 Martin Mathieson
  *
- * $Id: sip_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: sip_stat.c 26641 2008-10-31 09:53:56Z stig $
  * Copied from http_stat.c
  *
  * Wireshark - Network traffic analyzer
@@ -630,7 +630,7 @@ gtk_sipstat_init(const char *optarg, void *userdata _U_)
     if (error_string)
     {
         /* Error.  We failed to attach to the tap. Clean up */
-        simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str);
+        simple_dialog(ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str);
         g_free(sp->filter);
         g_free(sp);
         g_string_free(error_string, TRUE);
@@ -653,6 +653,7 @@ gtk_sipstat_init(const char *optarg, void *userdata _U_)
 
     sip_init_hash(sp);
     cf_retap_packets(&cfile, FALSE);
+    gdk_window_raise(sp->win->window);
 }
 
 static tap_dfilter_dlg sip_stat_dlg = {
