@@ -1,9 +1,8 @@
-
 /* stats_tree_stat.c
  * GTK Tap implementation of stats_tree
  * 2005, Luis E. G. Ontanon
  *
- * $Id: stats_tree_stat.c 25933 2008-08-05 17:33:14Z morriss $
+ * $Id: stats_tree_stat.c 26641 2008-10-31 09:53:56Z stig $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -308,7 +307,7 @@ init_gtk_tree(const char* optarg, void *userdata _U_)
 
 	if (error_string) {
 		/* error, we failed to attach to the tap. clean up */
-		simple_dialog( ESD_TYPE_ERROR, ESD_BTN_OK, error_string->str );
+		simple_dialog( ESD_TYPE_ERROR, ESD_BTN_OK, "%s", error_string->str );
 		/* destroy_stat_tree_window(st); */
 		report_failure("stats_tree for: %s failed to attach to the tap: %s",cfg->name,error_string->str);
 		g_string_free(error_string, TRUE);
@@ -328,6 +327,7 @@ init_gtk_tree(const char* optarg, void *userdata _U_)
 	window_present(st->pr->win);
 
 	cf_retap_packets(&cfile, FALSE);
+	gdk_window_raise(st->pr->win->window);
 }
 
 
