@@ -1,7 +1,7 @@
 /*
  *  uat_gui.c
  *
- *  $Id: uat_gui.c 25946 2008-08-06 12:03:16Z lego $
+ *  $Id: uat_gui.c 26641 2008-10-31 09:53:56Z stig $
  *
  *  User Accessible Tables GUI
  *  Mantain an array of user accessible data strucures
@@ -153,7 +153,7 @@ static char* fld_tostr(void* rec, uat_field_t* f) {
 			
 			for (i=0; i<len;i++) g_string_append_printf(s,"%.2X",((guint8*)ptr)[i]);
 			
-			out = ep_strdup_printf(s->str);
+			out = ep_strdup(s->str);
 			
 			g_string_free(s,TRUE);
 			break;
