@@ -5,7 +5,7 @@
  *
  * Author: Lu Pan <lu.pan@intel.com>
  *
- * $Id: packet-m2m.c 22435 2007-08-01 17:42:43Z jake $
+ * $Id: packet-m2m.c 27224 2009-01-13 20:47:06Z jake $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -37,7 +37,6 @@
 #include <string.h>
 #include <glib.h>
 #include <epan/packet.h>
-#include <epan/prefs.h>
 #include <epan/reassemble.h>
 #include <epan/etypes.h>
 #include <plugins/wimax/wimax_tlv.h>
@@ -60,7 +59,6 @@ guint g_frame_number = 0;
 
 /* Local Variables */
 static gint proto_m2m = -1;
-static dissector_handle_t m2m_handle = NULL;
 static dissector_handle_t wimax_fch_burst_handle = NULL;
 static dissector_handle_t wimax_cdma_code_burst_handle = NULL;
 static dissector_handle_t wimax_pdu_burst_handle = NULL;
@@ -369,31 +367,24 @@ m2m_defragment_init(void)
 /* Register Wimax Mac to Mac Protocol handler */
 void proto_reg_handoff_m2m(void)
 {
-	static int Initialized = FALSE;
+	dissector_handle_t m2m_handle;
 
-	if (!Initialized)
-	{
-		m2m_handle = create_dissector_handle(dissect_m2m, proto_m2m);
-		dissector_add("ethertype", ETHERTYPE_WMX_M2M, m2m_handle);
-	}
+	m2m_handle = create_dissector_handle(dissect_m2m, proto_m2m);
+	dissector_add("ethertype", ETHERTYPE_WMX_M2M, m2m_handle);
 }
 
 /* Register Wimax Mac to Mac Protocol */
 void proto_register_m2m(void)
 {
-	if (proto_m2m == -1)
-	{
-		proto_m2m = proto_register_protocol (
-							"WiMax Mac to Mac Packet", /* name */
-							"M2M  (m2m)", /* short name */
-							"m2m" /* abbrev */
-							);
+	proto_m2m = proto_register_protocol (
+		"WiMax Mac to Mac Packet", /* name */
+		"M2M  (m2m)", /* short name */
+		"m2m" /* abbrev */
+		);
 
-		proto_register_field_array(proto_m2m, hf, array_length(hf));
-		proto_register_field_array(proto_m2m, hf_tlv, array_length(hf_tlv));
-		proto_register_subtree_array(ett, array_length(ett));
-	}
-	prefs_register_protocol(proto_m2m, proto_reg_handoff_m2m);
+	proto_register_field_array(proto_m2m, hf, array_length(hf));
+	proto_register_field_array(proto_m2m, hf_tlv, array_length(hf_tlv));
+	proto_register_subtree_array(ett, array_length(ett));
 
 	/* init the PDU fragment table */
 	fragment_table_init(&pdu_frag_table);
@@ -461,7 +452,7 @@ static void dissect_m2m(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			tlv_len = get_tlv_length(&m2m_tlv_info);
 			if(tlv_type == -1 || tlv_len > 64000 || tlv_len < 1)
 			{	/* invalid tlv info */
-				if(pinfo->cinfo)
+				if (check_col(pinfo->cinfo, COL_INFO))
 				{
 					col_append_sep_str(pinfo->cinfo, COL_INFO, ", ", "M2M TLV error");
 				}
@@ -472,7 +463,7 @@ static void dissect_m2m(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			/* get the TLV value offset */
 			tlv_offset = get_tlv_value_offset(&m2m_tlv_info);
 			/* display TLV type */
-			ti = proto_tree_add_protocol_format(m2m_tree, proto_m2m, tvb, offset, (tlv_len + tlv_offset), val_to_str(tlv_type, tlv_name, "Unknown TLV"));
+			ti = proto_tree_add_protocol_format(m2m_tree, proto_m2m, tvb, offset, (tlv_len + tlv_offset), "%s", val_to_str(tlv_type, tlv_name, "Unknown TLV"));
 			/* add TLV subtree */
 			tlv_tree = proto_item_add_subtree(ti, ett_m2m_tlv);
 			/* update the offset */
@@ -797,7 +788,7 @@ void proto_tree_add_tlv(tlv_info_t *this, tvbuff_t *tvb, guint offset, packet_in
 	/* make sure the TLV information is valid */
 	if(!this->valid)
 	{	/* invalid TLV info */
-		if(pinfo->cinfo)
+		if (check_col(pinfo->cinfo, COL_INFO))
 		{
 			col_append_sep_fstr(pinfo->cinfo, COL_INFO, NULL, "Invalid TLV");
 		}
