@@ -3,7 +3,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: mate_setup.c 25937 2008-08-05 21:03:46Z lego $
+* $Id: mate_setup.c 27085 2008-12-22 15:24:18Z wmeier $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -628,8 +628,8 @@ extern mate_config* mate_make_config(const gchar* filename, int mate_hfid) {
 	if ( mate_load_config(filename,matecfg) ) {
 		analyze_config();
 	} else {
-		report_failure("MATE failed to configue!\n"
-					   "It is recommended that you fix your config and restart wireshark.\n"
+		report_failure("MATE failed to configure!\n"
+					   "It is recommended that you fix your config and restart Wireshark.\n"
 					   "The reported error is:\n%s\n",matecfg->config_error->str);
 		
 		/* if (matecfg) destroy_mate_config(matecfg,FALSE); */
