@@ -4,7 +4,7 @@
 *
 * Copyright 2004, Luis E. Garcia Ontanon <luis@ontanon.org>
 *
-* $Id: mate_util.c 26163 2008-09-07 17:49:03Z guy $
+* $Id: mate_util.c 27085 2008-12-22 15:24:18Z wmeier $
 *
 * Wireshark - Network traffic analyzer
 * By Gerald Combs <gerald@wireshark.org>
@@ -63,7 +63,7 @@ void dbg_print(const gint* which, gint how, FILE* where, const gchar* fmt, ... )
 	va_end( list );
 
 	if (! where) {
-		g_message(debug_buffer);
+		g_message("%s", debug_buffer);
 	} else {
 		fputs(debug_buffer,where);
 		fputs("\n",where);
@@ -224,7 +224,7 @@ void scs_unsubscribe(SCS_collection* c, gchar* s) {
 			(*ip)--;
 		}
 	} else {
-		g_warning("unsusbcribe: not subscribed");
+		g_warning("unsubscribe: not subscribed");
 	}
 }
 
