@@ -2,7 +2,7 @@
  * Routines for PN-DCP (PROFINET Discovery and basic Configuration Protocol) 
  * packet dissection.
  *
- * $Id: packet-pn-dcp.c 24122 2008-01-17 19:30:35Z ulfl $
+ * $Id: packet-pn-dcp.c 25490 2008-06-19 18:44:23Z ulfl $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -130,11 +130,11 @@ static const value_string pn_dcp_service_type[] = {
 static const value_string pn_dcp_block_error[] = {
 	{ 0x00, "Ok" },
 	{ 0x01, "Option unsupp." },
-	{ 0x02, "Suboption unsupp." },
+	{ 0x02, "Suboption unsupp. or no DataSet avail." },
 	{ 0x03, "Suboption not set" },
-	{ 0x04, "Manufacturer specific" },
-	{ 0x05, "Manufacturer specific" },
-	{ 0x06, "Ressource Error" },
+	{ 0x04, "Ressource Error" },
+	{ 0x05, "SET not possible by local reasons" },
+	{ 0x06, "In operation, SET not possible" },
     /* all others reserved */
     { 0, NULL }
 };
