@@ -2,7 +2,7 @@
  * Routines for Ether-S-Bus dissection 
  * Copyright 2006, Christian Durrer <christian.durrer@sensemail.ch>
  *
- * $Id: packet-sbus.c 26103 2008-08-29 01:40:32Z wmeier $
+ * $Id: packet-sbus.c 27085 2008-12-22 15:24:18Z wmeier $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -176,9 +176,6 @@
 #define F_INFO_B2      (1<<4)         /* EEPROM information of slot B2*/
 #define F_PGU_BAUD (1<<5)             /* PGU baudrate can be switched*/
 
-/* Forward declaration we need below */
-void proto_reg_handoff_sbus(void);
-
 /* Initialize the protocol and registered fields */
 static int proto_sbus = -1;
 static int hf_sbus_length = -1;
@@ -414,7 +411,7 @@ static const value_string sbus_command_vals[] = {
 };
 
 static const value_string webserver_aid_vals[] = {
-       {0x01, "Partitial request"},
+       {0x01, "Partial request"},
        {0x02, "Request end"},
        {0x07, "Get Data"},
        {0x10, "Transfer OK"},
