@@ -1,7 +1,7 @@
 /* print.c
  * Routines for printing packet analysis trees.
  *
- * $Id: print.c 25901 2008-08-01 17:36:09Z jake $
+ * $Id: print.c 26850 2008-11-26 07:34:57Z jake $
  *
  * Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -745,6 +745,9 @@ write_pdml_field_hex_value(write_pdml_data *pdata, field_info *fi)
 	int i;
 	const guint8 *pd;
 
+	if (!fi->ds_tvb)
+		return;
+
 	if (fi->length > tvb_length_remaining(fi->ds_tvb, fi->start)) {
 		fprintf(pdata->fh, "field length invalid!");
 		return;
@@ -1111,7 +1114,7 @@ print_preamble_ps(print_stream_t *self, gchar *filename)
 	fputs("\n", output->fh);
 	fputs("%% the page title\n", output->fh);
 	ps_clean_string(psbuffer, filename, MAX_PS_LINE_LENGTH);
-	fprintf(output->fh, "/eth_pagetitle (%s - Wireshark " VERSION "%s) def\n", psbuffer, wireshark_svnversion);
+	fprintf(output->fh, "/ws_pagetitle (%s - Wireshark " VERSION "%s) def\n", psbuffer, wireshark_svnversion);
 	fputs("\n", output->fh);
 	return !ferror(output->fh);
 }
@@ -1550,6 +1553,9 @@ get_field_hex_value(GSList* src_list, field_info *fi)
 {
     const guint8 *pd;
 
+    if (!fi->ds_tvb)
+        return NULL;
+
     if (fi->length > tvb_length_remaining(fi->ds_tvb, fi->start)) {
         return "field length invalid!";
     }
