@@ -4,7 +4,7 @@
  * Creates random packet traces. Useful for debugging sniffers by testing
  * assumptions about the veracity of the data found in the packet.
  *
- * $Id: randpkt.c 21945 2007-05-25 23:40:42Z gerald $
+ * $Id: randpkt.c 26799 2008-11-17 21:46:57Z gerald $
  *
  * Copyright (C) 1999 by Gilbert Ramirez <gram@alumni.rice.edu>
  *
@@ -455,13 +455,14 @@ main(int argc, char **argv)
 	int			produce_max_bytes = 5000;
 	pkt_example		*example;
 
-	while ((opt = getopt(argc, argv, "b:c:t:")) != -1) {
+	while ((opt = getopt(argc, argv, "b:c:ht:")) != -1) {
 		switch (opt) {
 			case 'b':	/* max bytes */
 				produce_max_bytes = atoi(optarg);
 				if (produce_max_bytes > 65536) {
-					printf("Max bytes is 65536\n");
-					exit(0);
+					fprintf(stderr,
+					    "randpkt: Max bytes is 65536\n");
+					exit(1);
 				}
 				break;
 
@@ -473,6 +474,7 @@ main(int argc, char **argv)
 				produce_type = parse_type(optarg);
 				break;
 
+			case 'h':
 			default:
 				usage();
 				break;
@@ -495,18 +497,22 @@ main(int argc, char **argv)
 
 	dump = wtap_dump_open(produce_filename, WTAP_FILE_PCAP,
 		example->sample_wtap_encap, produce_max_bytes, FALSE /* compressed */, &err);
-    if (!dump) {
-        printf("Error writing to %s\n", produce_filename);
-        exit(1);
-    }
+	if (!dump) {
+		fprintf(stderr,
+		    "randpkt: Error writing to %s\n", produce_filename);
+		exit(2);
+	}
 
 	seed();
 
 	/* reduce max_bytes by # of bytes already in sample */
 	if (produce_max_bytes <= example->sample_length) {
-		printf("Sample packet length is %d, which is greater than or equal to\n", example->sample_length);
-		printf("your requested max_bytes value of %d\n", produce_max_bytes);
-		exit(0);
+		fprintf(stderr,
+		    "randpkt: Sample packet length is %d, which is greater than or equal to\n",
+		    example->sample_length);
+		fprintf(stderr, "your requested max_bytes value of %d\n",
+		    produce_max_bytes);
+		exit(1);
 	}
 	else {
 		produce_max_bytes -= example->sample_length;
@@ -585,7 +591,7 @@ int parse_type(char *string)
 	}
 
 	/* Complain */
-	printf("Type %s not known.\n", string);
+	fprintf(stderr, "randpkt: Type %s not known.\n", string);
 	exit(1);
 }
 
@@ -602,7 +608,9 @@ pkt_example* find_example(int type)
 		}
 	}
 
-	printf("Internal error. Type %d has no entry in examples table.\n", type);
+	fprintf(stderr,
+	    "randpkt: Internal error. Type %d has no entry in examples table.\n",
+	    type);
 	exit(1);
 }
 
@@ -611,24 +619,48 @@ void
 seed(void)
 {
 	unsigned int	randomness;
-
-#if defined(linux)
-	/* Okay, I should use #ifdef HAVE_DEV_RANDOM, but this is a quick hack */
+	time_t now;
+#ifndef _WIN32
 	int 		fd;
+	ssize_t		ret;
 
+	/*
+	 * Assume it's at least worth trying /dev/random on UN*X.
+	 * If it doesn't exist, fall back on time().
+	 *
+	 * XXX - does Windows have a system source of entropy?
+	 */
 	fd = open("/dev/random", O_RDONLY);
-	if (fd < 0) {
-		printf("Could not open /dev/random for reading: %s\n", strerror(errno));
-		exit(0);
+	if (fd == -1) {
+		if (errno != ENOENT) {
+			fprintf(stderr,
+			    "randpkt: Could not open /dev/random for reading: %s\n",
+			    strerror(errno));
+			exit(2);
+		}
+		goto fallback;
 	}
 
-	read(fd, &randomness, sizeof(randomness));
-#else
-	time_t now;
+	ret = read(fd, &randomness, sizeof randomness);
+	if (ret == -1) {
+		fprintf(stderr,
+		    "randpkt: Could not read from /dev/random: %s\n",
+		    strerror(errno));
+		exit(2);
+	}
+	if ((size_t)ret != sizeof randomness) {
+		fprintf(stderr,
+		    "randpkt: Tried to read %lu bytes from /dev/random, got %ld\n",
+		    (unsigned long)sizeof randomness, (long)ret);
+		exit(2);
+	}
+	srand(randomness);
+	return;
 
+fallback:
+#endif
 	now = time(NULL);
 	randomness = (unsigned int) now;
-#endif
 
 	srand(randomness);
 }
