@@ -1,7 +1,7 @@
 /* version_info.c
  * Routines to report version information for stuff used by Wireshark
  *
- * $Id: version_info.c 26113 2008-09-02 11:17:03Z wmeier $
+ * $Id: version_info.c 27194 2009-01-08 13:24:04Z kukosa $
  *
  * Wireshark - Network traffic analyzer
  * By Gerald Combs <gerald@wireshark.org>
@@ -87,6 +87,10 @@
 # include <sys/capability.h>
 #endif
 
+#ifdef HAVE_GEOIP
+#include <epan/geoip_db.h>
+#endif
+
 #ifdef SVNVERSION
 	const char *wireshark_svnversion = " (" SVNVERSION ")";
 #else
@@ -214,8 +218,7 @@ get_epan_compiled_version_info(GString *str)
         /* SNMP */
 	g_string_append(str, ", ");
 #ifdef HAVE_LIBSMI
-	g_string_append(str, "with SMI ");
-	g_string_append(str, SMI_VERSION_STRING);
+	g_string_append(str, "with SMI " SMI_VERSION_STRING);
 #else /* no SNMP library */
 	g_string_append(str, "without SMI");
 #endif /* _SMI_H */
@@ -223,19 +226,18 @@ get_epan_compiled_version_info(GString *str)
 	/* c-ares */
 	g_string_append(str, ", ");
 #ifdef HAVE_C_ARES
-	g_string_append(str, "with c-ares ");
-	g_string_append(str, ARES_VERSION_STR);
+	g_string_append(str, "with c-ares " ARES_VERSION_STR);
 #else
 	g_string_append(str, "without c-ares");
-#endif /* HAVE_C_ARES */
 
-	/* ADNS */
+	/* ADNS - only add if no c-ares */
 	g_string_append(str, ", ");
 #ifdef HAVE_GNU_ADNS
 	g_string_append(str, "with ADNS");
 #else
 	g_string_append(str, "without ADNS");
 #endif /* HAVE_GNU_ADNS */
+#endif /* HAVE_C_ARES */
 
         /* LUA */
 	g_string_append(str, ", ");
@@ -275,6 +277,15 @@ get_epan_compiled_version_info(GString *str)
 #else
 	g_string_append(str, "without Kerberos");
 #endif /* HAVE_KERBEROS */
+
+	/* GeoIP */
+	g_string_append(str, ", ");
+#ifdef HAVE_GEOIP
+	g_string_append(str, "with GeoIP");
+#else
+	g_string_append(str, "without GeoIP");
+#endif /* HAVE_GEOIP */
+
 }
 
 /*
@@ -285,7 +296,7 @@ void
 get_runtime_version_info(GString *str, void (*additional_info)(GString *))
 {
 #if defined(_WIN32)
-	OSVERSIONINFO info;
+	OSVERSIONINFOEX info;
 #elif defined(HAVE_SYS_UTSNAME_H)
 	struct utsname name;
 #endif
@@ -314,7 +325,7 @@ get_runtime_version_info(GString *str, void (*additional_info)(GString *))
 	 * older versions of the SDK.
 	 */
 	info.dwOSVersionInfoSize = sizeof info;
-	if (!GetVersionEx(&info)) {
+	if (!GetVersionEx((OSVERSIONINFO *)&info)) {
 		/*
 		 * XXX - get the failure reason.
 		 */
@@ -396,7 +407,15 @@ get_runtime_version_info(GString *str, void (*additional_info)(GString *))
 			break;
 
 		case 6:
-			g_string_append_printf(str, "Windows Vista");
+#ifndef VER_NT_WORKSTATION
+#define VER_NT_WORKSTATION 0x01
+			if ((info.wReserved[1] & 0xff) == VER_NT_WORKSTATION)
+#else
+			if (info.wProductType == VER_NT_WORKSTATION)
+#endif
+				g_string_append_printf(str, "Windows Vista");
+			else
+				g_string_append_printf(str, "Windows Server 2008");
 			break;
 
 		default:
@@ -473,6 +492,16 @@ get_runtime_version_info(GString *str, void (*additional_info)(GString *))
 	g_string_append(str, ", ");
 	get_runtime_pcap_version(str);
 
+    /* GnuTLS */
+#ifdef HAVE_LIBGNUTLS
+	g_string_append_printf(str, ", GnuTLS %s", gnutls_check_version(NULL));
+#endif /* HAVE_LIBGNUTLS */
+
+        /* Gcrypt */
+#ifdef HAVE_LIBGCRYPT
+	g_string_append_printf(str, ", Gcrypt %s", gcry_check_version(NULL));
+#endif /* HAVE_LIBGCRYPT */
+
 	/* Additional application-dependent information */
 	if (additional_info)
 		(*additional_info)(str);
@@ -554,7 +583,7 @@ const char *
 get_copyright_info(void)
 {
 	return
-"Copyright 1998-2008 Gerald Combs <gerald@wireshark.org> and contributors.\n"
+"Copyright 1998-2009 Gerald Combs <gerald@wireshark.org> and contributors.\n"
 "This is free software; see the source for copying conditions. There is NO\n"
 "warranty; not even for MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n";
 }
