@@ -1,6 +1,6 @@
 /* file_access.c
  *
- * $Id: file_access.c 26212 2008-09-15 21:50:50Z jake $
+ * $Id: file_access.c 27176 2009-01-07 07:21:31Z jake $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -77,6 +77,8 @@
 #include "commview.h"
 #include "pcapng.h"
 #include "btsnoop.h"
+#include "tnef.h"
+#include "dct3trace.h"
 
 
 /* The open_file_* routines should return:
@@ -121,6 +123,8 @@ static wtap_open_routine_t open_routines_base[] = {
 	mpeg_open,
 	pcapng_open,
 	btsnoop_open,
+	tnef_open,
+	dct3trace_open,
 	/* Files that don't have magic bytes at a fixed location,
 	 * but that instead require a heuristic of some sort to
 	 * identify them.  This includes the ASCII trace files that
@@ -205,7 +209,7 @@ void wtap_register_open_routine(wtap_open_routine_t open_routine, gboolean has_m
    written to as new packets arrive independently of random I/O done
    to display protocol trees for packets when they're selected. */
 wtap* wtap_open_offline(const char *filename, int *err, char **err_info,
-    gboolean do_random)
+			gboolean do_random)
 {
 	struct stat statb;
 	wtap	*wth;
@@ -582,7 +586,16 @@ static const struct file_type_info dump_open_table_base[] = {
 	  pcapng_dump_can_write_encap, pcapng_dump_open },
 
 	/* WTAP_FILE_BTSNOOP */
-	{ "Symbian OS btsnoop", "btsnoop", "*.log", NULL, FALSE, NULL, NULL }
+	{ "Symbian OS btsnoop", "btsnoop", "*.log", NULL, FALSE, NULL, NULL },
+        
+	/* WTAP_FILE_X2E_XORAYA */
+	{ NULL, NULL, NULL, NULL, FALSE, NULL, NULL },
+
+	/* WTAP_FILE_TNEF */
+	{ "Transport-Neutral Encapsulation Format", "tnef", "*.*", NULL, FALSE, NULL, NULL },
+
+	/* WTAP_FILE_DCT3TRACE */
+	{ "Gammu DCT3 trace", "dct3trace", "*.xml", NULL, FALSE, NULL, NULL }
 };
 
 gint wtap_num_file_types = sizeof(dump_open_table_base) / sizeof(struct file_type_info);
@@ -707,7 +720,7 @@ gboolean wtap_dump_can_compress(int filetype _U_)
 
 static gboolean wtap_dump_open_check(int filetype, int encap, gboolean comressed, int *err);
 static wtap_dumper* wtap_dump_alloc_wdh(int filetype, int encap, int snaplen,
-    gboolean compressed, int *err);
+					gboolean compressed, int *err);
 static gboolean wtap_dump_open_finish(wtap_dumper *wdh, int filetype, gboolean compressed, int *err);
 
 static FILE *wtap_dump_file_open(wtap_dumper *wdh, const char *filename);
@@ -783,9 +796,9 @@ wtap_dumper* wtap_dump_fdopen(int fd, int filetype, int encap, int snaplen,
 		return NULL;	/* couldn't allocate it */
 
 #ifdef _WIN32
-    if(fd == 1) {
+	if(fd == 1) {
 		setmode(fileno(stdout), O_BINARY);
-    }
+	}
 #endif
 
 	/* In case "fopen()" fails but doesn't set "errno", set "errno"
@@ -870,11 +883,11 @@ static gboolean wtap_dump_open_finish(wtap_dumper *wdh, int filetype, gboolean c
 	} else {
 		fd = fileno(wdh->fh);
 		if (lseek(fd, 1, SEEK_CUR) == -1)
-		  cant_seek = TRUE;
+			cant_seek = TRUE;
 		else {
-		  /* Undo the seek. */
-		  lseek(fd, 0, SEEK_SET);
-		  cant_seek = FALSE;
+			/* Undo the seek. */
+			lseek(fd, 0, SEEK_SET);
+			cant_seek = FALSE;
 		}
 	}
 
@@ -887,7 +900,7 @@ static gboolean wtap_dump_open_finish(wtap_dumper *wdh, int filetype, gboolean c
 }
 
 gboolean wtap_dump(wtap_dumper *wdh, const struct wtap_pkthdr *phdr,
-    const union wtap_pseudo_header *pseudo_header, const guchar *pd, int *err)
+		   const union wtap_pseudo_header *pseudo_header, const guchar *pd, int *err)
 {
 	return (wdh->subtype_write)(wdh, phdr, pseudo_header, pd, err);
 }
@@ -926,10 +939,10 @@ gboolean wtap_dump_close(wtap_dumper *wdh, int *err)
 			}
 			ret = FALSE;
 		}
-    } else {
-        /* as we don't close stdout, at least try to flush it */
-        wtap_dump_flush(wdh);
-    }
+	} else {
+		/* as we don't close stdout, at least try to flush it */
+		wtap_dump_flush(wdh);
+	}
 	if (wdh->dump.opaque != NULL)
 		g_free(wdh->dump.opaque);
 	g_free(wdh);
