@@ -1,6 +1,6 @@
 /* lanalyzer.c
  *
- * $Id: lanalyzer.c 15602 2005-08-28 22:52:05Z guy $
+ * $Id: lanalyzer.c 21078 2007-03-21 01:32:50Z ulfl $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -118,8 +118,8 @@ static const guint8 LA_CyclicInformationFake[] = {
       };
 
 static gboolean lanalyzer_read(wtap *wth, int *err, gchar **err_info,
-    long *data_offset);
-static gboolean lanalyzer_seek_read(wtap *wth, long seek_off,
+    gint64 *data_offset);
+static gboolean lanalyzer_seek_read(wtap *wth, gint64 seek_off,
     union wtap_pseudo_header *pseudo_header, guchar *pd, int length,
     int *err, gchar **err_info);
 static void     lanalyzer_close(wtap *wth);
@@ -274,7 +274,7 @@ int lanalyzer_open(wtap *wth, int *err, gchar **err_info)
 
 /* Read the next packet */
 static gboolean lanalyzer_read(wtap *wth, int *err, gchar **err_info,
-    long *data_offset)
+    gint64 *data_offset)
 {
 	int		packet_size = 0;
 	int		bytes_read;
@@ -396,7 +396,7 @@ static gboolean lanalyzer_read(wtap *wth, int *err, gchar **err_info,
 	return TRUE;
 }
 
-static gboolean lanalyzer_seek_read(wtap *wth, long seek_off,
+static gboolean lanalyzer_seek_read(wtap *wth, gint64 seek_off,
     union wtap_pseudo_header *pseudo_header, guchar *pd, int length,
     int *err, gchar **err_info _U_)
 {
@@ -576,7 +576,7 @@ static gboolean lanalyzer_dump(wtap_dumper *wdh,
       if (*err)
             return FALSE;
 
-	  tv.tv_sec  = phdr->ts.secs;
+	  tv.tv_sec  = (long int) phdr->ts.secs;
 	  tv.tv_usec = phdr->ts.nsecs / 1000;
 
       if (!itmp->init) {
@@ -714,7 +714,7 @@ gboolean lanalyzer_dump_open(wtap_dumper *wdh, gboolean cant_seek, int *err)
 static gboolean lanalyzer_dump_header(wtap_dumper *wdh, int *err)
 {
       LA_TmpInfo *itmp   = (LA_TmpInfo*)(wdh->dump.opaque);
-      struct tm  *fT     = localtime(&(itmp->start.tv_sec));
+      struct tm  *fT     = localtime( (time_t *) &(itmp->start.tv_sec));
       guint16 board_type = itmp->encap == WTAP_ENCAP_TOKEN_RING
                               ? BOARD_325TR     /* LANalyzer Board Type */
                               : BOARD_325;      /* LANalyzer Board Type */
