@@ -1,6 +1,6 @@
 /* netxray.c
  *
- * $Id: netxray.c 19814 2006-11-05 22:46:44Z ulfl $
+ * $Id: netxray.c 27164 2009-01-06 13:31:28Z wmeier $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@alumni.rice.edu>
@@ -77,7 +77,9 @@ struct netxray_hdr {
 	guint32 linespeed;	/* speed of network, in bits/second		*/
 
 	guint8	xxx_x40[12];	/* unknown [other stuff]			*/
-	guint8	realtick[4];	/* in v2, means ???                     	*/
+	guint8	realtick[4];	/* (ticks/sec for Ethernet/Ndis/Timeunit=2 ?)	*/
+				/* (realtick[1], realtick[2] also currently	*/
+				/*  used as flag for 'FCS presence')		*/
 
 	guint8	xxx_x50[4];	/* unknown [other stuff]			*/
 	guint8	captype;	/* capture type					*/
@@ -99,11 +101,10 @@ struct netxray_hdr {
 /*
  * Capture type, in hdr.captype.
  *
- * XXX - S6040-model Sniffers with gigabit blades store 6 here for
- * Ethernet captures, and some other Ethernet captures had a capture
- * type of 3, so presumably the interpretation of the capture type
- * depends on the network type.  We prefix all the capture types
- * for WAN captures with WAN_.
+ * Values other than 0 are dependent on the network type.
+ * For Ethernet captures, it indicates the type of capture pod.
+ * For WAN captures (all of which are done with a pod), it indicates
+ * the link-layer type.
  */
 #define CAPTYPE_NDIS	0		/* Capture on network interface using NDIS 			*/
 
@@ -116,7 +117,7 @@ struct netxray_hdr {
 					/*  Captype 5 seen in capture from Distributed Sniffer with:	*/
 					/*    Version 4.50.211 software					*/
 					/*    SysKonnect SK-9843 Gigabit Ethernet Server Adapter	*/
-#define ETH_CAPTYPE_GIGPOD2	6	/* gigabit Ethernet captured with pod */
+#define ETH_CAPTYPE_GIGPOD2	6	/* gigabit Ethernet, captured with blade on S6040-model Sniffer */
 
 /*
  * WAN capture types.
@@ -132,6 +133,7 @@ struct netxray_hdr {
 #define WAN_CAPTYPE_SMDS	10	/* SMDS DXI */
 #define WAN_CAPTYPE_BROUTER4	11	/* Bridge/router captured with pod */
 #define WAN_CAPTYPE_BROUTER5	12	/* Bridge/router captured with pod */
+#define WAN_CAPTYPE_CHDLC 	19	/* Cisco router (CHDLC) captured with pod */
 
 #define CAPTYPE_ATM		15	/* ATM captured with pod */
 
@@ -147,37 +149,57 @@ struct netxray_hdr {
  *
  * Instead, if a value in a TpS table is wrong, check whether captype
  * has a non-zero value; if so, perhaps we need a new TpS table for the
- * corresponding network type and captype.
+ * corresponding network type and captype, or perhaps the 'realtick'
+ * field contains the correct ticks-per-second value.
  *
  * TpS...[] entries of 0.0 mean that no capture file for the
- * corresponding captype/timeunit values has yet been seen
+ * corresponding captype/timeunit values has yet been seen, or that
+ * we're using the 'realtick' value.
  *
- * Note that the "realtick" value is wrong in many captures, so
- * we no longer use it.  We don't know what significance it has.
- * In at least one capture where "realtick" doesn't correspond
- * to the value from the appropriate TpS table, the per-packet header's
- * "xxx" field is all zero, so it's not as if a 2.x header includes
- * a "compatibility" time stamp corresponding to the value from the
- * TpS table and a "real" time stamp corresponding to "realtick".
+ * XXX - 05/29/07: For Ethernet captype = 0 (NDIS) and timeunit = 2:
+ *  Perusal of a number of Sniffer captures
+ *  (including those from Wireshark bug reports
+ *  and those from the Wireshark 'menagerie)
+ *  suggests that 'realtick' for this case
+ *  contains the correct ticks/second to be used.
+ *  So: we'll use realtick for Ethernet captype=0 and timeunit=2.
+ *  (It might be that realtick should be used for Ethernet captype = 0 
+ *  and timeunit = 1 but I've not yet enough captures to be sure).
+ *   Based upon the captures reviewed to date, realtick cannot be used for
+ *   any of the other Ethernet captype/timeunit combinations for which there
+ *   are non-zero values in the TpS tables.
  *
- * XXX - the third item is 1193180.0, presumably because somebody found
- * it gave the right answer for some captures, but 3 times that, i.e.
- * 3579540.0, appears to give the right answer for some other captures.
- * Some captures have realtick of 1193182, some have 3579545, and some
- * have 1193000.  Most of those, in one set of captures somebody has,
- * are wrong.
+ *  In at least one capture where "realtick" doesn't correspond
+ *  to the value from the appropriate TpS table, the per-packet header's
+ *  "xxx" field is all zero, so it's not as if a 2.x header includes
+ *  a "compatibility" time stamp corresponding to the value from the
+ *  TpS table and a "real" time stamp corresponding to "realtick".
+ *
+ * XXX - the item corresponding to timeunit = 2 is 1193180.0, presumably
+ *  because somebody found it gave the right answer for some captures, but
+ *  3 times that, i.e. 3579540.0, appears to give the right answer for some
+ *  other captures.
+ *
+ *  Some captures have realtick of 1193182, some have 3579545, and some
+ *  have 1193000.  Most of those, in one set of captures somebody has,
+ *  are wrong.  (Did that mean "wrong for some capture files, but not
+ *  for the files in which they occurred", or "wrong for the files in
+ *  which they occurred?  If it's "wrong for some capture files, but
+ *  not for the files in which they occurred", perhaps those were Ethernet
+ *  captures with a captype of 0 and timeunit = 2, so that we now use
+ *  realtick, and perhaps that fixes the problems.)
  *
  * XXX - in at least one ATM capture, hdr.realtick is 1193180.0
- * and hdr.timeunit is 0.  Does that capture have a captype of
- * CAPTYPE_ATM?  If so, what should the table for ATM captures with
- * that captype be?
+ *  and hdr.timeunit is 0.  Does that capture have a captype of
+ *  CAPTYPE_ATM?  If so, what should the table for ATM captures with
+ *  that captype be?
  */
 static double TpS[] = { 1e6, 1193000.0, 1193182.0 };
 #define NUM_NETXRAY_TIMEUNITS (sizeof TpS / sizeof TpS[0])
 
 /*
  * Table of time units for Ethernet captures with captype ETH_CAPTYPE_GIGPOD.
- * 0.0 means "unknown.
+ * 0.0 means "unknown".
  *
  * It appears that, at least for Ethernet captures, if captype is
  * ETH_CAPTYPE_GIGPOD, that indicates that it's a gigabit Ethernet
@@ -191,24 +213,35 @@ static double TpS[] = { 1e6, 1193000.0, 1193182.0 };
  * the values below are correct; for 002.002, it's claimed that
  * the right value for TpS_gigpod[2] is 1250000.0, but at least one
  * 002.002 gigabit pod capture has 31250000.0 as the right value.
+ * XXX: Note that the TpS_otherpod[2] value is 1250000.0; It seems
+ *  reasonable to suspect that the original claim might actually 
+ *  have been for a capture with a captype of 'otherpod'.
+ * (Based upon captures reviewed realtick does not contain the 
+ *   correct TpS values for the 'gigpod' captype).
  */
 static double TpS_gigpod[] = { 1e9, 0.0, 31250000.0 };
 #define NUM_NETXRAY_TIMEUNITS_GIGPOD (sizeof TpS_gigpod / sizeof TpS_gigpod[0])
 
 /*
  * Table of time units for Ethernet captures with captype ETH_CAPTYPE_OTHERPOD.
+ *  (Based upon captures reviewed realtick does not contain the 
+ *   correct TpS values for the 'otherpod' captype).
  */
 static double TpS_otherpod[] = { 1e6, 0.0, 1250000.0 }; 
 #define NUM_NETXRAY_TIMEUNITS_OTHERPOD (sizeof TpS_otherpod / sizeof TpS_otherpod[0])
 
 /*
  * Table of time units for Ethernet captures with captype ETH_CAPTYPE_OTHERPOD2.
+ * (Based upon captures reviewed realtick does not contain the 
+ *   correct TpS values for the 'otherpod2' captype).
  */
 static double TpS_otherpod2[] = { 1e6, 0.0, 0.0 }; 
 #define NUM_NETXRAY_TIMEUNITS_OTHERPOD2 (sizeof TpS_otherpod2 / sizeof TpS_otherpod2[0])
 
 /*
  * Table of time units for Ethernet captures with captype ETH_CAPTYPE_GIGPOD2. 
+ * (Based upon captures reviewed realtick does not contain the 
+ *   correct TpS values for the 'gigpod2' captype).
  */
 static double TpS_gigpod2[] = { 1e9, 0.0, 20000000.0 };
 #define NUM_NETXRAY_TIMEUNITS_GIGPOD2 (sizeof TpS_gigpod2 / sizeof TpS_gigpod2[0])
@@ -301,7 +334,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 	gboolean is_old;
 	struct netxray_hdr hdr;
 	guint network_type;
-	double timeunit;
+	double ticks_per_sec;
 	int version_major, version_minor;
 	int file_type;
 	double start_timestamp;
@@ -450,12 +483,12 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 	switch (file_type) {
 
 	case WTAP_FILE_NETXRAY_OLD:
-		timeunit = 1000.0;
+		ticks_per_sec = 1000.0;
 		wth->tsprecision = WTAP_FILE_TSPREC_MSEC;
 		break;
 
 	case WTAP_FILE_NETXRAY_1_0:
-		timeunit = 1000.0;
+		ticks_per_sec = 1000.0;
 		wth->tsprecision = WTAP_FILE_TSPREC_MSEC;
 		break;
 
@@ -466,14 +499,14 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 		 * rather than the milliseconds time stamps in NetXRay
 		 * and older versions of Windows Sniffer.
 		 */
-		timeunit = 1000000.0;
+		ticks_per_sec = 1000000.0;
 		wth->tsprecision = WTAP_FILE_TSPREC_USEC;
 		break;
 
 	case WTAP_FILE_NETXRAY_2_00x:
 		/*
-		 * Get the time stamp value from the appropriate TpS
-		 * table.
+		 * Get the time stamp units from the appropriate TpS
+		 * table or from the file header.
 		 */
 		switch (network_type) {
 
@@ -492,7 +525,19 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 					    hdr.timeunit, hdr.version);
 					return -1;
 				}
-				timeunit = TpS[hdr.timeunit];
+				/* 
+				XXX: 05/29/07: Use 'realtick' instead of TpS table if timeunit=2;
+					Using 'realtick' in this case results
+					in the correct 'ticks per second' for all the captures that 
+					I have of this type (including captures from a number of Wirshark
+					bug reports).
+				*/
+				if (hdr.timeunit == 2) {
+					ticks_per_sec = pletohl(hdr.realtick);
+				}
+				else {
+					ticks_per_sec = TpS[hdr.timeunit];
+				}
 				break;
 
 			case ETH_CAPTYPE_GIGPOD:
@@ -504,7 +549,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 					    hdr.timeunit, hdr.version);
 					return -1;
 				}
-				timeunit = TpS_gigpod[hdr.timeunit];
+				ticks_per_sec = TpS_gigpod[hdr.timeunit];
 
 				/*
 				 * At least for 002.002 and 002.003
@@ -524,7 +569,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 					    hdr.timeunit, hdr.version);
 					return -1;
 				}
-				timeunit = TpS_otherpod[hdr.timeunit];
+				ticks_per_sec = TpS_otherpod[hdr.timeunit];
 
 				/*
 				 * At least for 002.002 and 002.003
@@ -544,7 +589,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 					    hdr.timeunit, hdr.version);
 					return -1;
 				}
-				timeunit = TpS_otherpod2[hdr.timeunit];
+				ticks_per_sec = TpS_otherpod2[hdr.timeunit];
 				/*
 				 * XXX: start time stamp in the one capture file examined of this type was 0;
 				 *      We'll assume the start time handling is the same as for other pods.
@@ -566,7 +611,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 					    hdr.timeunit, hdr.version);
 					return -1;
 				}
-				timeunit = TpS_gigpod2[hdr.timeunit];
+				ticks_per_sec = TpS_gigpod2[hdr.timeunit];
                                 /*
                                  * XXX: start time stamp in the one capture file examined of this type was 0;
                                  *      We'll assume the start time handling is the same as for other pods.
@@ -597,7 +642,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 				    hdr.version);
 				return -1;
 			}
-			timeunit = TpS[hdr.timeunit];
+			ticks_per_sec = TpS[hdr.timeunit];
 			break;
 		}
 
@@ -611,7 +656,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 		 * 1 microsecond to display more digits of precision?
 		 * XXX - Seems reasonable to use nanosecs only if TPS >= 10M
 		 */
-		if (timeunit >= 1e7)
+		if (ticks_per_sec >= 1e7)
 			wth->tsprecision = WTAP_FILE_TSPREC_NSEC;
 		else
 			wth->tsprecision = WTAP_FILE_TSPREC_USEC;
@@ -619,9 +664,9 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 
 	default:
 		g_assert_not_reached();
-		timeunit = 0.0;
+		ticks_per_sec = 0.0;
 	}
-	start_timestamp = start_timestamp/timeunit;
+	start_timestamp = start_timestamp/ticks_per_sec;
 
 	if (network_type == 4) {
 		/*
@@ -696,6 +741,13 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 				file_encap = WTAP_ENCAP_SDLC;
 				break;
 
+			case WAN_CAPTYPE_CHDLC:
+				/*
+				 *  Cisco router (CHDLC) captured with pod
+				 */
+				file_encap = WTAP_ENCAP_CHDLC_WITH_PHDR;
+				break;
+
 			default:
 				*err = WTAP_ERR_UNSUPPORTED_ENCAP;
 				*err_info = g_strdup_printf("netxray: WAN capture subtype 0x%02x unknown or unsupported",
@@ -716,7 +768,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 	wth->file_encap = file_encap;
 	wth->snapshot_length = 0;	/* not available in header */
 	wth->capture.netxray->start_time = pletohl(&hdr.start_time);
-	wth->capture.netxray->timeunit = timeunit;
+	wth->capture.netxray->ticks_per_sec = ticks_per_sec;
 	wth->capture.netxray->start_timestamp = start_timestamp;
 	wth->capture.netxray->version_major = version_major;
 
@@ -730,6 +782,7 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 	case WTAP_ENCAP_ETHERNET:
 	case WTAP_ENCAP_IEEE_802_11_WITH_RADIO:
 	case WTAP_ENCAP_ISDN:
+	case WTAP_ENCAP_LAPB:
 		/*
 		 * It appears that, in at least some version 2 Ethernet
 		 * captures, for frames that have 0xff in hdr_2_x.xxx[2]
@@ -797,6 +850,16 @@ int netxray_open(wtap *wth, int *err, gchar **err_info)
 		 * There don't seem to be any other values in any of the
 		 * xxx_x5..., xxx_x6...., xxx_x7.... fields
 		 * that obviously correspond to frames having an FCS.
+		 *
+		 * 05/29/07: Examination of numerous sniffer captures suggests
+		 *            that the apparent correlation of certain realtick 
+		 *            bytes to 'FCS presence' may actually be 
+		 *            a 'false positive'.
+		 *           ToDo: Review analysis and update code.
+		 *           It might be that the ticks-per-second value
+		 *           is hardware-dependent, and that hardware with
+		 *           a particular realtick value puts an FCS there
+		 *	     and other hardware doesn't.
 		 */
 		if (version_major == 2) {
 			if (hdr.realtick[1] == 0x34 && hdr.realtick[2] == 0x12)
@@ -930,7 +993,7 @@ reread:
 	if (wth->capture.netxray->version_major == 0) {
 		t = (double)pletohl(&hdr.old_hdr.timelo)
 		    + (double)pletohl(&hdr.old_hdr.timehi)*4294967296.0;
-		t /= wth->capture.netxray->timeunit;
+		t /= wth->capture.netxray->ticks_per_sec;
 		t -= wth->capture.netxray->start_timestamp;
 		wth->phdr.ts.secs = wth->capture.netxray->start_time + (long)t;
 		wth->phdr.ts.nsecs = (unsigned long)((t-(double)(unsigned long)(t))
@@ -944,7 +1007,7 @@ reread:
 	} else {
 		t = (double)pletohl(&hdr.hdr_1_x.timelo)
 		    + (double)pletohl(&hdr.hdr_1_x.timehi)*4294967296.0;
-		t /= wth->capture.netxray->timeunit;
+		t /= wth->capture.netxray->ticks_per_sec;
 		t -= wth->capture.netxray->start_timestamp;
 		wth->phdr.ts.secs = wth->capture.netxray->start_time + (long)t;
 		wth->phdr.ts.nsecs = (unsigned long)((t-(double)(unsigned long)(t))
@@ -1241,10 +1304,33 @@ netxray_set_pseudo_header(wtap *wth, const guint8 *pd, int len,
 			 */
 			pseudo_header->x25.flags =
 			    (hdr->hdr_2_x.xxx[12] & 0x01) ? 0x00 : FROM_DCE;
+
+			/*
+			 * It appears, at least with version 2 captures,
+			 * that we have 4 bytes of stuff (which might be
+			 * a valid FCS or might be junk) at the end of
+			 * the packet if hdr->hdr_2_x.xxx[2] and
+			 * hdr->hdr_2_x.xxx[3] are 0xff, and we don't if
+			 * they don't.
+			 *
+			 * XXX - does the low-order bit of hdr->hdr_2_x.xxx[8]
+			 * indicate a bad FCS, as is the case with
+			 * Ethernet?
+			 */
+			if (hdr->hdr_2_x.xxx[2] == 0xff &&
+			    hdr->hdr_2_x.xxx[3] == 0xff) {
+				/*
+				 * FCS, or junk, at the end.
+				 * XXX - is it an FCS if "fcs_valid" is
+				 * true?
+				 */
+				padding = 4;
+			}
 			break;
 
 		case WTAP_ENCAP_PPP_WITH_PHDR:
 		case WTAP_ENCAP_SDLC:
+		case WTAP_ENCAP_CHDLC_WITH_PHDR:
 			pseudo_header->p2p.sent =
 			    (hdr->hdr_2_x.xxx[12] & 0x01) ? TRUE : FALSE;
 			break;
